% File src/library/base/man/Extract.data.frame.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Extract.data.frame}
\alias{[.data.frame}
\alias{[[.data.frame}
\alias{[<-.data.frame}
\alias{[[<-.data.frame}
\alias{$.data.frame}
\alias{$<-.data.frame}
\title{Extract or Replace Parts of a Data Frame}
\description{
データフレームの一部分を取り出す，置き換える．
}
\usage{
\method{[}{data.frame}(x, i, j, drop = )
\method{[}{data.frame}(x, i, j) <- value
\method{[[}{data.frame}(x, ..., exact = TRUE)
\method{[[}{data.frame}(x, i, j) <- value
\method{$}{data.frame}(x, name)
\method{$}{data.frame}(x, name) <- value
}
\arguments{
  \item{x}{データフレーム．}

  \item{i, j, ...}{取り出したり置き換える要素．
\code{[} と \code{[[} に対しては，これらは \code{numeric} か \code{character} もしくは，
\code{[} 御身に対しては空，数値の値は \code{\link{as.integer}} によるかのように
強制変換される．\code{[} による置き換えでは論理値行列が許される．}

  \item{name}{
文字通りの文字列，もしくは \link{name} (\link{backtick} で
引用化されているかもしれない)．}

  \item{drop}{論理値．もし \code{TRUE} なら結果は可能な最小の次元に強制変換される．
既定ではもし一つの列だけが残っていれば捨てられるが，
一つの列だけが残っていれば捨てられ無い．}

  \item{value}{適当な置き換え値：必要ならすべての回数
繰り返され強制変換されるかもしれない：強制変換の節を見よ
もし \code{NULL} なら，単一の列が選択されていれば列を消す．}

   \item{exact}{論理値：\code{\link{[}} を見よ，そして列名に適用せよ．}
}
\details{
データフレームは何種類ものモードで添字操作が出来る．\code{[} と 
\code{[[} が単一の添字ベクトルとともに(\code{x[i]} または 
\code{x[[i]]})，データフレームはあたかもそれがリストであるかのように操作される．
この用法では \code{drop} 引数は警告とともに無視される．

\code{$} に対する \code{data.frame} メソッドは \code{x} をリストとして
扱うが，(R-3.1.0 のように) \code{name} の \code{x} の名前への部分マッチング
は警告を生むであろう：これは将来のバージョンではエラーになるかもしれない．
置き換えメソッドは正しい行数に対して \code{value} をチェックし，
必要ならそれを置き換える．

\code{[} と \code{[[} が二つの添字(\code{x[i, j]} と \code{x[[i, j]]})
とともに使われると，それらは行列の添字操作と同様に動作する：
\code{[[} は一つの要素だけを選択するのに使われる．
選択された各列(例えば \code{xj})に対し，(もしそれが行列風でなければ)
典型的には結果の列は \code{xj[i]} になる．そして従って
対応する \code{[} メソッドに依存する．実例の節を参照せよ．

もし \code{[} がデータフレームを返すならば，それはユニーク(で欠損しない)な
行名を持ち，必要なら \code{\link{make.unique}} を用いて行名が変換される．
同様にもし列が選択されると，必要なら列名がユニークになるように
変換される(例えばもしある列が複数回選択されたり，
データフレームが重複する列名を持つとき，与えられた名前の列が複数
選択された時など)．

\code{drop = TRUE} の時は，これはデータフレームに含まれる行列の
部分設定ばかりでなく，データフレーム自体にも適用される．

置き換えメソッドは存在しない列(複数可)を指定することで列を加えるのに
使うことが出来る．この場合列はデータフレームの右端に付け加えられ，
数値添字は存在する添字に隣接しなければならない．
他方で，行は現在の最後の行の後の任意の行に付け加えることが出来る．
そして列は欠損値で埋められるかもしれない．
添字における欠損値は置き換えでは認められない．

\code{[} に対しては置き換え値はリストであっても良い：リストの各要素が
一つの列(の一部分)を置き換え，必要ならリストはリサイクルされる．
もし数値で指定された列が生成されると，対応するリスト要素の名前(もしあれば)
が列の名前に使われる．
もし置き換えが行を選択しなければ，リスト値は
\code{NULL} 要素を含んでもよく，対応する列が削除される．
(実例を見よ．)

\code{[} を用いた行列添字操作(論理値または2列の整数行列 \code{i} を用いた
\code{x[i]})は勧められない．取り出しに対しては，
\code{x} は先ず行列に強制変換される．置き換えに対しては，
論理値行列添字は \code{x} と同じ次元でなければならない．
置き換えはいっときに一行ずつなされ，多重の型変換を伴うことがある．

\code{[} と \code{[[} による取り出しメソッドは行名と部分的にマッチする．
既定では列名には部分的マッチングはされないが，
もし \code{exact = FALSE} (そして \code{exact = NA} なら警告付きで)ならば
\code{[[} は部分的マッチングを行う．もし行名に正確にマッチングを
行いたいなら，実行例におけるように \code{\link{match}} を使う．
}
\section{強制変換}{
置き換え値がいつ強制変換されるかは複雑な話になる．
そして \R の発展に従い変化してきている・この節は概略にすぎない．

\code{[} と \code{[[} が列全体を加えるか置き換えるのに使われるときは
強制変換はされないが，もし正確な繰り返し回数が使われるのなら
\code{value} は正しい長さまで(総称的関数 \code{\link{rep}} を用い)
複製される．

\code{[} が論理値行列とともに使われるときは，
各値はそれが置き換えられる列の型に強制変換される．

\code{[} と \code{[[} が二つの添字とともに使われるときは，
列は値を収容できるよう必要に応じて変換される．

置き換え値が配列(行列を含む)の時は，それは
(\code{\link{data.frame}} と \code{\link{as.data.frame}}
がそうするように)列の系列としては扱われず単一の列として挿入される．
}
\section{警告}{
一つの \emph{行} だけが残される時の既定の動作は 
\code{drop = FALSE} の指定と同値である．
データフレームからリストに落とすには，
\code{drop = TRUE} を明示的に指定する必要がある．

\code{drop} と \code{exact} 以外の引数は名前付きであっては
ならない：もし名前付きで挙動がここで説明されたのと異なれば
警告がでる．
}
\value{
\code{[} に対してはデータフレーム，リストもしくは単一の列(後の二つは
次元が捨て去られているときだけ)．もし行列添字操作が取り出しに使われると
ベクトルが返される．未定義の列が選択されると(データフレームには'欠損'列の
一般的な概念が無いから)もし結果がデータフレームならばエラーになる．
さもなければ，もし単一の列が選択され，これが未定義なら，
結果は \code{NULL} となる．

\code{[[} に対してはデータフレームの列か \code{NULL} 
(一つの添字による取り出し)，もしくは長さ1のベクトル
(二つの添字による取り出し)．

\code{$} に対しては，データフレームの列(または \code{NULL})．

\code{[<-}， \code{[[<-} そして \code{$<-} に対してはデータフレーム．
}
\seealso{
  しばしばより簡単な抜き出しには \code{\link{subset}}，
  \code{\link{data.frame}}， \code{\link{Extract}}．
}
\examples{
sw <- swiss[1:5, 1:4]  # 扱いやすい部分集合を選ぶ

sw[1:3]      # 列を選択
sw[, 1:3]    # 同じ
sw[4:5, 1:3] # 行と列を選択
sw[1]        # 一列のデータフレーム
sw[, 1, drop = FALSE]  # 同じ
sw[, 1]      # (名前無しの)ベクトル
sw[[1]]      # 同じ

sw[1,]       # 一行のデータフレーム
sw[1,, drop = TRUE]  # リスト

sw["C", ] # 部分マッチ
sw[match("C", row.names(sw)), ] # 正確なマッチ無し
try(sw[, "Ferti"]) # 列名は正確にマッチしなければならない

\dontshow{
stopifnot(identical(sw[, 1], sw[[1]]),
          identical(sw[, 1][1], 80.2),
          identical(sw[, 1, drop = FALSE], sw[1]),
          is.data.frame(sw[1]), dim(sw[1] ) == c(5,1),
          is.data.frame(sw[1,]), dim(sw[1,]) == c(1,4),
          is.list(s1 <- sw[1, , drop = TRUE]), identical(s1$Fertility, 80.2))
}
swiss[ c(1, 1:2), ]   # 重複した行，ユニークな行名が生成される

sw[sw <= 6] <- 6  # 論理行列による添字操作
sw

## adding a 列
sw["new1"] <- LETTERS[1:5]   # 文字列の列を加える
sw[["new2"]] <- letters[1:5] # 同じ
sw[, "new3"] <- LETTERS[1:5] # 同じ
sw$new4 <- 1:5
sapply(sw, class)
sw$new4 <- NULL              # 列を削除
sw
sw[6:8] <- list(letters[10:14], NULL, aa = 1:5)
# 列6を更新，列7を削除, 付加
sw

## データフレーム中の行列
A <- data.frame(x = 1:3, y = I(matrix(4:6)), z = I(matrix(letters[1:9], 3, 3)))
A[1:3, "y"] # a matrix
A[1:3, "z"] # a matrix
A[, "y"]    # a matrix

## 特殊な属性を保持：
## "as.data.frame" と "[" メソッドと共にクラスを使う：
% "avector" := vector that keeps attributes and we could provide a constructor
%  avector <- function(x) { class(x) <- c("avector", class(x)); x }
as.data.frame.avector <- as.data.frame.vector

`[.avector` <- function(x,i,...) {
  r <- NextMethod("[")
  mostattributes(r) <- attributes(x)
  r
}

d <- data.frame(i = 0:7, f = gl(2,4),
                u = structure(11:18, unit = "kg", class = "avector"))
str(d[2:4, -1]) # 'u' keeps its "unit"
\dontshow{
stopifnot(identical(d[2:4,-1][,"u"],
                    structure(12:14, unit = "kg", class = "avector")))
}
}
\keyword{array}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Extract.data.frame.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Extract.data.frame}
%\alias{[.data.frame}
%\alias{[[.data.frame}
%\alias{[<-.data.frame}
%\alias{[[<-.data.frame}
%\alias{$.data.frame}
%\alias{$<-.data.frame}
%\title{Extract or Replace Parts of a Data Frame}
%\description{
%  Extract or replace subsets of data frames.
%}
%\usage{
%\method{[}{data.frame}(x, i, j, drop = )
%\method{[}{data.frame}(x, i, j) <- value
%\method{[[}{data.frame}(x, ..., exact = TRUE)
%\method{[[}{data.frame}(x, i, j) <- value
%\method{$}{data.frame}(x, name)
%\method{$}{data.frame}(x, name) <- value
%}
%\arguments{
%  \item{x}{data frame.}
%
%  \item{i, j, ...}{elements to extract or replace.  For \code{[} and
%    \code{[[}, these are \code{numeric} or \code{character} or, for
%    \code{[} only, empty.  Numeric values are coerced to integer as if
%    by \code{\link{as.integer}}.  For replacement by \code{[}, a logical
%    matrix is allowed.}
%
%  \item{name}{
%    A literal character string or a \link{name} (possibly \link{backtick}
%    quoted).}
%
%  \item{drop}{logical.  If \code{TRUE} the result is coerced to the
%    lowest possible dimension.  The default is to drop if only one
%    column is left, but \bold{not} to drop if only one row is left.}
%
%  \item{value}{A suitable replacement value: it will be repeated a whole
%    number of times if necessary and it may be coerced: see the
%    Coercion section.  If \code{NULL}, deletes the column if a single
%    column is selected.}
%
%   \item{exact}{logical: see \code{\link{[}}, and applies to column names.}
%}
%\details{
%  Data frames can be indexed in several modes.  When \code{[} and
%  \code{[[} are used with a single vector index (\code{x[i]} or
%  \code{x[[i]]}), they index the data frame as if it were a list.  In
%  this usage a \code{drop} argument is ignored, with a warning.
%
%  The \code{data.frame} method for \code{$}, treats \code{x} as a
%  list, except that (as of R-3.1.0) partial matching of \code{name} to
%  the names of \code{x} will generate a warning; this may become an
%  error in future versions.  The replacement method checks
%  \code{value} for the correct number of rows, and replicates it if
%  necessary.
%
%  When \code{[} and \code{[[} are used with two indices (\code{x[i, j]}
%  and \code{x[[i, j]]}) they act like indexing a matrix:  \code{[[} can
%  only be used to select one element.  Note that for each selected
%  column, \code{xj} say, typically (if it is not matrix-like), the
%  resulting column will be \code{xj[i]}, and hence rely on the
%  corresponding \code{[} method, see the examples section.
%
%  If \code{[} returns a data frame it will have unique (and non-missing)
%  row names, if necessary transforming the row names using
%  \code{\link{make.unique}}.  Similarly, if columns are selected column
%  names will be transformed to be unique if necessary (e.g., if columns
%  are selected more than once, or if more than one column of a given
%  name is selected if the data frame has duplicate column names).
%
%  When \code{drop = TRUE}, this is applied to the subsetting of any
%  matrices contained in the data frame as well as to the data frame itself.
%
%  The replacement methods can be used to add whole column(s) by specifying
%  non-existent column(s), in which case the column(s) are added at the
%  right-hand edge of the data frame and numerical indices must be
%  contiguous to existing indices.  On the other hand, rows can be added
%  at any row after the current last row, and the columns will be
%  in-filled with missing values.  Missing values in the indices are not
%  allowed for replacement.
%
%  For \code{[} the replacement value can be a list: each element of the
%  list is used to replace (part of) one column, recycling the list as
%  necessary.  If columns specified by number are created, the names
%  (if any) of the corresponding list elements are used to name the
%  columns.  If the replacement is not selecting rows, list values can
%  contain \code{NULL} elements which will cause the corresponding
%  columns to be deleted.  (See the Examples.)
%
%  Matrix indexing (\code{x[i]} with a logical or a 2-column integer
%  matrix \code{i}) using \code{[} is not recommended.  For extraction,
%  \code{x} is first coerced to a matrix. For replacement, logical
%  matrix indices must be of the same dimension as \code{x}.
%  Replacements are done one column at a time, with multiple type
%  coercions possibly taking place.
%
%  Both \code{[} and \code{[[} extraction methods partially match row
%  names.  By default neither partially match column names, but \code{[[}
%  will if \code{exact = FALSE} (and with a warning if \code{exact =
%  NA}).  If you want to exact matching on row names use
%  \code{\link{match}}, as in the examples.
%}
%\section{Coercion}{
%  The story over when replacement values are coerced is a complicated
%  one, and one that has changed during \R's development.  This section
%  is a guide only.
%
%  When \code{[} and \code{[[} are used to add or replace a whole column,
%  no coercion takes place but \code{value} will be
%  replicated (by calling the generic function \code{\link{rep}}) to the
%  right length if an exact number of repeats can be used.
%
%  When \code{[} is used with a logical matrix, each value is coerced to
%  the type of the column into which it is to be placed.
%
%  When  \code{[} and \code{[[} are used with two indices, the
%  column will be coerced as necessary to accommodate the value.
%
%  Note that when the replacement value is an array (including a matrix)
%  it is \emph{not} treated as a series of columns (as
%  \code{\link{data.frame}} and \code{\link{as.data.frame}} do) but
%  inserted as a single column.
%}
%\section{Warning}{
%  The default behaviour when only one \emph{row} is left is equivalent to
%  specifying \code{drop = FALSE}.  To drop from a data frame to a list,
%  \code{drop = TRUE} has to be specified explicitly.
%
%  Arguments other than \code{drop} and \code{exact} should not be named:
%  there is a warning if they are and the behaviour differs from the
%  description here.
%}
%\value{
%  For \code{[} a data frame, list or a single column (the latter two
%  only when dimensions have been dropped).  If matrix indexing is used for
%  extraction a vector results.  If the result would be a data frame an
%  error results if undefined columns are selected (as there is no general
%  concept of a 'missing' column in a data frame).  Otherwise if a single
%  column is selected and this is undefined the result is \code{NULL}.
%
%  For \code{[[} a column of the data frame or \code{NULL}
%  (extraction with one index)
%  or a length-one vector (extraction with two indices).
%
%  For \code{$}, a column of the data frame (or \code{NULL}).
%
%  For \code{[<-}, \code{[[<-} and \code{$<-}, a data frame.
%}
%\seealso{
%  \code{\link{subset}} which is often easier for extraction,
%  \code{\link{data.frame}}, \code{\link{Extract}}.
%}
%\examples{
%sw <- swiss[1:5, 1:4]  # select a manageable subset
%
%sw[1:3]      # select columns
%sw[, 1:3]    # same
%sw[4:5, 1:3] # select rows and columns
%sw[1]        # a one-column data frame
%sw[, 1, drop = FALSE]  # the same
%sw[, 1]      # a (unnamed) vector
%sw[[1]]      # the same
%
%sw[1,]       # a one-row data frame
%sw[1,, drop = TRUE]  # a list
%
%sw["C", ] # partially matches
%sw[match("C", row.names(sw)), ] # no exact match
%try(sw[, "Ferti"]) # column names must match exactly
%
%\dontshow{
%stopifnot(identical(sw[, 1], sw[[1]]),
%          identical(sw[, 1][1], 80.2),
%          identical(sw[, 1, drop = FALSE], sw[1]),
%          is.data.frame(sw[1]), dim(sw[1] ) == c(5,1),
%          is.data.frame(sw[1,]), dim(sw[1,]) == c(1,4),
%          is.list(s1 <- sw[1, , drop = TRUE]), identical(s1$Fertility, 80.2))
%}
%swiss[ c(1, 1:2), ]   # duplicate row, unique row names are created
%
%sw[sw <= 6] <- 6  # logical matrix indexing
%sw
%
%## adding a column
%sw["new1"] <- LETTERS[1:5]   # adds a character column
%sw[["new2"]] <- letters[1:5] # ditto
%sw[, "new3"] <- LETTERS[1:5] # ditto
%sw$new4 <- 1:5
%sapply(sw, class)
%sw$new4 <- NULL              # delete the column
%sw
%sw[6:8] <- list(letters[10:14], NULL, aa = 1:5)
%# update col. 6, delete 7, append
%sw
%
%## matrices in a data frame
%A <- data.frame(x = 1:3, y = I(matrix(4:6)), z = I(matrix(letters[1:9], 3, 3)))
%A[1:3, "y"] # a matrix
%A[1:3, "z"] # a matrix
%A[, "y"]    # a matrix
%
%## keeping special attributes: use a class with a
%## "as.data.frame" and "[" method:
%% "avector" := vector that keeps attributes and we could provide a constructor
%%  avector <- function(x) { class(x) <- c("avector", class(x)); x }
%as.data.frame.avector <- as.data.frame.vector
%
%`[.avector` <- function(x,i,...) {
%  r <- NextMethod("[")
%  mostattributes(r) <- attributes(x)
%  r
%}
%
%d <- data.frame(i = 0:7, f = gl(2,4),
%                u = structure(11:18, unit = "kg", class = "avector"))
%str(d[2:4, -1]) # 'u' keeps its "unit"
%\dontshow{
%stopifnot(identical(d[2:4,-1][,"u"],
%                    structure(12:14, unit = "kg", class = "avector")))
%}
%}
%\keyword{array}
%
\encoding{UTF8}
