% File src/library/base/man/Constants.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012-2014 R Core Team
% Distributed under GPL 2 or later

\name{LongVectors}
\alias{long vector}
\alias{long vectors}
\alias{Long vectors}
\title{Long Vectors}
\description{
\eqn{2^{31}}{2^31} またはそれ以上の要素を持つベクトルが \R 3.0.0 で登場した．
}
\details{
\R 3.0.0 以前では \R のすべてのベクトルは最大 
 \eqn{2^{31} - 1}{2^31 - 1} 個の要素に限られ，整数ベクトルで添字化
 可能であった．

現在すべての \link{atomic} (バイト，整数，論理値，数値，複素数値，文字列)ベクトル，
\link{list} と \link{expression} は64ビットプラットフォームではもっと長く
することが可能である：そうしたベクトルは \sQuote{ロングベクトル} と呼ばれ，
少々異なった内部構造を持つ．理論上は  \eqn{2^{52}}{2^52} 個の要素を
持つことが出来るが，現在の CPU と OS のアドレス空間の制限はもっと限られている．
そうしたオブジェクトは倍精度実数として表現される長さを持ち，
倍精度実数ベクトルで添字化可能である．

配列(行列を含む)は各次元が最大 \eqn{2^{31} - 1}{2^31 - 1} である限り
ロングベクトルを使うことが出来る：従って1次元のロング配列は存在しない．

\R のコードは典型的には僅かな変更でロングベクトルを処理できる．
例えば，おそらく長さに対して不必要な \code{as.integer} が使われていないことを
確認する．しかしながら，コンパイルされたコードは典型的には
相当な変更を必要とする．\code{\link{.C}} と \code{\link{.Fortran}}
インタフェイスはロングベクトルを受けつかず，従って 
 \code{\link{.Call}} (もしくは同類)を使う必要があることを注意しよう．

保管上の必要(文字毎に最低64バイト必要)から，文字列ベクトルは少数の異なる
要素を持つ時だけ有用になるであろう．その時ですら因子の方が
より効率的である(要素毎に8ではなく4バイト)． 従ってロングベクトルの主な使用は
整数ベクトル(因子を含む)と数値ベクトルを意図している．
}

\section{行列代数}{
今や10億個の要素を持つ \eqn{m \times n}{m x n} 行列が使用可能になった．
行列代数(\code{\link{\%*\%}}, \code{\link{crossprod}}, \code{\link{svd}},
  \code{\link{qr}}, \code{\link{solve}} 等) や \code{\link{eigen}} が
実際に可能かどうかは，Fortran コンパイラや外部 
BLAS や LAPACK が使用に使われているかを含む実装次第である．

実用的なパフォーマンスを得るためには効率的な並列 BLAS の移植がしばしば
重要である．例えば，あるプラットフォームでは 47,000 正方行列に対する 
 \code{chol} は内部 BLAS を用いて約5時間，最適化 BLAS を1コアで使うと21分，
16コアの最適化 BLAS では2分かかった．
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Constants.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{LongVectors}
%\alias{long vector}
%\alias{long vectors}
%\alias{Long vectors}
%\title{Long Vectors}
%\description{
%  Vectors of \eqn{2^{31}}{2^31} or more elements were added in \R 3.0.0.
%}
%\details{
%  Prior to \R 3.0.0, all vectors in \R were restricted to at most
%  \eqn{2^{31} - 1}{2^31 - 1} elements and could be indexed by integer
%  vectors.
%
%  Currently all \link{atomic} (raw, logical, integer, numeric, complex,
%  character) vectors, \link{list}s and \link{expression}s can be much
%  longer on 64-bit platforms: such vectors are referred to as
%  \sQuote{long vectors} and have a slightly different internal
%  structure.  In theory up they can to \eqn{2^{52}}{2^52} elements, but
%  address space limits of current CPUs and OSes will be much smaller.
%  Such objects will have a \link{length} that is expressed as a double,
%  and can be indexed by double vectors.
%
%  Arrays (including matrices) can be based on long vectors provided each
%  of their dimensions is at most \eqn{2^{31} - 1}{2^31 - 1}: thus there
%  are no 1-dimensional long arrays.
%
%  \R code typically only needs minor changes to work with long vectors,
%  maybe only checking that \code{as.integer} is not used unnecessarily
%  for e.g.\sspace{}lengths.  However, compiled code typically needs quite
%  extensive changes.  Note that the \code{\link{.C}} and
%  \code{\link{.Fortran}} interfaces do not accept long vectors, so
%  \code{\link{.Call}} (or similar) has to be used.
%
%  Because of the storage requirements (a minimum of 64 bytes per
%  character string), character vectors are only going to be usable if
%  they have a small number of distinct elements, and even then factors
%  will be more efficient (4 bytes per element rather than 8).  So it is
%  expected that most of the usage of long vectors will be integer
%  vectors (including factors) and numeric vectors.
%}
%
%\section{Matrix algebra}{
%  It is now possible to use \eqn{m \times n}{m x n} matrices with more
%  than 2 billion elements.  Whether matrix algebra (including
%  \code{\link{\%*\%}}, \code{\link{crossprod}}, \code{\link{svd}},
%  \code{\link{qr}}, \code{\link{solve}} and \code{\link{eigen}} will
%  actually work is somewhat implementation dependent, including the
%  Fortran compiler used and if an external BLAS or LAPACK is used.
%
%  An efficient parallel BLAS implementation will often be important to
%  obtain usable performance.  For example on one particular platform
%  \code{chol} on a 47,000 square matrix took about 5 hours with the
%  internal BLAS, 21 minutes using an optimized BLAS on one core, and 2
%  minutes using an optimized BLAS on 16 cores.
%}
%
\encoding{UTF8}
