% File src/library/base/man/Sys.setenv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{Sys.setenv}
\alias{Sys.setenv}
\alias{Sys.unsetenv}
\title{Set or Unset Environment Variables}
\usage{
Sys.setenv(\dots)

Sys.unsetenv(x)
}
\arguments{
  \item{\dots}{文字列に変換できる値を持つ名前付き引数．}
  \item{x}{文字列ベクトル，または文字列に変換できるオブジェクト．}
}
\description{
  \code{Sys.setenv} は環境変数を設定する(\R から呼び出される他のプロセスのため，
もしくはこの \R プロセスからの後の \code{\link{Sys.getenv}} 呼び出しのため)．

  \code{Sys.unsetenv} は環境変数を除く．
}
\value{
  論理値ベクトルで，要素はもし対応する変数の設定・除去が成功すると
真となる．(\code{Sys.unsetenv} に対しては，これは存在しない
変数の除去の試みも含む．)
}
\details{
 \code{Sys.setenv} では非標準的な \R 名は引用化されなければならない：
例を見よ．殆どのプラットフォーム(と POSIX)は  \code{"="} を
含む名前を認めていない．
Windows は認めるが，\R が提供する機能はこれらを正確に
扱えないかもしれず，使うべきではない．多くのプラットフォームは
環境変数を  \code{""} に設定することを認めるが，
Windows は認めず，従って \code{Sys.setenv(FOO = "")} は
 \env{FOO} を取り除く．

個々の環境変数やすべての環境変数の最大長にはシステム固有の限界が
あるかもしれない．

Windows は環境ブロックに 32,767 文字の制限を持ち，
  \code{cmd.exe} は各値に対し限界 2047 (Windows 2000) か 8192 文字
  (XP and later) を持つ．
}
% http://support.microsoft.com/kb/830473

\note{
Unix では，もし \code{Sys.unsetenv} がサポートされていなければ，
少なくとも環境変数の値を \code{""} にしようと試み，警告が出る．
}
\seealso{
  \R セッションのため環境変数を設定するためには \code{\link{Sys.getenv}},
  \code{\link{Startup}}．

  作業ディレクトリのためには \code{\link{setwd}}．


  \sQuote{\link{environment variables}} に対するヘルプは \R が
使う多くの環境変数をリストする．
}
\examples{
print(Sys.setenv(R_TEST = "testit", "A+C" = 123))  # `A+C` もまた使える
Sys.getenv("R_TEST") 

# Windows なら
Sys.unsetenv("R_TEST")

# Unix なら
Sys.unsetenv("R_TEST")  # 警告が出，成功しない

Sys.getenv("R_TEST", unset = NA)
}
\keyword{environment}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.setenv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.setenv}
%\alias{Sys.setenv}
%\alias{Sys.unsetenv}
%\title{Set or Unset Environment Variables}
%\usage{
%Sys.setenv(\dots)
%
%Sys.unsetenv(x)
%}
%\arguments{
%  \item{\dots}{named arguments with values coercible to a character string.}
%  \item{x}{a character vector, or an object coercible to character.}
%}
%\description{
%  \code{Sys.setenv} sets environment variables (for other processes
%  called from within \R or future calls to \code{\link{Sys.getenv}} from
%  this \R process).
%
%  \code{Sys.unsetenv} removes environment variables.
%}
%\value{
%  A logical vector, with elements being true if (un)setting the
%  corresponding variable succeeded.  (For \code{Sys.unsetenv} this
%  includes attempting to remove a non-existent variable.)
%}
%\details{
%  Non-standard \R names must be quoted in \code{Sys.setenv}: see the
%  examples.  Most platforms (and POSIX) do not allow names containing
%  \code{"="}.  Windows does, but the facilities provided by \R may not
%  handle these correctly so they should be avoided.  Most platforms
%  allow setting an environment variable to \code{""}, but Windows does
%  not, and there \code{Sys.setenv(FOO = "")} unsets \env{FOO}.
%
%  There may be system-specific limits on the maximum length of the values
%  of individual environment variables or of all environment variables.
%#ifdef windows
%  Windows has a limit of 32,767 characters on the environment block, and
%  \code{cmd.exe} has a limit of 2047 (Windows 2000) or 8192 characters
%  (XP and later) for each value.
%#endif
%}
%% http://support.microsoft.com/kb/830473
%
%#ifdef unix
%\note{
%  If \code{Sys.unsetenv} is not supported, it will at least try to
%  set the value of the environment variable to \code{""}, with a
%  warning.
%}
%#endif
%\seealso{
%  \code{\link{Sys.getenv}}, \link{Startup} for ways to set environment
%  variables for the \R session.
%
%  \code{\link{setwd}} for the working directory.
%
%
%  The help for \sQuote{\link{environment variables}} lists many of the
%  environment variables used by \R.
%}
%\examples{
%print(Sys.setenv(R_TEST = "testit", "A+C" = 123))  # `A+C` could also be used
%Sys.getenv("R_TEST")
%#ifdef windows
%Sys.unsetenv("R_TEST")
%#endif
%#ifdef unix
%Sys.unsetenv("R_TEST")  # may warn and not succeed
%#endif
%Sys.getenv("R_TEST", unset = NA)
%}
%\keyword{environment}
%\keyword{utilities}
%
\encoding{UTF8}
