% File src/library/base/man/data.class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{data.class}
\alias{data.class}
\title{Object Classes}
\description{
  任意の \R オブジェクトのクラスを決定する．
}
\usage{
data.class(x)
}
\arguments{
  \item{x}{\R オブジェクト．}
}
\value{
  \code{x} のクラスを与える文字列．

  クラスはそれが \code{NULL} でなければ \code{\link{class}} 属性の
  最初の要素である．もしくはそれが \code{NULL} でなければオブジェクトの
  次元属性から導かれる．もしくは \code{mode(x)} である．

  簡単に言えば \code{data.class(x)} はメソッドの選択適用に典型的に
  有用な物を返す．(もしくは基本的な構成関数が既にか恐らく結局はクラス属性として
  付与するであろうもの．)
}
\note{
  互換性の理由から，上の規則に対する例外が一つある：
  \code{x} が \code{\link{integer}} なら
  \code{data.class(x)} の結果は \code{x} がクラスを持っていても
  \code{"numeric"} とされる．
}
\seealso{
  \code{\link{class}}
}
\examples{
x <- LETTERS
data.class(factor(x))                 # クラス属性を持つ
data.class(matrix(x, ncol = 13))      # 次元属性を持つ
data.class(list(x))                   # mode(x) と同じ
data.class(x)                         # mode(x) と同じ

stopifnot(data.class(1:2) == "numeric") # 互換性"規則"
}
\keyword{classes}
\keyword{methods}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/data.class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{data.class}
%\alias{data.class}
%\title{Object Classes}
%\description{
%  Determine the class of an arbitrary \R object.
%}
%\usage{
%data.class(x)
%}
%\arguments{
%  \item{x}{an \R object.}
%}
%\value{
%  character string giving the \emph{class} of \code{x}.
%
%  The class is the (first element) of the \code{\link{class}}
%  attribute if this is non-\code{NULL}, or inferred from the object's
%  \code{dim} attribute if this is non-\code{NULL}, or \code{mode(x)}.
%
%  Simply speaking, \code{data.class(x)} returns what is typically useful
%  for method dispatching.  (Or, what the basic creator functions already
%  and maybe eventually all will attach as a class attribute.)
%}
%\note{
%  For compatibility reasons, there is one exception to the rule above:
%  When \code{x} is \code{\link{integer}}, the result of
%  \code{data.class(x)} is \code{"numeric"} even when \code{x} is classed.
%}
%\seealso{
%  \code{\link{class}}
%}
%\examples{
%x <- LETTERS
%data.class(factor(x))                 # has a class attribute
%data.class(matrix(x, ncol = 13))      # has a dim attribute
%data.class(list(x))                   # the same as mode(x)
%data.class(x)                         # the same as mode(x)
%
%stopifnot(data.class(1:2) == "numeric") # compatibility "rule"
%}
%\keyword{classes}
%\keyword{methods}
%
\encoding{UTF8}
