% File src/library/base/man/deparseOpts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{deparseOpts}
\alias{.deparseOpts}
\title{Options for Expression Deparsing}
\description{
  \code{deparse}, \code{dput} そして \code{dump} に対する
  逆構文解析オプションを処理する．
}
\usage{
.deparseOpts(control)
}
\arguments{
  \item{control}{逆構文解析オプションの文字列．}
}
\details{
  これは \code{\link{deparse}}, \code{\link{dput}} そして 
  \code{\link{dump}} によりそれらの \code{control} 引数を処理するために
  呼び出される．

  \code{control} 引数はゼロもしくはそれ以上の以下の文字列を含む
  ベクトルである．部分マッチングが使われる．
  \describe{
    \item{\code{keepInteger}}{
      整数ベクトルを \code{as.integer()} で囲むか接尾辞 \code{L} をつけて
      構文解析時に倍精度数値に変換されないようにする．
      \code{"S_compatible"} が設定されていない限り，ベクトル中に
      \code{NA} でない値がないとき
      これは整数 \code{NA} が(\code{NA_integer_} により)保護されることを
      保証する．
    }
    \item{\code{quoteExpressions}}{
      表現式を \code{quote()} で囲み，再構文解析時に評価されないようにする．
    }
    \item{\code{showAttributes}}{
      オブジェクトが(\code{source} 属性以外の)属性を持つとき，
      それらをオブジェクトの値と並んで表示するために \code{structure()} を使う．
      これは \code{\link{deparse}} と \code{\link{dput}} の既定値である．
    }
    \item{\code{useSource}}{
      もしオブジェクトが \code{source} 属性を持てば，オブジェクトを逆解析する代わりに
      それを表示する．現在関数定義だけに適用される．
    }
    \item{\code{warnIncomplete}}{
      \link{environment} や外部ポインター等のある種の奇妙なオブジェクトは
      正しく逆構文解析されない．このオプションはもし逆構文解析器がこうした状況の
      一つを認識すると警告を発生する．

      同等に，\R < 2.7.0 の構文解析器は8192バイトまでの文字列しか受け付けず，
      このオプションはそれより長い文字列に対して警告する．
    }
    \item{\code{keepNA}}{
      整数，実数そして文字列 \code{NA} は必要なら同じ型に構文解析されるように，
      強制変換関数で囲まれる．\R では \code{NA_real_} は出力可能なので，
      これは主に \code{S_compatible} との関連で用いられる．
    }
    \item{\code{all}}{
      上に挙げられたすべてのオプションを指定する省略形．
      これは \code{dump} に対しては既定で，\code{\link{edit}} (固定されている)
      で使われるオプションである．
    }
    \item{\code{delayPromises}}{
      予約を評価する代わりに <promise: expression> の形式に逆構文解析する．
      値と予約の環境は示されず逆構文解析されたコードは読み込み実行できない．
    }
    \item{\code{S_compatible}}{
      S と \R < 2.5.0 に可能な限り互換に逆構文解析する．
      S との互換性のために倍精度ベクトル中の整数値は小数点付きで逆構文解析される．
      バックチックは使われない．
    }
    \item{\code{hexNumeric}}{
      実数と有限複素数は2進小数として最大の記録正確度を持つ \samp{"\%a"} の形式で出力される
      (16進数としてコードされる：\code{\link{sprintf}} を見よ)
      一方もしくは双方が有限でない複素数値はあたかもこのオプションが未設定であるかのように
      出力される．

      (これはこの書式が正確にサポートされていることに依存している：
      Windows 上での既知の問題は \R 3.1.2 以来解消されている．)
    }
    \item{\code{digits17}}{
      実数と有限複素数は既定よりもより高精度な表示を与える \samp{"\%.17g"}
      の形式で出力される(しかし出力はプラットフォームに依存し，読み戻される際に
      精度の損失があり得る)．
      一方もしくは双方が有限でない複素数値はあたかもこのオプションが未設定であるかのように
      出力される．
    }
  }
  殆どの読みやすい(しかし恐らく不完全な)表示に対しては
  \code{control = NULL} を使おう．これはオブジェクトの値を表示するが，
  その属性はしない．\code{\link{deparse}} の既定は属性も表示するが，
  結果の構文可能性を高める他のオプションは一切使用しない．
  (\code{\link{dput}} と \code{\link{dump}} はより多くの既定オプションを使い，
  ソースのない関数のプリントに \code{c("keepInteger", "keepNA")} を使う．)

  \code{control = "all"} の使用は \code{deparse()} を最も 
  \code{parse()} の逆操作に近くする．しかしながら，このオプションでもすべてのオブジェクトが
  逆構文解析可能になるわけではない．もし不可能なことを要求されていると
  関数が認識すると警告が出る．
  また倍精度実数と複素数値の10進数表現は不正確になることがあり得る．

  \code{"hexNumeric"} と \code{"digits17"} の一方だけが指定できる．
}
\value{
  選択されたオプションに対応する数値．
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/deparseOpts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{deparseOpts}
%\alias{.deparseOpts}
%\title{Options for Expression Deparsing}
%\description{
%  Process the deparsing options for \code{deparse}, \code{dput} and
%  \code{dump}.
%}
%\usage{
%.deparseOpts(control)
%}
%\arguments{
%  \item{control}{character vector of deparsing options.}
%}
%\details{
%  This is called by \code{\link{deparse}}, \code{\link{dput}} and
%  \code{\link{dump}} to process their \code{control} argument.
%
%  The \code{control} argument is a vector containing zero or more of the
%  following strings.  Partial string matching is used.
%  \describe{
%    \item{\code{keepInteger}}{
%      Either surround integer vectors by \code{as.integer()} or use
%      suffix \code{L}, so they are not converted to type double when
%      parsed.  This includes making sure that integer \code{NA}s are
%      preserved (via \code{NA_integer_} if there are no non-\code{NA}
%      values in the vector, unless \code{"S_compatible"} is set).
%    }
%    \item{\code{quoteExpressions}}{
%      Surround expressions with \code{quote()}, so they are not
%      evaluated when re-parsed.
%    }
%    \item{\code{showAttributes}}{
%      If the object has attributes (other than a \code{source}
%      attribute), use \code{structure()} to display them as well as the
%      object value.  This is the default for \code{\link{deparse}} and
%      \code{\link{dput}}.
%    }
%    \item{\code{useSource}}{
%      If the object has a \code{source} attribute, display that instead
%      of deparsing the object.  Currently only applies to function
%      definitions.
%    }
%    \item{\code{warnIncomplete}}{
%      Some exotic objects such as \link{environment}s, external
%      pointers, etc. can not be deparsed properly.  This option causes a
%      warning to be issued if the deparser recognizes one of these
%      situations.
%
%      Also, the parser in \R < 2.7.0 would only accept strings of up to
%      8192 bytes, and this option gives a warning for longer strings.
%    }
%    \item{\code{keepNA}}{
%      Integer, real and character \code{NA}s are surrounded by coercion
%      functions where necessary to ensure that they are parsed to the
%      same type.  Since e.g.\sspace{}\code{NA_real_} can be output in \R, this is
%      mainly used in connection with \code{S_compatible}.
%    }
%    \item{\code{all}}{
%      An abbreviated way to specify all of the options
%      listed above.  This is the default for \code{dump}, and the options
%      used by \code{\link{edit}} (which are fixed).
%    }
%    \item{\code{delayPromises}}{
%      Deparse promises in the form <promise: expression> rather than
%      evaluating them.  The value and the environment of the promise
%      will not be shown and the deparsed code cannot be sourced.
%    }
%    \item{\code{S_compatible}}{
%      Make deparsing as far as possible compatible with S and \R < 2.5.0.
%      For compatibility with S, integer values of double vectors are
%      deparsed with a trailing decimal point.  Backticks are not used.
%    }
%    \item{\code{hexNumeric}}{
%      Real and finite complex numbers are output in \samp{"\%a"} format as
%      binary fractions (coded as hexadecimal: see \code{\link{sprintf}})
%      with maximal opportunity to be recorded exactly to full precision.
%      Complex numbers with one or both non-finite components are
%      output as if this option were not set.
%
%      (This relies on that format being correctly supported: known
%      problems on Windows are worked around as from \R 3.1.2.)
%    }
%    \item{\code{digits17}}{
%      Real and finite complex numbers are output using format
%      \samp{"\%.17g"} which may give more precision than the default
%      (but the output will depend on the platform and there may be loss
%      of precision when read back).  Complex numbers with one or both
%      non-finite components are output as if this option were not set.
%    }
%  }
%  For the most readable (but perhaps incomplete) display, use
%  \code{control = NULL}. This displays the object's value, but not its
%  attributes.  The default in \code{\link{deparse}} is to display the
%  attributes as well, but not to use any of the other options to make
%  the result parseable.  (\code{\link{dput}} and \code{\link{dump}} do
%  use more default options, and printing of functions without sources
%  uses \code{c("keepInteger", "keepNA")}.)
%
%  Using \code{control = "all"} comes closest to making \code{deparse()}
%  an inverse of \code{parse()}.  However, not all objects are
%  deparse-able even with this option.  A warning will be issued if the
%  function recognizes that it is being asked to do the impossible.
%  Also, representing double and complex numbers as decimals may well not
%  be exact.
%
%  Only one of \code{"hexNumeric"} and \code{"digits17"} can be specified.
%}
%\value{
%  A numerical value corresponding to the options selected.
%}
%\keyword{programming}
%
\encoding{UTF8}
