% File src/library/base/man/icuSetCollate.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2015 R Core Team
% Distributed under GPL 2 or later

\name{icuSetCollate}
\alias{icuSetCollate}
\alias{icuGetCollate}
\alias{R_ICU_LOCALE}

\title{ Setup Collation by ICU }
\description{
  ICU (\R の構築の際のオプション部分)が行う照合の仕方を制御する．
}
\usage{
icuSetCollate(...)

icuGetCollate(type = c("actual", "valid"))
}
\arguments{
  \item{\dots}{名前付き引数，\sQuote{詳細}を見よ．}
  \item{type}{文字列：簡略化可能．照合に使われる実際のロケールか
    正当であるべき最も特別なロケール．}
}
\details{
  オプションで \R は ICU を使って文字列を照合するように構築できる
  (\url{http://site.icu-project.org})．そうしたシステムに対しては
  \code{icuSetCollate} を照合の仕方を調節するのに使える．
  他の構築ではこの関数の呼び出しは何もせず，警告が出る．

  可能な引数は
  \describe{
    \item{\code{locale}:}{\code{"da_DK"} のような文字列で，
      照合規則を使う言語と国を与える．
      もし存在すればこれは最初の引数でなければならない．}
    \item{\code{case_first}:}{\code{"upper"}, \code{"lower"} 又は
      \code{"default"} で，大文字か小文字を最初にソートすることを要求する．
      既定では普通小文字が最初であるが，あらゆる国でそうとは限らない
      (例えばデンマーク語の既定ではそうではない)．}
    \item{\code{alternate_handling}:}{
      \sQuote{変数}文字(主に句読点とシンボル)の処理を制御する．
      可能な値は \code{"non_ignorable"} (第一強度)と
      \code{"shifted"} (第四強度)．}
    \item{\code{strength}:}{どの成分を使うべきか? 可能な値は
      \code{"primary"}, \code{"secondary"}, \code{"tertiary"}
      (既定), \code{"quaternary"} そして \code{"identical"}．}
    \item{\code{french_collation}:}{フランスロケールではアクセントが
      照合に及ぼす影響は右から左であるが，ほとんどの他のロケールでは
      それは左から右である．可能な値は \code{"on"}, \code{"off"}
      そして \code{"default"}．}
    \item{\code{normalization}:}{文字列は正規化されるべきか?  可能な値は
      \code{"on"} と \code{"off"} (既定値)．これは複合文字の照合に影響する．}
    \item{\code{case_level}:}{二番目と三番目の間の追加レベルで，
      大小の日本語の仮名文字を区別するのに使われる．
      可能な値は \code{"on"} と \code{"off"} (既定値)．}
    \item{\code{hiragana_quaternary}:}{可能な値は \code{"on"} (平仮名を
      第三レベルで最初にソート) と \code{"off"}．}
  }
  照合の詳細な理解があるか特殊な要求を除けば，最初の三つが恐らく
  興味があるであろう．

  \code{locale} には幾つかの特殊な値が受け入れられる：
  \describe{
    \item{\code{"none"}:}{ICU を照合に使わない：代わりに OS の
      照合サービスが使われる．(\R 3.1.2. から)}
    \item{\code{"ASCII"}:}{ICU を照合に使わない：代わりに C 関数
      \code{strcmp} が使われる．これは(符号無しの)数値順序でバイトごとに
      ソートする．(\R 3.1.3. から)}
    \item{\code{"default"}:}{
      セッションの最初になされるように OS からロケールを得る．
      もし環境変数 \env{R_ICU_LOCALE} が空でない値に設定されていれば，
      OS のサービスを使う代わりにその値が用いられる．
    }
    \item{\code{""}, \code{"root"}:}{
      \sQuote{root} 照合：
      \url{http://www.unicode.org/reports/tr35/tr35-collation.html#Root_Collation}
      を見よ．
    }
  }
  現実の ICU ロケールの指定については
  \url{http://userguide.icu-project.org/locale} を見よ．ICU は
  あるロケールがサポートされていることを報告せず，
  それが\sQuote{最適}と考えるものに戻る
  (これはかなり相違する可能性があり \code{icuGetCollate("actual")} で
  報告される，しばしば \code{"root"} である)．殆どの英語のロケールは
  \code{"root"} に戻る．なぜなら，例えば \code{"en_GB"} は適正なロケール
  であるが，照合に関する特別な規則を持たないためである．
  \code{"C"} はサポートされている ICU ロケールではないことを注意する．
  
  例としては \code{case_level = "on", strength = "primary"} はアクセントの
  違いを無視し，\code{alternate_handling = "shifted"} は空白と句読点を
  無視する．
  
  もし OS が照合のために \code{C} ロケールを使うように設定されていれば，最初 ICU
  は照合のために使われない．一旦この関数が \code{locale} の値と共に呼び出されると，
  \code{locale = "none"} と共に再び呼び出されるまで ICU が使われる．

  もし \code{locale} が指定されると，すべてのカスタム化は既定値にリセットされる：
  OS の照合位置カテゴリーが \code{\link{Sys.setlocale}} で
  変更されると，照合エンジンはリセットされる．
}
\value{
  \code{icuGetCollate} に対しては使用中の ICU ロケールを説明する文字列
  (\code{"ICU not in use"} と報告されるかもしれない).
  \sQuote{実際}のロケールは要求されるロケールよりも簡単かもしれない：
  例えば \code{"da_DK"} の代わりに \code{"da"}：英語のロケールは恐らく
  \code{"root"} と報告される．
}
\note{
  ICU は利用可能な限り既定で使われる：これは
  OS X, Solaris そして多くの Linux に該当する．
  UTF-8 では内部的に動作するので UTF-8 ロケールで最も有効である．

  Windows ではこれはオプションである：もし \R が ICU 付きで構築されると，
  環境変数  \env{R_ICU_LOCALE} が設定されるか，
  一度 \code{icuSetCollate} がロケールを選択するために呼び出された時だけ使われる
  (ICU と Windows はロケール名に関する意見が違うため)．\cr
  \code{icuSetCollate(locale = "default")} は
  \R >= 3.2.0 と Windows Vista/Server 2008 及びそれ以降で
  かなり上手く動作するであろう
  (しかし \env{LC_COLLATE}) のような環境変数を無視するシステム既定動作を
  が見受けられる)．
}
\seealso{
  \code{\link{Comparison}}, \code{\link{sort}}.

  どこで ICU が得られるかについては \code{\link{capabilities}}；
  そのバージョンについては \code{\link{extSoftVersion}}．

  照合に関する ICU のユーザーガイドの章
  (\url{http://userguide.icu-project.org/collation}).
}
\examples{\donttest{
## これらは利用できる ICU とロケールに依存する．
## 現在の設定が分からないので既定値にリセットするしか無い．
if(capabilities("ICU")) {
    print(icuGetCollate())
    print(icuGetCollate("valid"))
    x <- c("Aarhus", "aarhus", "safe", "test", "Zoo")
    print(sort(x))
    icuSetCollate(case_first = "upper"); print(sort(x))
    icuSetCollate(case_first = "lower"); print(sort(x))

    ## デンマークの照合で大文字が最初で 'aa' は単一の文字
    icuSetCollate(locale = "da_DK", case_first = "default"); print(sort(x)) 
    ## エストニア語では Z を S と T の間に置く
    icuSetCollate(locale = "et_EE"); print(sort(x))
    icuSetCollate(locale = "default"); print(icuGetCollate("valid"))
}
}}
\keyword{ utilities }

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/icuSetCollate.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{icuSetCollate}
%\alias{icuSetCollate}
%\alias{icuGetCollate}
%\alias{R_ICU_LOCALE}
%
%\title{ Setup Collation by ICU }
%\description{
%  Controls the way collation is done by ICU (an optional part of the \R
%  build).
%}
%\usage{
%icuSetCollate(...)
%
%icuGetCollate(type = c("actual", "valid"))
%}
%\arguments{
%  \item{\dots}{Named arguments, see \sQuote{Details}.}
%  \item{type}{character string: can be abbreviated.  Either the actual locale
%    in use for collation or the most specific locale which would be valid.}
%}
%\details{
%  Optionally, \R can be built to collate character strings by ICU
%  (\url{http://site.icu-project.org}).  For such systems,
%  \code{icuSetCollate} can be used to tune the way collation is done.
%  On other builds calling this function does nothing, with a warning.
%
%  Possible arguments are
%  \describe{
%    \item{\code{locale}:}{A character string such as \code{"da_DK"}
%      giving the language and country whose collation rules are to be
%      used.  If present, this should be the first argument.}
%    \item{\code{case_first}:}{\code{"upper"}, \code{"lower"} or
%      \code{"default"}, asking for upper- or lower-case characters to be
%      sorted first.  The default is usually lower-case first, but not in
%      all languages (not under the default settings for Danish, for example).}
%    \item{\code{alternate_handling}:}{Controls the handling of
%      \sQuote{variable} characters (mainly punctuation and symbols).
%      Possible values are \code{"non_ignorable"} (primary strength) and
%      \code{"shifted"} (quaternary strength).}
%    \item{\code{strength}:}{Which components should be used?  Possible
%      values \code{"primary"}, \code{"secondary"}, \code{"tertiary"}
%      (default), \code{"quaternary"} and \code{"identical"}. }
%    \item{\code{french_collation}:}{In a French locale the way accents
%      affect collation is from right to left, whereas in most other locales
%      it is from left to right.  Possible values \code{"on"}, \code{"off"}
%      and \code{"default"}.}
%    \item{\code{normalization}:}{Should strings be normalized?  Possible values
%      are \code{"on"} and \code{"off"} (default).  This affects the
%      collation of composite characters.}
%    \item{\code{case_level}:}{An additional level between secondary and
%      tertiary, used to distinguish large and small Japanese Kana
%      characters. Possible values \code{"on"} and \code{"off"} (default).}
%    \item{\code{hiragana_quaternary}:}{Possible values \code{"on"} (sort
%      Hiragana first at quaternary level) and \code{"off"}.}
%  }
%  Only the first three are likely to be of interest except to those with a
%  detailed understanding of collation and specialized requirements.
%
%  Some special values are accepted for \code{locale}:
%  \describe{
%    \item{\code{"none"}:}{ICU is not used for collation: the OS's
%      collation services are used instead.  (As from \R 3.1.2.)}
%    \item{\code{"ASCII"}:}{ICU is not used for collation: the C function
%      \code{strcmp} is used instead, which should sort byte-by-byte in
%      (unsigned) numerical order.  (As from \R 3.1.3.)}
%    \item{\code{"default"}:}{
%      obtains the locale from the OS as is done at the start of the
%      session.  If environment variable \env{R_ICU_LOCALE} is set to a
%      non-empty value, its value is used rather than consulting the OS.
%    }
%    \item{\code{""}, \code{"root"}:}{
%      the \sQuote{root} collation: see
%      \url{http://www.unicode.org/reports/tr35/tr35-collation.html#Root_Collation}.
%    }
%  }
%  For the specifications of \sQuote{real} ICU locales, see
%  \url{http://userguide.icu-project.org/locale}.  Note that ICU does not
%  report that a locale is not supported, but falls back to its idea of
%  \sQuote{best fit} (which could be rather different and is reported by
%  \code{icuGetCollate("actual")}, often \code{"root"}).  Most English
%  locales fall back to \code{"root"} as although e.g.\sspace{}\code{"en_GB"} is
%  a valid locale (at least on some platforms), it contains no special
%  rules for collation.  Note that \code{"C"} is not a supported ICU locale.
%  
%  Some examples are \code{case_level = "on", strength = "primary"} to ignore
%  accent differences and \code{alternate_handling = "shifted"} to ignore
%  space and punctuation characters.
%  
%  Initially ICU will not be used for collation if the OS is set to use
%  the \code{C} locale for collation.  Once this function is called with
%  a value for \code{locale}, ICU will be used until it is called again
%  with \code{locale = "none"}.
%
%  All customizations are reset to the default for the locale if
%  \code{locale} is specified: the collation engine is reset if the
%  OS collation locate category is changed by \code{\link{Sys.setlocale}}.
%}
%\value{
%  For \code{icuGetCollate}, a character string describing the ICU locale
%  in use (which may be reported as \code{"ICU not in use"}).  The
%  \sQuote{actual} locale may be simpler than the requested locale: for
%  example \code{"da"} rather than \code{"da_DK"}: English locales are
%  likely to report \code{"root"}.
%}
%\note{
%  ICU is used by default wherever it is available: this include OS X,
%  Solaris and many Linux installations.  As it works internally in
%  UTF-8, it will be most efficient in UTF-8 locales.
%
%  It is optional on Windows: if \R has been built against ICU, it will
%  only be used if environment variable \env{R_ICU_LOCALE} is set or once
%  \code{icuSetCollate} is called to select the locale (as ICU and
%  Windows differ in their idea of locale names).  Note that
%  \code{icuSetCollate(locale = "default")} should work reasonably well
%  for \R >= 3.2.0 and Windows Vista/Server 2008 and later (but finds the
%  system default ignoring environment variables such as \env{LC_COLLATE}).
%}
%\seealso{
%  \link{Comparison}, \code{\link{sort}}.
%
%  \code{\link{capabilities}} for whether ICU is available;
%  \code{\link{extSoftVersion}} for its version.
%
%  The ICU user guide chapter on collation
%  (\url{http://userguide.icu-project.org/collation}).
%}
%\examples{\donttest{
%## These examples depend on having ICU available, and on the locale.
%## As we don't know the current settings, we can only reset to the default.
%if(capabilities("ICU")) {
%    print(icuGetCollate())
%    print(icuGetCollate("valid"))
%    x <- c("Aarhus", "aarhus", "safe", "test", "Zoo")
%    print(sort(x))
%    icuSetCollate(case_first = "upper"); print(sort(x))
%    icuSetCollate(case_first = "lower"); print(sort(x))
%
%    ## Danish collates upper-case-first and with 'aa' as a single letter
%    icuSetCollate(locale = "da_DK", case_first = "default"); print(sort(x)) 
%    ## Estonian collates Z between S and T
%    icuSetCollate(locale = "et_EE"); print(sort(x))
%    icuSetCollate(locale = "default"); print(icuGetCollate("valid"))
%}
%}}
%\keyword{ utilities }
%
\encoding{UTF8}
