% File src/library/base/man/make.names.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{make.names}
\alias{make.names}
\title{Make Syntactically Valid Names}
\description{
  文字列ベクトルから構文的に正しい名前を作る．
}
\usage{
make.names(names, unique = FALSE, allow_ = TRUE)
}
\arguments{
 \item{names}{構文的に正しい名前に変換される文字列ベクトル．
   これは必要なら文字に変換される．}
 \item{unique}{論理値；もし \code{TRUE} なら結果の要素はユニークである．
   これは，例えば列名としては望ましいかもしれない．}
 \item{allow_}{論理値．1.9.0. 以前の \R への互換性のため．}
}
\value{
  \code{names} と同じ長さの文字列ベクトルで，
  各々が現在のロケールのエンコーディングで構文的に正しい名前に変換されている．
}
\details{
  構文的に適正な名前は文字，数字，そしてドットもしくはアンダースコアから成り，
  文字かドットで始まり数字が続かない．
  \code{".2way"} のような名前や予約語は適正ではない．

  \emph{文字}の定義は現在のロケールに依存するが，
  ASCII 数字だけが数字と考えられる．

  必要なら文字 \code{"X"} が先頭に付く．
  全ての不正な文字は \code{"."} と翻訳される．欠損値は
  \code{"NA"} と翻訳される．
  \R のキーワードにマッチする名前はドットが付け加えられる．
  重複した値は \code{\link{make.unique}} で変更される．
}

\section{警告}{
  ある種の OS，特に FreeBSD，はある種のロケールでどの文字がアルファベットなのかについて
  非常に不正確な情報を報告する(典型的には UTF-8 ロケールを含む
  多バイトロケール)．しかしながら \R は Windows, OS X そして AIX に対しては
  正しく置き換える．
}
\note{
  \R のバージョン 1.9.0 以前ではアンダースコアは変数名には使えず，
  それらがドットに変換されていることに基づいたコードは最早
  動作しない．過去への互換性のためには \code{allow_ = FALSE} を使う．

  \code{allow_ = FALSE} も名前にアンダースコアを認めないアプリケーションへの
  移出用に名前を作る際には有用である(例えば，S-PLUS やある種の DBMS)．
}
\seealso{
  \code{\link{make.unique}},
  \code{\link{names}},
  \code{\link{character}},
  \code{\link{data.frame}}.
}
\examples{
make.names(c("a and b", "a-and-b"), unique = TRUE)
# "a.and.b"  "a.and.b.1"
make.names(c("a and b", "a_and_b"), unique = TRUE)
# "a.and.b"  "a_and_b"
make.names(c("a and b", "a_and_b"), unique = TRUE, allow_ = FALSE)
# "a.and.b"  "a.and.b.1"
make.names(c("", "X"), unique = TRUE)
# 現在は "X.1" "X"; 3.0.2 までの R は "X" "X.1" を与えた

state.name[make.names(state.name) != state.name] # 空白を持つ 10 組
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/make.names.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{make.names}
%\alias{make.names}
%\title{Make Syntactically Valid Names}
%\description{
%  Make syntactically valid names out of character vectors.
%}
%\usage{
%make.names(names, unique = FALSE, allow_ = TRUE)
%}
%\arguments{
% \item{names}{character vector to be coerced to syntactically valid
%   names.  This is coerced to character if necessary.}
% \item{unique}{logical; if \code{TRUE}, the resulting elements are
%     unique.  This may be desired for, e.g., column names.}
% \item{allow_}{logical.  For compatibility with \R prior to 1.9.0.}
%}
%\value{
%  A character vector of same length as \code{names} with each changed to
%  a syntactically valid name, in the current locale's encoding.
%}
%\details{
%  A syntactically valid name consists of letters, numbers and the dot or
%  underline characters and starts with a letter or the dot not followed
%  by a number.  Names such as \code{".2way"} are not valid, and neither
%  are the \link{reserved} words.
%
%  The definition of a \emph{letter} depends on the current locale, but
%  only ASCII digits are considered to be digits.
%
%  The character \code{"X"} is prepended if necessary.
%  All invalid characters are translated to \code{"."}.  A missing value
%  is translated to \code{"NA"}.  Names which match \R keywords have a dot
%  appended to them.  Duplicated values are altered by
%  \code{\link{make.unique}}.
%}
%
%\section{Warning}{
%  Some OSes, notably FreeBSD, report extremely incorrect information about
%  which characters are alphabetic in some locales (typically, all
%  multi-byte locales including UTF-8 locales).  However, \R provides
%  substitutes on Windows, OS X and AIX.
%}
%\note{
%  Prior to \R version 1.9.0, underscores were not valid in variable names,
%  and code that relies on them being converted to dots will no longer
%  work. Use \code{allow_ = FALSE} for back-compatibility.
%
%  \code{allow_ = FALSE} is also useful when creating names for export to
%  applications which do not allow underline in names (for example,
%  S-PLUS and some DBMSs).
%}
%\seealso{
%  \code{\link{make.unique}},
%  \code{\link{names}},
%  \code{\link{character}},
%  \code{\link{data.frame}}.
%}
%\examples{
%make.names(c("a and b", "a-and-b"), unique = TRUE)
%# "a.and.b"  "a.and.b.1"
%make.names(c("a and b", "a_and_b"), unique = TRUE)
%# "a.and.b"  "a_and_b"
%make.names(c("a and b", "a_and_b"), unique = TRUE, allow_ = FALSE)
%# "a.and.b"  "a.and.b.1"
%make.names(c("", "X"), unique = TRUE)
%# "X.1" "X" currently; R up to 3.0.2 gave "X" "X.1"
%
%state.name[make.names(state.name) != state.name] # those 10 with a space
%}
%\keyword{character}
%
\encoding{UTF8}
