% File src/library/base/man/polyroot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{polyroot}
\title{Find Zeros of a Real or Complex Polynomial}
\usage{
polyroot(z)
}
\alias{polyroot}
\arguments{
  \item{z}{多項式係数の増加順のベクトル．}
}
\description{
  実数又は複素数係数の多項式のゼロ点を見つける．
}
\details{
  次数 \eqn{n - 1} の多項式
  \deqn{
    p(x) = z_1 + z_2 x + \cdots + z_n x^{n-1}}{
    p(x) = z1 + z2 * x + \ldots + z[n] * x^(n-1)}
  はその係数ベクトル \code{z[1:n]} で与えられる．
  \code{polyroot} は \eqn{p(x)} の \eqn{n-1} 個のゼロ点を
  Jenkins-Traub アルゴリズムを用いて計算する．

  もし係数ベクトル \code{z} が最高次数にゼロを持てばそれらは
  捨てられる．

  次数の最大値はないが，低次の多項式を除けば数値的安定性が
  問題になる．
}
\value{
  長さ \eqn{n - 1} の複素数値ベクトルで，\eqn{n} は
  \code{z} の最大の非ゼロ要素の位置である．
}
\source{
  参考文献中の Fortran コードの Ross Ihaka による翻訳，
  R Core Team による修正を含む．
}
\references{
  Jenkins and Traub (1972)
  TOMS Algorithm 419.
  \emph{Comm. ACM}, \bold{15}, 97--99.
}
\seealso{
  任意の関数の根を見つける \code{\link{uniroot}}；
  デモディレクトリの \code{\link{complex}} と \code{zero} の例．
}
\examples{
polyroot(c(1, 2, 1))
round(polyroot(choose(8, 0:8)), 11) # 結果を予想してみよ!
for (n1 in 1:4) print(polyroot(1:n1), digits = 4)
polyroot(c(1, 2, 1, 0, 0)) # 最初と同じ
}
\keyword{math}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/polyroot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{polyroot}
%\title{Find Zeros of a Real or Complex Polynomial}
%\usage{
%polyroot(z)
%}
%\alias{polyroot}
%\arguments{
%  \item{z}{the vector of polynomial coefficients in increasing order.}
%}
%\description{
%  Find zeros of a real or complex polynomial.
%}
%\details{
%  A polynomial of degree \eqn{n - 1},
%  \deqn{
%    p(x) = z_1 + z_2 x + \cdots + z_n x^{n-1}}{
%    p(x) = z1 + z2 * x + \ldots + z[n] * x^(n-1)}
%  is given by its coefficient vector \code{z[1:n]}.
%  \code{polyroot} returns the \eqn{n-1} complex zeros of \eqn{p(x)}
%  using the Jenkins-Traub algorithm.
%
%  If the coefficient vector \code{z} has zeroes for the highest powers,
%  these are discarded.
%
%  There is no maximum degree, but numerical stability
%  may be an issue for all but low-degree polynomials.
%}
%\value{
%  A complex vector of length \eqn{n - 1}, where \eqn{n} is the position
%  of the largest non-zero element of \code{z}.
%}
%\source{
%  C translation by Ross Ihaka of Fortran code in the reference, with
%  modifications by the R Core Team.
%}
%\references{
%  Jenkins and Traub (1972)
%  TOMS Algorithm 419.
%  \emph{Comm. ACM}, \bold{15}, 97--99.
%}
%\seealso{
%  \code{\link{uniroot}} for numerical root finding of arbitrary
%  functions;
%  \code{\link{complex}} and the \code{zero} example in the demos
%  directory.
%}
%\examples{
%polyroot(c(1, 2, 1))
%round(polyroot(choose(8, 0:8)), 11) # guess what!
%for (n1 in 1:4) print(polyroot(1:n1), digits = 4)
%polyroot(c(1, 2, 1, 0, 0)) # same as the first
%}
%\keyword{math}
%
\encoding{UTF8}
