% File src/library/base/man/rawConversion.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2004-2014 R Core Team
% Distributed under GPL 2 or later

\name{rawConversion}
\alias{charToRaw}
\alias{rawToChar}
\alias{rawShift}
\alias{rawToBits}
\alias{intToBits}
\alias{packBits}
\title{Convert to or from Raw Vectors}
\description{
  型 \code{"raw"} のオブジェクトの変換と操作．
}
\usage{
charToRaw(x)
rawToChar(x, multiple = FALSE)

rawShift(x, n)

rawToBits(x)
intToBits(x)
packBits(x, type = c("raw", "integer"))
}
\arguments{
  \item{x}{変換又はシフトされるオブジェクト．}
  \item{multiple}{論理値：変換は一つの文字列にすべきかそれとも
    複数の個別の文字列にすべきか?}
  \item{n}{シフトするビット数．正の数は右へシフトし負の数は左へ
    シフトする：可能な値は \code{-8 ... 8}．}
  \item{type}{結果の型，部分的にマッチされる．}
}
\value{
  \code{charToRaw} は長さ 1 の文字列をバイト型に変換する．
  変換は宣言されたエンコーディングに無関係に行われる
  (\code{\link{Encoding}} を見よ)．

  \code{rawToChar} は生のバイトを一つの文字列に，
  一つのバイトの文字列に変換する(\code{0} は \code{""} になる)．
  (一つの文字列は埋め込まれた nul を含むことが出来る；
  末尾の nul だけが許されそして取り除かれる．)
  どちらの場合も多バイトロケールで不正な結果をつくりだす可能性がある．
  例えば UTF-8 を使った場合．もし \code{multiple} が真ならロングベクトルが
  許される．

  \code{rawShift(x, n)} は \code{x} 中のビットを \code{n} 位置だけ右へ
  シフトする，上の引数 \code{n} を見よ．

  \code{rawToBits} はバイト型ベクトルの長さの8倍の長さのバイト型ベクトルを
  返し，項目は 0 か 1 である．\code{intToBits} は整数ベクトルの32倍の長さの
  バイト型ベクトルを返し，項目は 0 か 1 である．
  (整数でない数値は整数に切り詰められる．)
  どちらのケースも最も下位のビットが先にアンパックされる．

  \code{packBits} はその入力をパックする(バイト型か整数ベクトルに対しては最下位
  ビットだけ)．バイト型か整数ベクトルに対しては最初に最下位ビットから．
}
\details{
  \code{packBits} はバイト型，整数又は論理値を受け付けるが，
  最後の二つは NA を含んではならない．

#ifdef unix
  \sQuote{バイト}は必ずしも文字と同じではない．例えば UTF-8 ロケール．
#endif
}
\examples{
x <- "A test string"
(y <- charToRaw(x))
is.vector(y) # TRUE

rawToChar(y)
rawToChar(y, multiple = TRUE)
(xx <- c(y,  charToRaw("&"), charToRaw("more")))
rawToChar(xx)

rawShift(y, 1)
rawShift(y, -2)

rawToBits(y)

showBits <- function(r) stats::symnum(as.logical(rawToBits(r)))

z <- as.raw(5)
z ; showBits(z)
showBits(rawShift(z, 1)) # 右へシフト
showBits(rawShift(z, 2))
showBits(z)
showBits(rawShift(z, -1)) # 左へシフト
showBits(rawShift(z, -2)) # ..
showBits(rawShift(z, -3)) # シフトし尽くす
}
\keyword{classes}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/rawConversion.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2004-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rawConversion}
%\alias{charToRaw}
%\alias{rawToChar}
%\alias{rawShift}
%\alias{rawToBits}
%\alias{intToBits}
%\alias{packBits}
%\title{Convert to or from Raw Vectors}
%\description{
%  Conversion and manipulation of  objects of type \code{"raw"}.
%}
%\usage{
%charToRaw(x)
%rawToChar(x, multiple = FALSE)
%
%rawShift(x, n)
%
%rawToBits(x)
%intToBits(x)
%packBits(x, type = c("raw", "integer"))
%}
%\arguments{
%  \item{x}{object to be converted or shifted.}
%  \item{multiple}{logical: should the conversion be to a single
%    character string or multiple individual characters?}
%  \item{n}{the number of bits to shift.  Positive numbers shift right
%    and negative numbers shift left: allowed values are \code{-8 ... 8}.}
%  \item{type}{the result type, partially matched.}
%}
%\value{
%  \code{charToRaw} converts a length-one character string to raw bytes.
%  It does so without taking into account any declared encoding (see
%  \code{\link{Encoding}}).
%
%  \code{rawToChar} converts raw bytes either to a single character
%  string or a character vector of single bytes (with \code{""} for
%  \code{0}).  (Note that a single character string could contain
%  embedded nuls; only trailing nulls are allowed and will be removed.)
%  In either case it is possible to create a result which is invalid in a
%  multibyte locale, e.g.\sspace{}one using UTF-8. \link{Long vectors} are
%  allowed if \code{multiple} is true.
%
%  \code{rawShift(x, n)} shift the bits in \code{x} by \code{n} positions
%  to the right, see the argument \code{n}, above.
%
%  \code{rawToBits} returns a raw vector of 8 times the length of a raw
%  vector with entries 0 or 1.  \code{intToBits} returns a raw vector
%  of 32 times the length of an integer vector with entries 0 or 1.
%  (Non-integral numeric values are truncated to integers.) In
%  both cases the unpacking is least-significant bit first.
%
%  \code{packBits} packs its input (using only the lowest bit for raw or
%  integer vectors) least-significant bit first to a raw or integer vector.
%}
%\details{
%  \code{packBits} accepts raw, integer or logical inputs, the last two
%  without any NAs.
%#ifdef unix
%
%  Note that \sQuote{bytes} are not necessarily the same as characters,
%  e.g.\sspace{}in UTF-8 locales.
%#endif
%}
%\examples{
%x <- "A test string"
%(y <- charToRaw(x))
%is.vector(y) # TRUE
%
%rawToChar(y)
%rawToChar(y, multiple = TRUE)
%(xx <- c(y,  charToRaw("&"), charToRaw("more")))
%rawToChar(xx)
%
%rawShift(y, 1)
%rawShift(y, -2)
%
%rawToBits(y)
%
%showBits <- function(r) stats::symnum(as.logical(rawToBits(r)))
%
%z <- as.raw(5)
%z ; showBits(z)
%showBits(rawShift(z, 1)) # shift to right
%showBits(rawShift(z, 2))
%showBits(z)
%showBits(rawShift(z, -1)) # shift to left
%showBits(rawShift(z, -2)) # ..
%showBits(rawShift(z, -3)) # shifted off entirely
%}
%\keyword{classes}
%
\encoding{UTF8}
