% File src/library/base/man/row.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{row}
\alias{row}
\title{Row Indexes}
\description{
  行列風オブジェクト中のそれらの行番号を指示する整数の行列，
  又は行ラベルを指示する因子を返す．
}
\usage{
row(x, as.factor = FALSE)
}
\arguments{
  \item{x}{行列風オブジェクト，二次元の \code{dim} を持つもの．}
  \item{as.factor}{数ではなく行ラベル(必要なら作られる)の因子として
    値を返すべきかどうかを指示する論理値．}
}
\value{
  \code{x} と同じ次元を持つ整数(又は因子)行列で
  その \code{ij} 番目の要素は \code{i} (又は \code{i} 番目の行ラベル)
  に等しい．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  列を得るには \code{\link{col}}．
}
\examples{
x <- matrix(1:12, 3, 4)
# 行列の対角成分を取り出す
dx <- x[row(x) == col(x)]
dx

# 5 x 5 の単位行列を作る
x <- matrix(0, nrow = 5, ncol = 5)
x[row(x) == col(x)] <- 1
x
}
\keyword{array}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/row.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{row}
%\alias{row}
%\title{Row Indexes}
%\description{
%  Returns a matrix of integers indicating their row number in a
%  matrix-like object, or a factor indicating the row labels.
%}
%\usage{
%row(x, as.factor = FALSE)
%}
%\arguments{
%  \item{x}{a matrix-like object, that is one with a two-dimensional
%    \code{dim}.}
%  \item{as.factor}{a logical value indicating whether the value should
%    be returned as a factor of row labels (created if necessary)
%    rather than as numbers.}
%}
%\value{
%  An integer (or factor) matrix with the same dimensions as \code{x} and whose
%  \code{ij}-th element is equal to \code{i} (or the \code{i}-th row label).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{col}} to get columns.
%}
%\examples{
%x <- matrix(1:12, 3, 4)
%# extract the diagonal of a matrix
%dx <- x[row(x) == col(x)]
%dx
%
%# create an identity 5-by-5 matrix
%x <- matrix(0, nrow = 5, ncol = 5)
%x[row(x) == col(x)] <- 1
%x
%}
%\keyword{array}
%
\encoding{UTF8}
