% File src/library/base/man/seq.Date.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{seq.Date}
\alias{seq.Date}
\title{Generate Regular Sequences of Dates}
\description{
  暦日を表現するクラス \code{"\link{Date}"} のオブジェクトに対する
  \code{\link{seq}} メソッド．
}
\usage{
\method{seq}{Date}(from, to, by, length.out = NULL, along.with = NULL, \dots)
}
\arguments{
  \item{from}{開始日．必須．}
  \item{to}{終了日．オプション．}
  \item{by}{系列の増分．オプション．\sQuote{詳細}を見よ．}
  \item{length.out}{整数，オプション．系列の希望の長さ．}
  \item{along.with}{この引数の長さから長さを取る．}
  \item{\dots}{他のメソッドに・から渡される他引数．}
}
\details{
  \code{by} は幾つかの方法で指定できる．
  \itemize{
    \item 数値，単位は日とされる．
    \item クラス \code{\link{difftime}} のオブジェクト．
    \item 文字列で \code{"day"},
    \code{"week"}, \code{"month"}, \code{"quarter"} 又は \code{"year"}
    のどれか一つ．これはオプションで(正もしくは負の)整数と空白が
    前にあっても良い．又は \code{"s"} が続く．

    \code{"month"} の詳細は \code{\link{seq.POSIXt}} を見よ．
  }
}
\value{
  クラス \code{"Date"} のオブジェクト．
}
\note{
  \R 3.1.0 以前では四半期の増分は \code{by = "3 months"} で指定された．
  
}
\seealso{\code{\link{Date}}}

\examples{
## 一年の最初の日
seq(as.Date("1910/1/1"), as.Date("1999/1/1"), "years")
## 月ごとに
seq(as.Date("2000/1/1"), by = "month", length.out = 12)
## 四半期
seq(as.Date("2000/1/1"), as.Date("2003/1/1"), by = "quarter")

## 二つの日付の間の全ての付きの第7日を見つける，最後は第7日．
st <- as.Date("1998-12-17")
en <- as.Date("2000-1-7")
ll <- seq(en, st, by = "-1 month")
rev(ll[ll > st & ll < en])
}
\keyword{manip}
\keyword{chron}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/seq.Date.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{seq.Date}
%\alias{seq.Date}
%\title{Generate Regular Sequences of Dates}
%\description{
%  The method for \code{\link{seq}} for objects of class class
%  \code{"\link{Date}"} representing calendar dates.
%}
%\usage{
%\method{seq}{Date}(from, to, by, length.out = NULL, along.with = NULL, \dots)
%}
%\arguments{
%  \item{from}{starting date.  Required}
%  \item{to}{end date.  Optional.}
%  \item{by}{increment of the sequence.  Optional.  See \sQuote{Details}.}
%  \item{length.out}{integer, optional.  Desired length of the sequence.}
%  \item{along.with}{take the length from the length of this argument.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\details{
%  \code{by} can be specified in several ways.
%  \itemize{
%    \item A number, taken to be in days.
%    \item A object of class \code{\link{difftime}}
%    \item A character string, containing one of \code{"day"},
%    \code{"week"}, \code{"month"}, \code{"quarter"} or \code{"year"}.
%    This can optionally be preceded by a (positive or negative) integer
%    and a space, or followed by \code{"s"}.
%
%    See \code{\link{seq.POSIXt}} for the details of \code{"month"}.
%  }
%}
%\value{
%  A vector of class \code{"Date"}.
%}
%\note{
%  Quarterly increments were specified by \code{by = "3 months"} prior to
%  \R 3.1.0.
%}
%\seealso{\code{\link{Date}}}
%
%\examples{
%## first days of years
%seq(as.Date("1910/1/1"), as.Date("1999/1/1"), "years")
%## by month
%seq(as.Date("2000/1/1"), by = "month", length.out = 12)
%## quarters
%seq(as.Date("2000/1/1"), as.Date("2003/1/1"), by = "quarter")
%
%## find all 7th of the month between two dates, the last being a 7th.
%st <- as.Date("1998-12-17")
%en <- as.Date("2000-1-7")
%ll <- seq(en, st, by = "-1 month")
%rev(ll[ll > st & ll < en])
%}
%\keyword{manip}
%\keyword{chron}
%
\encoding{UTF8}
