% File src/library/base/man/sort.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{sort}
\alias{sort}
\alias{sort.default}
\alias{sort.POSIXlt}
\alias{sort.int}
\title{Sorting or Ordering Vectors}
\description{
  ベクトルや因子を(部分的に)増加又は減少順にソート(又は\emph{順位}付け)をする．
  一つ以上の変数に沿って順位付けをする，例えばデータフレームのソート，
  には \code{\link{order}} を見よ．
}
\usage{
sort(x, decreasing = FALSE, \dots)

\method{sort}{default}(x, decreasing = FALSE, na.last = NA, \dots)

sort.int(x, partial = NULL, na.last = NA, decreasing = FALSE,
         method = c("shell", "quick"), index.return = FALSE)
}
\arguments{
  \item{x}{\code{sort} に対してはクラスを持つ \R オブジェクトか
    数値，複素数又は論理値．\code{sort.int} に対しては数値，
    複素数，文字列ベクトル，又は因子．}
  \item{decreasing}{論理値．ソートは増加順か減少順か?
     部分ソートでは利用できない．}
  \item{\dots}{メソッドから・へ渡される引数，又は(既定メソッドとクラス無しの
    オブジェクトに対して) \code{sort.int} への引数．}
  \item{na.last}{\code{NA} の扱いを制御する．
    もし \code{TRUE} ならデータ中の欠損値は最後に置かれる；
    もし \code{FALSE} ならそれらは最初に置かれる；
    もし \code{NA} ならそれらは除かれる．}
  \item{partial}{\code{NULL} 又は部分ソートのための添字ベクトル．}
  \item{method}{使用するアルゴリズムを指定する文字列．
    部分ソートに対しては利用できない．短縮できる．}
  \item{index.return}{順序付けの添字もまた返すべきかを指示する論理値；
    これは僅かなケース，既定の \code{na.last = NA} と非因子の完全ソート，
    だけで使える．}
}
\details{
  \code{sort} は総称的でありメソッドを書くことが出来る．
  そして \code{sort.int} はもし最初の三つの引数が使われると
  S と互換性がある内部メソッドである．

  既定の \code{sort} メソッドはクラス付きオブジェクトに対して \code{\link{order}}
  を使い，これは更に総称的関数 \code{\link{xtfrm}} を使う
  (そして \code{xtfrm} メソッドが定義されていないか
  \code{\link{is.numeric}(x)} が真でなければ遅い可能性)．

  複素数は先ず実部に関して，次に虚部についてソートされる．

  文字列ベクトルのソート順序は使用中のロケールの照合列に依存する：
  \code{\link{Comparison}} を見よ．
  因子に対するソート順序はそれらの水準の順序である(これらは
  特に順序付き因子に対して適切である)．


  もし \code{partial} が \code{NULL} で無ければ，部分ソートによりソートされた
  配列中のそれらの正しい位置に置かれる結果の要素の添字を含むとされる．
  特定の位置における結果の値の各々に対して，
  それより小さな任意の値はソートされた配列中でより小さな値を持つことが
  保証され，より大きな任意の値はソートされた配列中でより大きな値を持つことが
  保証される．(これは効率性のために含められ，そしてオプションの
  多くは部分ソートに対しては利用できない．
  これは \code{partial} が一握りの要素を持つ時だけ
  本質的により効率的であり，そして完全なソートは
  10 以上ある時行われる(もし可能ならクイックソート))．
  名前は部分ソートでは捨て去られる．

  メソッド \code{"shell"} はシェルソートを使う(Sedgewick (1986) からの
  \eqn{O(n^{4/3})} の変種を使う)．もし \code{x} が名前を持てば安定な修正が
  使われるので，タイは再順序化されない．
  (これは名前がある時だけ関係する．)

  メソッド \code{"quick"} は Singleton (1969) の
  Hoare のクイックソートメソッドの実装を使い，
  \code{x} が数値(倍精度又は整数) で \code{partial} が \code{NULL}
  の時だけ利用できる．(\code{x} の他の型に対してはシェルソートが
  黙って使われる．) これは普通シェルソートより若干速い
  (恐らく百万の長さのベクトルでは 50\% 速く，千万では倍早い)が
  稀な最悪ケースでは貧弱な性能を持つ．(Peto の擬似乱数の中点を使う
  修正が最悪ケースをより稀にするために使われる．)  これは安定なソートではなく，
  タイは再順序化されるかもしれない．

  100,000 水準以下の因子は \code{method} が提供されない時 radix で
  ソートされる：\code{\link{sort.list}} を見よ．
}

\value{
  \code{sort} に対しては結果は選択適用される S3 メソッドに依存する．
  もし \code{x} がクラスを持たなければ \code{sort.int} が使用され，その
  説明が適用される．市営されたメソッドを持たないクラス付きオブジェクト
  に対しては既定メソッドが使われ，\code{x[order(x, ...)]} と等しくなる：
  これは \code{[} に対する適当なメソッドを持つクラスに依存する
  (そしてまた \code{\link{order}} が作用するものに依存し，これは
  リストに基づくクラスに対しては該当しない)．

  \code{sort.int} に対しては値はソートされたベクトルである．
  例外は \code{index.return} が真の時で，結果は
  ソートされた数値と順序付ける添字ベクトルを含む
  \code{x} と \code{ix} という名前の成分を持つリストである．
  後者の場合，もし \code{method == "quick"} ならばクイックソートは
  安定ではないので，(\code{sort.list} とは異なり)タイは順序付けで保存される．
  NB：添字ベクトルは\emph{\code{NA} を除いた後の}要素番号を参照する：
  もし元々の要素番号が欲しければ \code{\link{order}} を見よ．

  全ての属性は名前を除き返り値からは取り除かれる
  (Becker \emph{et al}, 1988, p.146 を見よ)，名前はソートされている．
  (もし \code{partial} が指定されていると名前すら取り除かれる．)
  これは返り値が因子と順序付き因子を除き如何なるクラスも持たないことを
  意味する(これらのクラスは特別に処理され，その結果は元々のクラスに変換し戻される)．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Knuth, D. E. (1998)
  \emph{The Art of Computer Programming, Volume 3: Sorting and
    Searching.} 2nd ed. Addison-Wesley.
  
  Sedgewick, R. (1986)
  A new upper bound for Shell sort.
  \emph{J. Algorithms} \bold{7}, 159--173.

  Singleton, R. C. (1969)  An efficient algorithm for sorting with
  minimal storage: Algorithm 347.
  \emph{Communications of the ACM} \bold{12}, 185--187.
}
\seealso{
  文字列がどのように並べられるかについては \sQuote{\link{Comparison}}．

  複数の変数のソートや再順位付けについては \code{\link{order}}．

  \code{\link{is.unsorted}}. \code{\link{rank}}.
}
\examples{
require(stats)

x <- swiss$Education[1:25]
x; sort(x); sort(x, partial = c(10, 15))

## '安定な' ソーティング(タイの)：
sort(c(10:3, 2:12), method = "sh", index.return = TRUE) # 安定している
## $x : 2  3  3  4  4  5  5  6  6  7  7  8  8  9  9 10 10 11 12
## $ix: 9  8 10  7 11  6 12  5 13  4 14  3 15  2 16  1 17 18 19
sort(c(10:3, 2:12), method = "qu", index.return = TRUE) # ではない
## $x : 2  3  3  4  4  5  5  6  6  7  7  8  8  9  9 10 10 11 12
## $ix: 9 10  8  7 11  6 12  5 13  4 14  3 15 16  2 17  1 18 19

x <- c(1:3, 3:5, 10)
is.unsorted(x)                  # FALSE: ソートされている
is.unsorted(x, strictly = TRUE) # TRUE : ではない(そしてあり得ない)
                                # 厳密にソートされている
\dontrun{
## ささやかな速度の比較実験：
N <- 2000
Sim <- 20
rep <- 1000 # << 自分の CPU に合わせる
c1 <- c2 <- numeric(Sim)
for(is in seq_len(Sim)){
  x <- rnorm(N)
  c1[is] <- system.time(for(i in 1:rep) sort(x, method = "shell"))[1]
  c2[is] <- system.time(for(i in 1:rep) sort(x, method = "quick"))[1]
  stopifnot(sort(x, method = "s") == sort(x, method = "q"))
}
rbind(ShellSort = c1, QuickSort = c2)
cat("Speedup factor of quick sort():\n")
summary({qq <- c1 / c2; qq[is.finite(qq)]})

## より大きなセット
x <- rnorm(1e7)
system.time(x1 <- sort(x, method = "shell"))
system.time(x2 <- sort(x, method = "quick"))
stopifnot(identical(x1, x2))
}}
\keyword{univar}
\keyword{manip}
\keyword{arith}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sort.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sort}
%\alias{sort}
%\alias{sort.default}
%\alias{sort.POSIXlt}
%\alias{sort.int}
%\title{Sorting or Ordering Vectors}
%\description{
%  Sort (or \emph{order}) a vector or factor (partially) into
%  ascending or descending order.  For ordering along more than one
%  variable, e.g., for sorting data frames, see \code{\link{order}}.
%}
%\usage{
%sort(x, decreasing = FALSE, \dots)
%
%\method{sort}{default}(x, decreasing = FALSE, na.last = NA, \dots)
%
%sort.int(x, partial = NULL, na.last = NA, decreasing = FALSE,
%         method = c("shell", "quick"), index.return = FALSE)
%}
%\arguments{
%  \item{x}{for \code{sort} an \R object with a class or a numeric,
%    complex, character or logical vector.  For \code{sort.int}, a
%    numeric, complex, character or logical vector, or a factor.}
%  \item{decreasing}{logical.  Should the sort be increasing or decreasing?
%     Not available for partial sorting.}
%  \item{\dots}{arguments to be passed to or from methods or (for the
%    default methods and objects without a class) to \code{sort.int}.}
%  \item{na.last}{for controlling the treatment of \code{NA}s.
%    If \code{TRUE}, missing values in the data are put last; if
%    \code{FALSE}, they are put first; if \code{NA}, they are removed.}
%  \item{partial}{\code{NULL} or a  vector of indices for partial sorting.}
%  \item{method}{character string specifying the algorithm used.  Not
%    available for partial sorting.  Can be abbreviated.}
%  \item{index.return}{logical indicating if the ordering index vector should
%    be returned as well; this is only available for a few cases, the default
%    \code{na.last = NA} and full sorting of non-factors.}
%}
%\details{
%  \code{sort} is a generic function for which methods can be written,
%  and \code{sort.int} is the internal method which is compatible
%  with S if only the first three arguments are used.
%
%  The default \code{sort} method makes use of \code{\link{order}} for
%  classed objects, which in turn makes use of the generic function
%  \code{\link{xtfrm}} (and can be slow unless a \code{xtfrm} method has
%  been defined or \code{\link{is.numeric}(x)} is true).
%
%  Complex values are sorted first by the real part, then the imaginary
%  part.
%
%  The sort order for character vectors will depend on the collating
%  sequence of the locale in use: see \code{\link{Comparison}}.
%  The sort order for factors is the order of their levels (which is
%  particularly appropriate for ordered factors).
%
%
%  If \code{partial} is not \code{NULL}, it is taken to contain indices
%  of elements of the result which are to be placed in their correct
%  positions in the sorted array by partial sorting.  For each of the
%  result values in a specified position, any values smaller than that
%  one are guaranteed to have a smaller index in the sorted array and any
%  values which are greater are guaranteed to have a bigger index in the
%  sorted array.  (This is included for efficiency, and many of the
%  options are not available for partial sorting.  It is only
%  substantially more efficient if \code{partial} has a handful of
%  elements, and a full sort is done (a Quicksort if possible) if there
%  are more than 10.)  Names are discarded for partial sorting.
%
%  Method \code{"shell"} uses Shellsort (an \eqn{O(n^{4/3})} variant from
%  Sedgewick (1986)).  If \code{x} has names a stable modification is
%  used, so ties are not reordered.  (This only matters if names are
%  present.)
%
%  Method \code{"quick"} uses Singleton (1969)'s implementation of
%  Hoare's Quicksort method and is only available when \code{x} is
%  numeric (double or integer) and \code{partial} is \code{NULL}.  (For
%  other types of \code{x} Shellsort is used, silently.)  It is normally
%  somewhat faster than Shellsort (perhaps 50\% faster on vectors of
%  length a million and twice as fast at a billion) but has poor
%  performance in the rare worst case.  (Peto's modification using a
%  pseudo-random midpoint is used to make the worst case rarer.)  This is
%  not a stable sort, and ties may be reordered.
%
%  Factors with less than 100,000 levels are sorted by radix sorting when
%  \code{method} is not supplied: see \code{\link{sort.list}}.
%}
%
%\value{
%  For \code{sort}, the result depends on the S3 method which is
%  dispatched.  If \code{x} does not have a class \code{sort.int} is used
%  and it description applies.  For classed objects which do not have a
%  specific method the default method will be used and is equivalent to
%  \code{x[order(x, ...)]}: this depends on the class having a suitable
%  method for \code{[} (and also that \code{\link{order}} will work,
%  which is not the case for a class based on a list).
%
%  For \code{sort.int} the value is the sorted vector unless
%  \code{index.return} is true, when the result is a list with components
%  named \code{x} and \code{ix} containing the sorted numbers and the
%  ordering index vector.  In the latter case, if \code{method ==
%    "quick"} ties may be reversed in the ordering (unlike
%  \code{sort.list}) as quicksort is not stable.  NB: the index vector
%  refers to element numbers \emph{after removal of \code{NA}s}: see
%  \code{\link{order}} if you want the original element numbers.
%
%  All attributes are removed from the return value (see Becker \emph{et
%    al}, 1988, p.146) except names, which are sorted.  (If
%  \code{partial} is specified even the names are removed.)  Note that
%  this means that the returned value has no class, except for factors
%  and ordered factors (which are treated specially and whose result is
%  transformed back to the original class).
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Knuth, D. E. (1998)
%  \emph{The Art of Computer Programming, Volume 3: Sorting and
%    Searching.} 2nd ed. Addison-Wesley.
%  
%  Sedgewick, R. (1986)
%  A new upper bound for Shell sort.
%  \emph{J. Algorithms} \bold{7}, 159--173.
%
%  Singleton, R. C. (1969)  An efficient algorithm for sorting with
%  minimal storage: Algorithm 347.
%  \emph{Communications of the ACM} \bold{12}, 185--187.
%}
%\seealso{
%  \sQuote{\link{Comparison}} for how character strings are collated.
%
%  \code{\link{order}} for sorting on or reordering multiple variables.
%
%  \code{\link{is.unsorted}}. \code{\link{rank}}.
%}
%\examples{
%require(stats)
%
%x <- swiss$Education[1:25]
%x; sort(x); sort(x, partial = c(10, 15))
%
%## illustrate 'stable' sorting (of ties):
%sort(c(10:3, 2:12), method = "sh", index.return = TRUE) # is stable
%## $x : 2  3  3  4  4  5  5  6  6  7  7  8  8  9  9 10 10 11 12
%## $ix: 9  8 10  7 11  6 12  5 13  4 14  3 15  2 16  1 17 18 19
%sort(c(10:3, 2:12), method = "qu", index.return = TRUE) # is not
%## $x : 2  3  3  4  4  5  5  6  6  7  7  8  8  9  9 10 10 11 12
%## $ix: 9 10  8  7 11  6 12  5 13  4 14  3 15 16  2 17  1 18 19
%
%x <- c(1:3, 3:5, 10)
%is.unsorted(x)                  # FALSE: is sorted
%is.unsorted(x, strictly = TRUE) # TRUE : is not (and cannot be)
%                                # sorted strictly
%\dontrun{
%## Small speed comparison simulation:
%N <- 2000
%Sim <- 20
%rep <- 1000 # << adjust to your CPU
%c1 <- c2 <- numeric(Sim)
%for(is in seq_len(Sim)){
%  x <- rnorm(N)
%  c1[is] <- system.time(for(i in 1:rep) sort(x, method = "shell"))[1]
%  c2[is] <- system.time(for(i in 1:rep) sort(x, method = "quick"))[1]
%  stopifnot(sort(x, method = "s") == sort(x, method = "q"))
%}
%rbind(ShellSort = c1, QuickSort = c2)
%cat("Speedup factor of quick sort():\n")
%summary({qq <- c1 / c2; qq[is.finite(qq)]})
%
%## A larger test
%x <- rnorm(1e7)
%system.time(x1 <- sort(x, method = "shell"))
%system.time(x2 <- sort(x, method = "quick"))
%stopifnot(identical(x1, x2))
%}}
%\keyword{univar}
%\keyword{manip}
%\keyword{arith}
%
\encoding{UTF8}
