% File src/library/base/man/subset.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{subset}
\alias{subset}
\alias{subset.default}
\alias{subset.matrix}
\alias{subset.data.frame}
\title{Subsetting Vectors, Matrices and Data Frames}
\description{
  条件を満たす部分集合をベクトル，行列，又はデータフレームから返す．
}
\usage{
subset(x, \dots)

\method{subset}{default}(x, subset, \dots)

\method{subset}{matrix}(x, subset, select, drop = FALSE, \dots)

\method{subset}{data.frame}(x, subset, select, drop = FALSE, \dots)
}
\arguments{
  \item{x}{部分操作されるオブジェクト．}
  \item{subset}{保存される要素や行を指示する論理値表現式；
    欠損値は偽とされる．}
  \item{select}{表現式，データフレームから選択される列を指示する．}
  \item{drop}{\code{[} 添字操作演算子に渡される．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．}
}
\details{
  これは総称的関数で，行列，データフレーム(リストを含む)そしてベクトルに対する
  メソッドを持つ．パッケージやユーザは追加のメソッドを加えることが出来る．

  通常のベクトルに対しては結果は単に
  \code{x[subset & !is.na(subset)]} である．

  データフレームに対しては \code{subset} 引数は行に働く．
  \code{subset} はデータフレーム中で評価されるので，列は
  表現式中の変数(名前を使う)として参照されることを注意する．

  \code{select} 引数はデータフレームと行列メソッドに対してだけ存在する．
  これは最初選択表現式中の列名を対応するデータフレームに置き換え，
  それから結果の整数ベクトルを列の添字として使う．
  これは標準の添字慣習の使用を許すので，例えば
  列の範囲を容易に指定したり一つの列を捨てたり出来る
  (例を見よ)．

  \code{drop} 引数は行列とデータフレームに対する添字操作メソッドに
  渡される：行列に対する既定動作は添字操作と異なることを注意する．

  因子は部分操作の後では空の水準を持つかもしれない；
  未使用の水準は自動的には取り除かれない．
  データフレームから未使用の水準を全て取り去るには \code{\link{droplevels}}
  を見よ．
}
\value{
  \code{x} と類似のオブジェクトで選択された要素(ベクトルに対して)，
  行と列(行列とデータフレームに対して)を含む，等．
}
\section{警告}{
  これは対話的に使われることを意図した利便関数である．
  プログラミングに対しては \code{\link{[}} のような標準の部分操作関数を
  使うほうが好ましく，そして特に非標準的な評価がされる引数 \code{subset} が
  予見できぬ結論を招く可能性がある．
}
\author{Peter Dalgaard and Brian Ripley}
\seealso{
  \code{\link{[}}, % = ./Extract.Rd
  \code{\link{transform}},
  \code{\link{droplevels}}
}
\examples{
subset(airquality, Temp > 80, select = c(Ozone, Temp))
subset(airquality, Day == 1, select = -Temp)
subset(airquality, select = Ozone:Wind)

with(airquality, subset(Ozone, Temp > 80))

## 時折り論理値の 'subset' 引数の必要性は面倒である
nm <- rownames(state.x77)
start_with_M <- nm \%in\% grep("^M", nm, value = TRUE)
subset(state.x77, start_with_M, Illiteracy:Murder)
# 最近のバージョンの R ではこれは単に
subset(state.x77, grepl("^M", nm), Illiteracy:Murder)
}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/subset.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{subset}
%\alias{subset}
%\alias{subset.default}
%\alias{subset.matrix}
%\alias{subset.data.frame}
%\title{Subsetting Vectors, Matrices and Data Frames}
%\description{
%  Return subsets of vectors, matrices or data frames which meet conditions.
%}
%\usage{
%subset(x, \dots)
%
%\method{subset}{default}(x, subset, \dots)
%
%\method{subset}{matrix}(x, subset, select, drop = FALSE, \dots)
%
%\method{subset}{data.frame}(x, subset, select, drop = FALSE, \dots)
%}
%\arguments{
%  \item{x}{object to be subsetted.}
%  \item{subset}{logical expression indicating elements or rows to keep:
%    missing values are taken as false.}
%  \item{select}{expression, indicating columns to select from a
%    data frame.}
%  \item{drop}{passed on to \code{[} indexing operator.}
%  \item{\dots}{further arguments to be passed to or from other methods.}
%}
%\details{
%  This is a generic function, with methods supplied for matrices, data
%  frames and vectors (including lists).  Packages and users can add
%  further methods.
%
%  For ordinary vectors, the result is simply
%  \code{x[subset & !is.na(subset)]}.
%
%  For data frames, the \code{subset} argument works on the rows.  Note
%  that \code{subset} will be evaluated in the data frame, so columns can
%  be referred to (by name) as variables in the expression (see the examples).
%
%  The \code{select} argument exists only for the methods for data frames
%  and matrices.  It works by first replacing column names in the
%  selection expression with the corresponding column numbers in the data
%  frame and then using the resulting integer vector to index the
%  columns.  This allows the use of the standard indexing conventions so
%  that for example ranges of columns can be specified easily, or single
%  columns can be dropped (see the examples).
%
%  The \code{drop} argument is passed on to the indexing method for
%  matrices and data frames: note that the default for matrices is
%  different from that for indexing.
%
%  Factors may have empty levels after subsetting; unused levels are
%  not automatically removed.  See \code{\link{droplevels}} for a way to
%  drop all unused levels from a data frame.
%
%}
%\value{
%  An object similar to \code{x} contain just the selected elements (for
%  a vector), rows and columns (for a matrix or data frame), and so on.
%}
%\section{Warning}{
%  This is a convenience function intended for use interactively.  For
%  programming it is better to use the standard subsetting functions like
%  \code{\link{[}}, and in particular the non-standard evaluation of
%  argument \code{subset} can have unanticipated consequences.
%}
%\author{Peter Dalgaard and Brian Ripley}
%\seealso{
%  \code{\link{[}}, % = ./Extract.Rd
%  \code{\link{transform}}
%  \code{\link{droplevels}}
%}
%\examples{
%subset(airquality, Temp > 80, select = c(Ozone, Temp))
%subset(airquality, Day == 1, select = -Temp)
%subset(airquality, select = Ozone:Wind)
%
%with(airquality, subset(Ozone, Temp > 80))
%
%## sometimes requiring a logical 'subset' argument is a nuisance
%nm <- rownames(state.x77)
%start_with_M <- nm \%in\% grep("^M", nm, value = TRUE)
%subset(state.x77, start_with_M, Illiteracy:Murder)
%# but in recent versions of R this can simply be
%subset(state.x77, grepl("^M", nm), Illiteracy:Murder)
%}
%\keyword{manip}
%
\encoding{UTF8}
