% File src/library/base/man/which.min.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{which.min}
\alias{which.min}
\alias{which.max}
\title{Where is the Min() or Max() or first TRUE or FALSE ?}
\concept{argmin}
\concept{argmax}
\concept{index of minimum}
\concept{index of maximum}
\concept{index of first TRUE}
\concept{index of first FALSE}
\description{
  数値(又は論理値)ベクトルの(最初の)最小値と最大値の位置，つまり添字を
  決定する．
}
\usage{
which.min(x)
which.max(x)
}
\arguments{
  \item{x}{数値(論理値，整数又は倍精度実数)ベクトル，
    又は \code{\link{double}} への内部的強制変換が動作する \R オブジェクト
    で，その \code{\link{min}} や \code{\link{max}} が探される．}
}
\note{
  \code{FALSE} と \code{TRUE} 値を持つ論理値ベクトル \code{x} に対しては
  \code{FALSE < TRUE} であるため \code{which.min(x)} と \code{which.max(x)}
  はそれぞれ最初の \code{FALSE} 又は \code{TRUE} の添字を返す．
}
\value{
  欠損値と \code{NaN} 値は捨て去られる．

  整数．64 ビットプラットフォームでもし
  \code{\link{length}(x) =: n}\eqn{\ge 2^{31}}{>= 2^31} ならば
  長さ 1 か 0 の整数である倍精度値(\code{x} が \code{NA} でない値を持てば)で，
  それぞれ \code{x} の\emph{最初}の最小値か最大値を与える．

  もし極値がユニーク(又は空)なら，結果はそれぞれ
  \code{which(x == min(x, na.rm = TRUE))} か
  \code{which(x == max(x, na.rm = TRUE))} である
  (しかしより効率的)． 
}
\author{Martin Maechler}
\seealso{
  \code{\link{which}}, \code{\link{max.col}}, \code{\link{max}}, 等．

  もし1次元ベクトルの代わりに配列/行列が必要なら \code{\link{arrayInd}()} を使う．

  \CRANpkg{nnet} パッケージ中の \code{\link[nnet]{which.is.max}} は
  タイを無作為に解消する点で異なる(そしてタイの定義に\sQuote{曖昧さ}を許す)．
}
\examples{
x <- c(1:4, 0:5, 11)
which.min(x)
which.max(x)

## NA があると動作しない，それらを捨て去る：
presidents[1:30]
range(presidents, na.rm = TRUE)
which.min(presidents) # 28
which.max(presidents) #  2


## 最初に起きたものを見つける，つまりもし少なくとも一つあれば最初の TRUE：
x <- rpois(10000, lambda = 10); x[sample.int(50, 20)] <- NA
## where is the first value >= 20 ?
which.max(x >= 20)

## リストにも使える(数値ベクトルに強制変換される)：
which.min(list(A = 7, pi = pi)) ##  ->  c(pi = 2L)
\dontshow{stopifnot(identical(which.min(list(A = 7, pi = pi)), c(pi = 2L)))}
}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/which.min.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{which.min}
%\alias{which.min}
%\alias{which.max}
%\title{Where is the Min() or Max() or first TRUE or FALSE ?}
%\concept{argmin}
%\concept{argmax}
%\concept{index of minimum}
%\concept{index of maximum}
%\concept{index of first TRUE}
%\concept{index of first FALSE}
%\description{
%  Determines the location, i.e., index of the (first) minimum or maximum
%  of a numeric (or logical) vector.
%}
%\usage{
%which.min(x)
%which.max(x)
%}
%\arguments{
%  \item{x}{numeric (logical, integer or double) vector or an \R object
%    for which the internal coercion to \code{\link{double}} works whose
%    \code{\link{min}} or \code{\link{max}} is searched for.}
%}
%\note{
%  For a \code{\link{logical}} vector \code{x} with both \code{FALSE} and
%  \code{TRUE} values, \code{which.min(x)} and \code{which.max(x)} return
%  the index of the first \code{FALSE} or \code{TRUE}, respectively, as
%  \code{FALSE < TRUE}.
%}
%\value{
%  Missing and \code{NaN} values are discarded.
%
%  an \code{\link{integer}} or on 64-bit platforms, if
%  \code{\link{length}(x) =: n}\eqn{\ge 2^{31}}{>= 2^31} an integer
%  valued \code{\link{double}} of length 1 or 0 (iff \code{x} has no
%  non-\code{NA}s), giving the index of the \emph{first} minimum or
%  maximum respectively of \code{x}.
%
%  If this extremum is unique (or empty), the results are the same as
%  (but more efficient than) \code{which(x == min(x, na.rm = TRUE))} or
%  \code{which(x == max(x, na.rm = TRUE))} respectively.
%}
%\author{Martin Maechler}
%\seealso{
%  \code{\link{which}}, \code{\link{max.col}}, \code{\link{max}}, etc.
%
%  Use \code{\link{arrayInd}()}, if you need array/matrix indices instead
%  of 1D vector ones.
%
%  \code{\link[nnet]{which.is.max}} in package \CRANpkg{nnet} differs in
%  breaking ties at random (and having a \sQuote{fuzz} in the definition
%  of ties).
%}
%\examples{
%x <- c(1:4, 0:5, 11)
%which.min(x)
%which.max(x)
%
%## it *does* work with NA's present, by discarding them:
%presidents[1:30]
%range(presidents, na.rm = TRUE)
%which.min(presidents) # 28
%which.max(presidents) #  2
%
%## Find the first occurrence, i.e. the first TRUE, if there is at least one:
%x <- rpois(10000, lambda = 10); x[sample.int(50, 20)] <- NA
%## where is the first value >= 20 ?
%which.max(x >= 20)
%
%## Also works for lists (which can be coerced to numeric vectors):
%which.min(list(A = 7, pi = pi)) ##  ->  c(pi = 2L)
%\dontshow{stopifnot(identical(which.min(list(A = 7, pi = pi)), c(pi = 2L)))}
%}
%\keyword{utilities}
%\encoding{UTF8}

\encoding{UTF8}

