% File src/library/base/man/zpackages.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{zpackages}
\title{Listing of Packages}
\alias{.packages}
\description{
  \code{.packages} はパッケージの利用可能性の情報を返す．
}
\usage{
.packages(all.available = FALSE, lib.loc = NULL)
}
\arguments{
  \item{all.available}{論理値；もし \code{TRUE} なら \code{lib.loc}
    中の全ての利用可能なパッケージの文字列ベクトルを返す．}
  \item{lib.loc}{探査がなされる \R のライブラリツリーの位置を記述する
    文字列ベクトル，又は \code{NULL}．既定値の \code{NULL} は
    \code{\link{.libPaths}()} に対応する．}
}
\details{
  \code{.packages()} は現在付加されているパッケージの名前を
  \emph{不可視}で返す一方，\cr
  \code{.packages(all.available = TRUE)} は
  ライブラリ位置のパス \code{lib.loc} 中で利用可能な\emph{全ての}
  パッケージを(可視で)返す．

  \sQuote{利用可能}と見做されるパッケージは適正なメタデータ
  (従ってインストール済みパッケージ)を持たなければならない．
  しかしながらこれはもしネタデータがディレクトリ名に一致しないと
  パッケージが利用可能と報告する：
  メタデータがマッチするかどうかを確認するには \code{\link{find.package}}
  を使うか，より遅いがより徹底的な\sQuote{利用可能}なパッケージの
  チェックには \code{\link{installed.packages}} を使う．
}
\note{
  \code{.packages(all.available = TRUE)} は少数のパッケージが
  利用可能かどうかを見つける方法ではない：
  数千のパッケージがインストールされていれば手間がかかるだけではなく，
  不完全なテストでもある．なぜ \code{\link{require}} を使うべきかについては
  \code{\link{find.package}} に対するヘルプを見よ．
}
\value{
  パッケージの基本名の文字列ベクトルで，
  \code{all.available = TRUE} で無い限り不可視．
}
\author{
  R core；
  \code{.packages} の \code{all.available = TRUE} 部分は Guido Masarotto．
}
\seealso{
  \code{\link{library}}, \code{\link{.libPaths}},
  \code{\link{installed.packages}}.
}
\examples{
(.packages())               # "base" だけかもしれない
.packages(all.available = TRUE) # 利用可能なもの全てを文字列で返す
require(splines)
(.packages())               # "splines" も
detach("package:splines")
}
\keyword{data}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/zpackages.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{zpackages}
%\title{Listing of Packages}
%\alias{.packages}
%\description{
%  \code{.packages} returns information about package availability.
%}
%\usage{
%.packages(all.available = FALSE, lib.loc = NULL)
%}
%\arguments{
%  \item{all.available}{logical; if \code{TRUE} return a character vector
%    of all available packages in \code{lib.loc}.}
%  \item{lib.loc}{a character vector describing the location of \R
%    library trees to search through, or \code{NULL}.  The default value
%    of \code{NULL} corresponds to \code{\link{.libPaths}()}.}
%}
%\details{
%  \code{.packages()} returns the names of the currently
%  attached packages \emph{invisibly} whereas
%  \code{.packages(all.available = TRUE)} gives (visibly) \emph{all}
%  packages available in the library location path \code{lib.loc}.
%
%  For a package to be regarded as being \sQuote{available} it must have valid
%  metadata (and hence be an installed package).  However, this will
%  report a package as available if the metadata does not match the
%  directory name: use \code{\link{find.package}} to confirm that the
%  metadata match or \code{\link{installed.packages}} for a much slower
%  but more comprehensive check of \sQuote{available} packages.
%}
%\note{
%   \code{.packages(all.available = TRUE)} is not a way to find out if a
%  small number of packages are available for use: not only is it
%  expensive when thousands of packages are installed, it is an
%  incomplete test.  See the help for \code{\link{find.package}} for why
%  \code{\link{require}} should be used.
%}
%\value{
%  A character vector of package base names, invisible unless
%  \code{all.available = TRUE}.
%}
%\author{
%  R core;
%  Guido Masarotto for the \code{all.available = TRUE} part of
%  \code{.packages}.
%}
%\seealso{
%  \code{\link{library}}, \code{\link{.libPaths}},
%  \code{\link{installed.packages}}.
%}
%\examples{
%(.packages())               # maybe just "base"
%.packages(all.available = TRUE) # return all available as character vector
%require(splines)
%(.packages())               # "splines", too
%detach("package:splines")
%}
%\keyword{data}
%\encoding{UTF8}

\encoding{UTF8}

