% File src/library/graphics/man/axis.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{axis}
\alias{axis}
\title{Add an Axis to a Plot}
\description{現在のプロットに軸を加える．
  側面，位置，ラベル，そしてその他のオプションの指定が許される．
}
\usage{
axis(side, at = NULL, labels = TRUE, tick = TRUE, line = NA,
     pos = NA, outer = FALSE, font = NA, lty = "solid",
     lwd = 1, lwd.ticks = lwd, col = NULL, col.ticks = NULL,
     hadj = NA, padj = NA, \dots)
}
\arguments{
  \item{side}{プロットのどの側に軸を描くかを指定する整数．
    軸は次のように置かれる：1=下側，2=左側，3=上側，そして 4=右側．}
  \item{at}{チックマークを描く点．非有限値
    (無限，\code{NaN} 又は \code{NA})は除かれる．既定では
    (\code{NULL} の時)チックマーク位置は計算される，下の
    \sQuote{詳細}を見よ．}
  \item{labels}{これは(数値)注釈をチックマークにするかどうかを
    指定する論理値か，チック点に置かれるラベルの文字列ベクトルか
    表現式ベクトルのどちらかである．
    (他のオブジェクトは \code{\link{as.graphicsAnnot}} で
    強制変換される．)
    もしこれが論理値でなければ，\code{at} がまた提供されるべきで
    同じ長さでなければならない．もし \code{labels} が変換後に長さがゼロ
    ならば，それは \code{TRUE} を提供するのと同じ効果を持つ．}
  \item{tick}{チックマークと軸線を描くべきかを指定する論理値．}
  \item{line}{もし \code{NA} で無ければ，軸線がそこに引かれる余白の線の数．}
  \item{pos}{軸線が描かれる座標：
    \code{NA} でなkればこれは \code{line} の値を上書きする．}
  \item{outer}{標準的なプロットマージンの代わりに，軸をプロットマージンの
    外側に描かれるべきかどうかを指示する論理値．}
  \item{font}{テキスト用のフォント．既定は \code{par("font")}．}
  \item{lty}{軸とチックマーク双方に対する線種．}
  \item{lwd, lwd.ticks}{軸線とチックマーク用の線幅．
    ゼロや負の値は線やチックを抑制する．}
  \item{col, col.ticks}{それぞれ軸線とチックマークに対する色．
    \code{col = NULL} は \code{par("fg")} の使用を意味し，
    インラインで指定されているかもしれない．そして
    \code{col.ticks = NULL} は \code{col} が決定するどんな色も
    使うことを意味する．}
  \item{hadj}{読み取る方向に対して\emph{平行}(\sQuote{水平})
    な全てのラベルに対する補正(\code{\link{par}("adj")} を見よ)．
    もしこれが有限な値でなければ，既定値が使われる(軸に対して平行な
    文字列に対してはセンタリングし，さもなければ
    軸に最も近い端で揃える)．}
  \item{padj}{読み取る方向に\emph{垂直}な各チックマークに対する補正．
    軸に平行なラベルに対しては \code{padj = 0} は
    右又は上揃えを，\code{padj = 1} は左又は下揃えを意味する．
    これは各文字列に対する値のベクトルであってよく，必要なら
    リサイクルされる．

    もし \code{padj} が有限な値(既定)なら，
    \code{par("las")} の値が補正を決定する．
    軸に垂直にプロットされる文字列に対しては既定は文字列の
    センタリングである．}

  \item{\dots}{他のグラフィックパラメータを又
    この関数に渡すことが出来る．
    特に軸注釈に対する \code{cex.axis}, \code{col.axis} そして \code{font.axis}，
    位置決めに対する \code{mgp} と \code{xaxp} 又は \code{yaxp}，
    チックマークの長さと方向に対する \code{tck} 又は \code{tcl}，
    垂直/水平のラベル方向に対する \code{las}，又は \code{col} の代わりの \code{fg}，
    そしてクリッピングに対する \code{xpd}．これらについては \code{\link{par}} を見よ．

    パラメータ \code{xaxt} (側面 1 と 3) と \code{yaxt} (側面 2 と
    4)は軸をそもそも描くかどうかを制御する．

    後者がまた提供されていない限り \code{lab} は引数 \code{labels} に
    部分マッチする．(既定の軸は \code{\link{plot.window}} により既に
    設定されているので，\code{lab} は \code{axis} により決定されない．)}
}
\value{
  プロットが最初に描かれる時(\sQuote{詳細}を見よ)，チックマークが
  そこに描かれる軸スケールでの数値位置．

  この関数は普通，既存のプロットに軸を加えるという
  その副作用のために起動される，
}  
\details{
  軸線は \code{at} の最低から最高の値まで描かれるが，
  プロット領域でクリップされる．既定では，(丸め誤差の許容度の範囲内で)
  プロット領域内の点から描かれたチックだけがプロットされるが，
  チックやそれらのラベルはプロット領域の外部にはみ出しているかもしれない．
  \code{xpd = TRUE} や \code{xpd = NA} の使用は軸を更に延長する
  ことを許す．

  \code{at = NULL} の時，見栄えの良いチックマーク位置は
  内部的に(\code{\link{axTicks}(side)} がするように)
  \code{\link{par}("xaxp")} 又は \code{"yaxp"} と
  \code{\link{par}("xlog")} (もしくは \code{"ylog"}) から計算される．
  これらの位置はスクリーン上のプロットがリサイズされると変化するかもしれないことを
  注意しよう(例えば，もし \code{plot} の引数 \code{asp}
  (\code{\link{plot.window}} を見よ)が設定された時)．

  もし \code{labels} が指定されないと，提供されたり \code{at} から計算された数値
  があたかも\cr
  \code{\link{print.default}(digits = 7)} でプリントされた
  数値ベクトルであるかのように文字列に変換される．

  コードはチックラベルが重ならないように努力するので，
  既に書かれたラベルに寄りかかったり重なるラベルは除かれる．
  これは，例えば，他の全てのチックがラベルを持つ結果になる．
  (チックは左から右へ，又は下から上へ描かれ，
  少なくとも \sQuote{m} のスペースがラベル間に残される．)

  もし \code{line} か \code{pos} が設定されていると，それらは
  (\code{par("mgp")[3]} ではなく)軸行やチックの位置を決定する．
  そしてチックラベルは更に \code{par("mgp")[2]} 行マージン中
  (\code{pos} に対しては又はマージン方向)に置かれる．

  グラフィックパラメータの幾つかは軸が描かれる仕方に影響を与える．
  軸の垂直(側面 1 と 3)位置とチックラベルは \code{mgp[2:3]} と
  \code{mex} で制御され，チックのサイズと方向は
  \code{tck} と \code{tcl} で制御され，
  チックラベルの見かけは \code{cex.axis} で，
  \code{col.axis} と方向を持つ \code{font.axis} は \code{las}
  で制御される(しかし \code{srt} は違う，これは \code{at} が与えられれば
  \code{srt} さもなければ \code{las} を使う S とは異なる)．
  \code{adj} はサポートされずラベルは中心化されることを注意しよう．
  詳細は \code{\link{par}} を見よ．
}
\seealso{
  包括的なインタフェイスについては \code{\link{Axis}}．

  \code{\link{axTicks}} は \code{at = NULL} に対応する軸チック位置を返す；
  \code{\link{pretty}} は見栄えの良いチック座標の計算のために
  より柔軟である．そして使用中の座標システムに依存
  (それどころか適応も)していない．

  外見に影響する幾つかのグラフィックパラメータのドキュメントが
  \code{\link{par}} にある．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
require(stats) # rnorm のため
plot(1:4, rnorm(4), axes = FALSE)
axis(1, 1:4, LETTERS[1:4])
axis(2)
box() #- それを"普通のように"するため

plot(1:7, rnorm(7), main = "axis() examples",
     type = "s", xaxt = "n", frame = FALSE, col = "red")
axis(1, 1:7, LETTERS[1:7], col.axis = "blue")
# unusual options:
axis(4, col = "violet", col.axis = "dark violet", lwd = 2)
axis(3, col = "gold", lty = 2, lwd = 0.5)

# 独自の x 軸を持つ一つの方法
plot(1:10, xaxt = "n")
axis(1, xaxp = c(2, 9, 7))
}
\keyword{aplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/axis.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{axis}
%\alias{axis}
%\title{Add an Axis to a Plot}
%\description{Adds an axis to the current plot, allowing the
%  specification of the side, position, labels, and other options.
%}
%\usage{
%axis(side, at = NULL, labels = TRUE, tick = TRUE, line = NA,
%     pos = NA, outer = FALSE, font = NA, lty = "solid",
%     lwd = 1, lwd.ticks = lwd, col = NULL, col.ticks = NULL,
%     hadj = NA, padj = NA, \dots)
%}
%\arguments{
%  \item{side}{an integer specifying which side of the plot the axis is
%    to be drawn on.  The axis is placed as follows: 1=below,
%    2=left, 3=above and 4=right.}
%  \item{at}{the points at which tick-marks are to be drawn.  Non-finite
%    (infinite, \code{NaN} or \code{NA}) values are omitted.  By default
%    (when \code{NULL}) tickmark locations are computed, see
%    \sQuote{Details} below.}
%  \item{labels}{this can either be a logical value specifying whether
%    (numerical) annotations are to be made at the tickmarks, or a
%    character or expression vector of labels to be placed at the
%    tickpoints.  (Other objects are coerced by \code{\link{as.graphicsAnnot}}.)
%    If this is not logical, \code{at} should also be supplied and of the
%    same length.  If \code{labels} is of length zero after coercion,
%    it has the same effect as supplying \code{TRUE}.}
%  \item{tick}{a logical value specifying whether tickmarks and an axis line
%    should be drawn.}
%  \item{line}{the number of lines into the margin at which the axis line
%    will be drawn, if not \code{NA}.}
%  \item{pos}{the coordinate at which the axis line is to be drawn:
%    if not \code{NA} this overrides the value of \code{line}.}
%  \item{outer}{a logical value indicating whether the axis should be
%    drawn in the outer plot margin, rather than the standard plot
%    margin.}
%  \item{font}{font for text.  Defaults to \code{par("font")}.}
%  \item{lty}{line type for both the axis line and the tick marks.}
%  \item{lwd, lwd.ticks}{line widths for the axis line and the tick
%    marks. Zero or negative values will suppress the line or ticks.}
%  \item{col, col.ticks}{colors for the axis line and the tick marks
%    respectively.  \code{col = NULL} means to use \code{par("fg")},
%    possibly specified inline, and \code{col.ticks = NULL} means to use
%    whatever color \code{col} resolved to.}
%  \item{hadj}{adjustment (see \code{\link{par}("adj")}) for all labels
%    \emph{parallel} (\sQuote{horizontal}) to the reading direction.  If
%    this is not a finite value, the default is used (centring for
%    strings parallel to the axis, justification of the end nearest the
%    axis otherwise).}
%  \item{padj}{adjustment for each tick label \emph{perpendicular} to the
%    reading direction.  For labels parallel to the axes, \code{padj = 0}
%    means right or top alignment, and \code{padj = 1} means left or bottom
%    alignment.  This can be a vector given a value for each string, and
%    will be recycled as necessary.
%
%    If \code{padj} is not a finite value (the default), the value of
%    \code{par("las")} determines the adjustment.  For strings plotted
%    perpendicular to the axis the default is to centre the string.}
%
%  \item{\dots}{other \link{graphical parameters} may also be passed as
%    arguments to this function, particularly, \code{cex.axis},
%    \code{col.axis} and \code{font.axis} for axis annotation, \code{mgp}
%    and \code{xaxp} or \code{yaxp} for positioning, \code{tck} or
%    \code{tcl} for tick mark length and direction, \code{las} for
%    vertical/horizontal label orientation, or \code{fg} instead of
%    \code{col}, and \code{xpd} for clipping.  See \code{\link{par}} on these.
%
%    Parameters \code{xaxt} (sides 1 and 3) and \code{yaxt} (sides 2 and
%    4) control if the axis is plotted at all.
%
%    Note that \code{lab} will partial match to argument
%    \code{labels} unless the latter is also supplied.  (Since the
%    default axes have already been set up by \code{\link{plot.window}},
%    \code{lab} will not be acted on by \code{axis}.)}
%}
%\value{
%  The numeric locations on the axis scale at which tick marks were drawn
%  when the plot was first drawn (see \sQuote{Details}).
%
%  This function is usually invoked for its side effect, which is to add
%  an axis to an already existing plot.
%}
%\details{
%  The axis line is drawn from the lowest to the highest value of
%  \code{at}, but will be clipped at the plot region.  By default, only
%  ticks which are drawn from points within the plot region (up to a
%  tolerance for rounding error) are plotted, but the ticks and their
%  labels may well extend outside the plot region.  Use \code{xpd = TRUE}
%  or \code{xpd = NA} to allow axes to extend further.
%
%  When \code{at = NULL}, pretty tick mark locations are computed internally
%  (the same way \code{\link{axTicks}(side)} would) from
%  \code{\link{par}("xaxp")} or \code{"yaxp"} and
%  \code{\link{par}("xlog")} (or \code{"ylog"}).  Note that these
%  locations may change if an on-screen plot is resized (for example, if
%  the \code{plot} argument \code{asp} (see \code{\link{plot.window}}) is set.)
%
%  If \code{labels} is not specified, the numeric values supplied or
%  calculated for \code{at} are converted to character strings as if they
%  were a numeric vector printed by \code{\link{print.default}(digits = 7)}.
%
%  The code tries hard not to draw overlapping tick labels, and so will
%  omit labels where they would abut or overlap previously drawn labels.
%  This can result in, for example, every other tick being labelled.
%  (The ticks are drawn left to right or bottom to top, and space at
%  least the size of an \sQuote{m} is left between labels.)
%
%  If either \code{line} or \code{pos} is set, they (rather than
%  \code{par("mgp")[3]}) determine the position of the axis line and tick
%  marks, and the tick labels are placed \code{par("mgp")[2]} further
%  lines into (or towards for \code{pos}) the margin.
%
%  Several of the graphics parameters affect the way axes are drawn. The
%  vertical (for sides 1 and 3) positions of the axis and the tick labels
%  are controlled by \code{mgp[2:3]} and \code{mex}, the size and
%  direction of the ticks is controlled by \code{tck} and \code{tcl} and
%  the appearance of the tick labels by \code{cex.axis}, \code{col.axis}
%  and \code{font.axis} with orientation controlled by \code{las} (but
%  not \code{srt}, unlike S which uses \code{srt} if \code{at} is
%  supplied and \code{las} if it is not).  Note that \code{adj} is not
%  supported and labels are always centered.  See \code{\link{par}} for details.
%}
%\seealso{
%  \code{\link{Axis}} for a generic interface.
%
%  \code{\link{axTicks}} returns the axis tick locations
%  corresponding to \code{at = NULL}; \code{\link{pretty}} is more flexible
%  for computing pretty tick coordinates and does \emph{not} depend on
%  (nor adapt to) the coordinate system in use.
%
%  Several graphics parameters affecting the appearance are documented
%  in \code{\link{par}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%require(stats) # for rnorm
%plot(1:4, rnorm(4), axes = FALSE)
%axis(1, 1:4, LETTERS[1:4])
%axis(2)
%box() #- to make it look "as usual"
%
%plot(1:7, rnorm(7), main = "axis() examples",
%     type = "s", xaxt = "n", frame = FALSE, col = "red")
%axis(1, 1:7, LETTERS[1:7], col.axis = "blue")
%# unusual options:
%axis(4, col = "violet", col.axis = "dark violet", lwd = 2)
%axis(3, col = "gold", lty = 2, lwd = 0.5)
%
%# one way to have a custom x axis
%plot(1:10, xaxt = "n")
%axis(1, xaxp = c(2, 9, 7))
%}
%\keyword{aplot}
%
\encoding{UTF8}
