% File src/library/graphics/man/identify.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{identify}
\alias{identify}
\alias{identify.default}
\title{Identify Points in a Scatter Plot}
\encoding{UTF8}
\usage{
identify(x, \dots)

\method{identify}{default}(x, y = NULL, labels = seq_along(x), pos = FALSE,
         n = length(x), plot = TRUE, atpen = FALSE, offset = 0.5,
         tolerance = 0.25, \dots)
}
\arguments{
  \item{x, y}{散布図中の点の座標．
    又は座標を定めるオブジェクト(プロット用構造，時系列等：
    \code{\link{xy.coords}} を見よ)を \code{x} として与え
    \code{y} は無くて良い．}
  \item{labels}{点に対するラベルを与えるオプションの文字列ベクトル．
    \code{\link{as.character}} により強制変換され，
    必要なら \code{x} の長さまでリサイクルされる．
    余計なラベルは警告と共に捨て去られる．}
  \item{pos}{もし \code{pos} が \code{TRUE} ならば，テキストを各特定された
    点に関してどこにプロットするかを指示する成分が返り値に
    付け加えられる：値を見よ．}
  \item{n}{特定される点の最大数．}
  \item{plot}{論理値：もし \code{plot} が \code{TRUE} ならば，
    ラベルは点の近くにプリントされ，もし \code{FALSE} なら
    それらは省略される．}
  \item{atpen}{論理値：もし \code{TRUE} で \code{plot = TRUE} ならば，
    ラベルの下左隅が点に関してではなくクリックされた点位置にプロットされる．}
  \item{offset}{特定された点とラベルを分離する距離(文字列幅単位)．
    負の値が許される．
    もし \code{atpen = TRUE} ならば使われない．}
  \item{tolerance}{ポインタが点に\sQuote{十分近い}とされる
    最大距離(インチ単位)．}
  \item{\dots}{\code{cex}, \code{col} や \code{font} のような
    \code{\link{par}} への追加引数．}
}
\description{
  \code{identify} は(最初の)マウスボタンが押された時，
  グラフィックスポインタの位置を読み取る．
  それからポインタに最も
  近い点に対する \code{x} と \code{y} で与えられた座標を探す．
  もしこの点がポインタに十分近ければその添字が呼び出しの値の一部として
  返される．
}
\details{
  \code{identify} は総称的関数であり，既定メソッドだけがここで
  解説される．

  \code{identify} は \code{X11}, \code{windows} そして \code{quartz}
  のようなスクリーンデバイスに対してだけサポートされている．
  他のデバイス上では呼び出しは何もしない．

  点の近く(\code{tolerance} で定義される)でクリックするとそれを
  特定された店のリストに付け加える．
  点は一回だけ特定でき，もし点が既に特定されているか，
  クリックがどの点にも近く無ければ，メッセージが即座に \R
  コンソールにプリントされる．

  もし \code{plot} が \code{TRUE} ならば，点は \code{labels}
  中の対応する要素でラベルを付けられる．
  もし \code{atpen} が偽ならば(既定値)，ポインターが点に関して
  どこにあるかに応じて，ラベルは特定された
  点の下側，左側，上側そして右側に置かれる．
  もし \code{atpen} が真なら，ラベルはポインターの文字列ボックスの
  下左側に置かれる．

#ifdef unix
  通例の \code{\link{X11}} デバイスに対しては，特定のプロセスは
  最初以外の任意のマウスボタンをクリックすれば停止する．
  \code{\link{quartz}} デバイスに対しては，プロセスは
  同値なポップアップメニュー(普通二番目のマウスボタンか
  \code{Ctrl} のクリック)又は \code{ESC} キーで停止する．
#endif
#ifdef windows
  特定プロセスは二番目のボタンをクリックし
  メニューから \sQuote{Stop} を選ぶか，又はグラフィックスウィンド上の
  メニューから \sQuote{Stop} を選べば停止する．
#endif

  \code{identify} をサポートする殆どのデバイスでは，
  \code{\link{options}(locatorBell = FALSE)} が設定されていない限り
  点の選択の成功はベル音で指示される．

  もし特定のプロセスが終了する前に，ウィンドがサイズ変更や隠蔽され
  そして再表示されると，\code{identify} により描かれた任意のラベルは
  消え去る．
  これらは特定プロセスが終了しウィンドがサイズ変更や隠蔽され
  再表示されれば再び登場する．
  これは 
  \code{identify} で描かれたラベルは特定プロセスが停止されるまでは
  デバイスディスプレイに記録されないからである．

  もし \code{identify} の呼び出しを中断すれば，これはグラフィックスデバイスを
  未定義の状態に置き去りにし，点はラベルを付けられるがラベルは
  ディスプレイリストに記録されない．
  そうした状態にあるデバイスのコピー
#ifdef windows
  (例えばウィンドメニューからプロットを保存する)
#endif
  は予測できない結果を与える．
}
\value{
  もし \code{pos} が \code{FALSE} ならば，特定された点の
  添字を含む整数ベクトルで，特定された順に並ぶ．

  もし \code{pos} が \code{TRUE} ならば，
  どの点が特定されたかどうかを指示する成分 
  \code{ind} と， 特定された点に関してラベルがどこに
  置かれたか(1=下，2=左，3=上，4=右，そして 0=オフセット無しで，
  \code{atpen = TRUE} の時使われる)を指示する成分 \code{pos} を
  持つリスト．
}
\section{技術的事項}{
  もし \code{pos} がそこで指定されていれば，ラベルを置くための
  アルゴリズムは \code{text} で使われるものと同じであり，
  違いは特定された点に関するポインタの位置が
  \code{identify} 中の \code{pos} を決定することである．

  点の左に置かれるラベルに対しては，
  文字列ボックスの右端は点の \code{offset} 単位左に置かれる．
  点の右に対しても同様である．
  テキストのベースラインは文字列が垂直方向に近似的に
  中央になるように点の下に置かれる．
  点の上や下に置かれるラベルに対しては，
  文字列は点について水平方向にセンタリングされる．
  上に置かれたラベルに対しては，テキストのベースラインは
  \code{offset} 単位だけ点の上とされ，そして
  下に置かれたものに対してはベースラインは文字列ボックスの
  上部が近似的に \code{offset} 単位だけ点の下になるように
  置かれる．

  もしより正確な位置決め(例えばセンタリング)が必要なら
  \code{plot = FALSE} を使い \code{\link{text}} や
  \code{\link{points}} を用いてプロットする：
  例を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{locator}}, \code{\link{text}}.

  サポートされているかどうか見るには \code{\link{dev.capabilities}}．
}
\examples{
## 点を選ぶため identify を使う関数，そして選ばれた点を
## 別のシンボルで上書きする
identifyPch <- function(x, y = NULL, n = length(x), pch = 19, ...)
{
    xy <- xy.coords(x, y); x <- xy$x; y <- xy$y
    sel <- rep(FALSE, length(x)); res <- integer(0)
    while(sum(sel) < n) {
        ans <- identify(x[!sel], y[!sel], n = 1, plot = FALSE, ...)
        if(!length(ans)) break
        ans <- which(!sel)[ans]
        points(x[ans], y[ans], pch = pch)
        sel[ans] <- TRUE
        res <- c(res, ans)
    }
    res
}
}
\keyword{iplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/identify.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{identify}
%\alias{identify}
%\alias{identify.default}
%\title{Identify Points in a Scatter Plot}
%\usage{
%identify(x, \dots)
%
%\method{identify}{default}(x, y = NULL, labels = seq_along(x), pos = FALSE,
%         n = length(x), plot = TRUE, atpen = FALSE, offset = 0.5,
%         tolerance = 0.25, \dots)
%}
%\arguments{
%  \item{x, y}{coordinates of points in a scatter plot.  Alternatively, any
%    object which defines coordinates (a plotting structure, time
%    series etc: see \code{\link{xy.coords}}) can be given as \code{x},
%    and \code{y} left missing.}
%  \item{labels}{an optional character vector giving labels for the
%    points.  Will be coerced using \code{\link{as.character}}, and
%    recycled if necessary to the length of \code{x}.  Excess labels will
%    be discarded, with a warning.}
%  \item{pos}{if \code{pos} is \code{TRUE}, a component is added to the
%    return value which indicates where text was plotted relative to each
%    identified point: see Value.}
%  \item{n}{the maximum number of points to be identified.}
%  \item{plot}{logical: if \code{plot} is \code{TRUE}, the labels are
%    printed near the points and if \code{FALSE} they are omitted.}
%  \item{atpen}{logical: if \code{TRUE} and \code{plot = TRUE}, the
%    lower-left corners of the labels are plotted at the points clicked
%    rather than relative to the points.}
%  \item{offset}{the distance (in character widths) which separates the
%    label from identified points.  Negative values are allowed.  Not
%    used if \code{atpen = TRUE}.}
%  \item{tolerance}{the maximal distance (in inches) for the pointer to be
%    \sQuote{close enough} to a point.}
%  \item{\dots}{further arguments passed to \code{\link{par}} such as
%    \code{cex}, \code{col} and \code{font}.}
%}
%\description{
%  \code{identify} reads the position of the graphics pointer when the
%  (first) mouse button is pressed.  It then searches the coordinates
%  given in \code{x} and \code{y} for the point closest to the pointer.
%  If this point is close enough to the pointer, its index will be returned as
%  part of the value of the call.
%}
%\details{
%  \code{identify} is a generic function, and only the default method is
%  described here.
%
%  \code{identify} is only supported on screen devices such as
%  \code{X11}, \code{windows} and \code{quartz}.  On other devices the
%  call will do nothing.
%
%  Clicking near (as defined by \code{tolerance}) a point adds it to the
%  list of identified points.  Points can be identified only once, and if
%  the point has already been identified or the click is not
%  near any of the points a message is printed immediately on
%  the \R console.
%
%  If \code{plot} is \code{TRUE}, the point is labelled with the
%  corresponding element of \code{labels}.  If \code{atpen} is false (the
%  default) the labels are placed below, to the left, above or to the
%  right of the identified point, depending on where the pointer was
%  relative to the point.  If \code{atpen} is true, the
%  labels are placed with the bottom left of the string's box at the
%  pointer.
%
%#ifdef unix
%  For the usual \code{\link{X11}} device the identification process is
%  terminated by pressing any mouse button other than the first.
%  For the \code{\link{quartz}} device the process is terminated by
%  pressing either the pop-up menu equivalent (usually second mouse
%  button or \code{Ctrl}-click) or the \code{ESC} key.
%#endif
%#ifdef windows
%  The identification process is terminated by clicking the second button
%  and selecting \sQuote{Stop} from the menu, or from the \sQuote{Stop}
%  menu on the graphics window.
%#endif
%
%  On most devices which support \code{identify}, successful selection of
%  a point is indicated by a bell sound unless
%  \code{\link{options}(locatorBell = FALSE)} has been set.
%
%  If the window is resized or hidden and then exposed before the identification
%  process has terminated, any labels drawn by \code{identify}
%  will disappear.  These will reappear once the identification process has
%  terminated and the window is resized or hidden and exposed again.
%  This is because the labels drawn by \code{identify} are not
%  recorded in the device's display list until the identification process has
%  terminated.
%
%  If you interrupt the \code{identify} call this leaves the graphics
%  device in an undefined state, with points labelled but labels not
%  recorded in the display list.  Copying a device in that state
%#ifdef windows
%  (e.g., saving the plot from the window's menu)
%#endif
%  will give unpredictable results.
%}
%\value{
%  If \code{pos} is \code{FALSE}, an integer vector containing the
%  indices of the identified points, in the order they were identified.
%
%  If \code{pos} is \code{TRUE}, a list containing a component
%  \code{ind}, indicating which points were identified and a component
%  \code{pos}, indicating where the labels were placed relative to the
%  identified points (1=below, 2=left, 3=above, 4=right and 0=no offset,
%  used if \code{atpen = TRUE}).
%}
%\section{Technicalities}{
%  The algorithm used for placing labels is the same as used by
%  \code{text} if \code{pos} is specified there, the difference being
%  that the position of the pointer relative the identified point
%  determines \code{pos} in \code{identify}.
%
%  For labels placed to the left of a point, the right-hand edge of the
%  string's box is placed \code{offset} units to the left of the point,
%  and analogously for points to the right.  The baseline of the text is
%  placed below the point so as to approximately centre string vertically.
%  For labels placed above or below a point, the string is centered
%  horizontally on the point.  For labels placed above, the baseline of
%  the text is placed \code{offset} units above the point, and
%  for those placed below, the baseline is placed so that the top
%  of the string's box is approximately \code{offset} units below the
%  point.  If you want more precise placement (e.g., centering) use
%  \code{plot = FALSE} and plot via \code{\link{text}} or
%  \code{\link{points}}: see the examples.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{locator}}, \code{\link{text}}.
%
%  \code{\link{dev.capabilities}} to see if it is supported.
%}
%\examples{
%## A function to use identify to select points, and overplot the
%## points with another symbol as they are selected
%identifyPch <- function(x, y = NULL, n = length(x), pch = 19, ...)
%{
%    xy <- xy.coords(x, y); x <- xy$x; y <- xy$y
%    sel <- rep(FALSE, length(x)); res <- integer(0)
%    while(sum(sel) < n) {
%        ans <- identify(x[!sel], y[!sel], n = 1, plot = FALSE, ...)
%        if(!length(ans)) break
%        ans <- which(!sel)[ans]
%        points(x[ans], y[ans], pch = pch)
%        sel[ans] <- TRUE
%        res <- c(res, ans)
%    }
%    res
%}
%}
%\keyword{iplot}
%

