% File src/library/graphics/man/legend.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{legend}
\alias{legend}
\title{Add Legends to Plots}
\usage{
legend(x, y = NULL, legend, fill = NULL, col = par("col"),
       border = "black", lty, lwd, pch,
       angle = 45, density = NULL, bty = "o", bg = par("bg"),
       box.lwd = par("lwd"), box.lty = par("lty"), box.col = par("fg"),
       pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
       xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1,
       adj = c(0, 0.5), text.width = NULL, text.col = par("col"),
       text.font = NULL, merge = do.lines && has.pch, trace = FALSE,
       plot = TRUE, ncol = 1, horiz = FALSE, title = NULL,
       inset = 0, xpd, title.col = text.col, title.adj = 0.5,
       seg.len = 2)
}
\description{
  この関数はプロットに凡例を加えるのに使うことが出来る．
  関数 \code{\link{locator}(1)} の呼び出しが
  \code{x} と \code{y} 引数の代わりに使えることを注意する．
}
\arguments{
  \item{x, y}{凡例位置に使われる x と y 座標．
    これらはキーワードか \code{\link{xy.coords}} が受け入れる
    任意の方法で指定できる：
    \sQuote{詳細}を見よ．}
  \item{legend}{凡例に現れる長さ \eqn{\ge 1} の文字列又は
    表現式のベクトル．他のオブジェクトは \code{\link{as.graphicsAnnot}}
    により強制変換される．}
  \item{fill}{もし指定されると，この引数は
    指定された色で埋めた(又は指定色で陰影を付ける)箱が
    凡例テキストの横に現れるようにする．}
  \item{col}{凡例に現れる点や線の色．}
  \item{border}{箱の輪郭色(\code{fill} が指定された時だけ使われる)．}
  \item{lty, lwd}{凡例中に現れる先のタイプと幅．
    線を描くにはこれらの二つの一つが指定されなければならない．}
  \item{pch}{凡例中に現れるプロット用シンボルで，
    数値ベクトルか一文字のベクトル
    (\code{\link{points}} を見よ)．\code{points} とは異なり，
    これは全て単一の多文字の文字列が可能である．
    specified as a single multi-character string.
    シンボルを描くためには指定されることが\emph{必要}である．}
  \item{angle}{陰影線の角度．}
  \item{density}{もし数値で正ならば陰影線の密度．
    もし \code{NULL} か負か \code{NA} ならば色で塗られると仮定される．}
  \item{bty}{凡例の周囲に描かれる箱のタイプ．
    可能な値は \code{"o"} (既定)と \code{"n"}．}
  \item{bg}{凡例ボックスの背景色．(これは \code{bty != "n"} の時だけ
    使われる．)}
  \item{box.lty, box.lwd, box.col}{凡例ボックスの線種，幅そして色
    (もし \code{bty = "o"} ならば)．}
  \item{pt.bg}{\code{\link{points}} に対する背景色で
    引数 \code{bg} に対応する．}
  \item{cex}{現在の \code{par("cex")} に\bold{相対的}な文字拡大率．
    テキストに使われ，\code{pt.cex} と \code{title.cex} に対する
    既定値を提供する．}
  \item{pt.cex}{点の拡大因子．}
  \item{pt.lwd}{点に対する線幅で，線に対しては既定値は 1 で，
    もしそれが未設定ならば \code{par("lwd")}．}
  \item{xjust}{凡例の x 位置に関して凡例をどのようにジャスティファイするか．
    値 0 は左揃え，0.5 は中心化，そして 1 は右揃えを意味する．}
  \item{yjust}{凡例の y 位置に対して \code{xjust} と同じ．}
  \item{x.intersp}{水平 (x) 方向のスペーシングのための文字間の
    スペースの因子．}
  \item{y.intersp}{垂直 (y) 方向の線間隔に対する同様のもの．}
  \item{adj}{長さ 1 か 2 の数値；凡例テキストに対する文字列補正．
    \code{labels} が \link{plotmath} 表現式の時 y 補正に役に立つ．}
  \item{text.width}{x (\code{"user"}) 座標での凡例テキストの幅．
    (反転された x 軸に対しても正である必要がある．)
    既定値は \code{\link{strwidth}(legend)} で計算された適正な値．}
  \item{text.col}{凡例のテキストに対する色．}
  \item{text.font}{凡例のテキストに使われるフォント，\code{\link{text}} を見よ．}
  \item{merge}{論理値；もし \code{TRUE} ならば点と線をマージするが
    箱を産めない．もし点と線があれば既定値は \code{TRUE}．}
  \item{trace}{論理値：もし \code{TRUE} ならば \code{legend} が全ての
    その魔法的な計算を行うかを示す．}
  \item{plot}{論理値．もし \code{FALSE} ならば何もプロットされずサイズが
    返される．}
  \item{ncol}{凡例の項目をその中に設定する列の数(既定は 1 で垂直な凡例)．}
  \item{horiz}{論理値；もし \code{TRUE} なら凡例を垂直でなく水平に
    設定する(\code{horiz} の指定は \code{ncol} の指定を上書きする)．}
  \item{title}{凡例のトップに置かれるタイトルを与える
    文字列か長さ 1 の表現式．他のオブジェクトは
    \code{\link{as.graphicsAnnot}} で強制変換される．}
  \item{inset}{凡例がキーワードで置かれる時の
    プロット領域の割合としてのマージンからの挿入距離．}
  \item{xpd}{もし提供されると，凡例が描かれる間に使われる
    グラフィカルパラメータ \code{xpd}．}
  \item{title.col}{\code{title} に対する色．}
  \item{title.adj}{\code{title} に対する水平補正：
    \code{\link{par}("adj")} に対するヘルプを見よ．}
  \item{seg.len}{\code{lty} と/又は \code{lwd} を装飾するために引かれる線の
    長さ(文字幅単位)．}
}
\details{
  引数 \code{x}, \code{y}, \code{legend} は座標が一つ又は二つの引数で
  指定されることを許すように非標準的な仕方で解釈される．
  もし \code{legend} が欠損し \code{y} が数値でなければ，
  二番目の引数が \code{legend} で最初の引数は座標を指定するとされる．

  座標は \code{\link{xy.coords}} が受け入れる任意の仕方で指定できる．
  もしこれが一つの点の座標を与えれば，それは凡例を含む矩形の上左隅の
  座標として使われる．もしそれが二つの点の座標を与えれば，それらは
  矩形の対立する隅を指定する(どちらかの隅の対と任意の順序)．

  位置は又 \code{x} をリスト
  \code{"bottomright"}, \code{"bottom"},
  \code{"bottomleft"}, \code{"left"}, \code{"topleft"},
  \code{"top"}, \code{"topright"}, \code{"right"} そしてand
  \code{"center"} のキーワードの一つに設定することで指定できる．
  これは凡例をプロットフレームの内部の指定された位置に置く．
  部分引数マッチングが使われる．
  オプションの引数 \code{inset} は凡例がプロットマージンからどれだけ
  離れて挿入されるかを指定する．
  もし単一の値が与えられれば，それは両方のマージンに使われる；
  もし二つの値が与えられると，最初は \code{x} 距離に，
  二つ目は \code{y} 距離に使われる．

  \code{col}, \code{pch}, \code{lty} 等の属性引数は
  必要ならリサイクルされる：\code{merge} はされない．
  \code{lty} の項目を \code{0} に設定するか，
  \code{lwd} を \code{NA} に設定すれば，
  対応する凡例の項目中の線を抑制する；
  点を抑制するには \code{pch} 値を \code{NA} に設定する．

  点は，もし適用可能ならば，それらが背景色 \code{pt.bg} を持つ
  線をカバーするように線の\emph{後に}描かれる．

  右揃えのラベルの作り方は例を見よ．

  Unicode code point では使われないために，値 \code{-31:-1} は
  黙って無視される．
}
\value{
  次のリスト成分を持つリストで
  \item{rect}{リストで次の成分を持つ
    \describe{
      \item{\code{w}, \code{h}}{凡例ボックスの幅と高さ．}
      \item{\code{left}, \code{top}}{箱の上左隅の x と y 座標．}
    }
  }
  \item{text}{リストで次の成分を持つ
    \describe{
      \item{\code{x, y}}{
      長さ \code{length(legend)} の数値ベクトルで，凡例のテキストの x と y 座標を与える．}
    }
  }
  不可視で返される．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  \code{legend()} を使う \code{\link{plot}}, \code{\link{barplot}}，
  そして数学表現のより多くの例は \code{\link{text}}．
}
\examples{
## '?matplot' 中の例や以下を実行せよ：
leg.txt <- c("Setosa     Petals", "Setosa     Sepals",
             "Versicolor Petals", "Versicolor Sepals")
y.leg <- c(4.5, 3, 2.1, 1.4, .7)
cexv  <- c(1.2, 1, 4/5, 2/3, 1/2)
matplot(c(1, 8), c(0, 4.5), type = "n", xlab = "Length", ylab = "Width",
        main = "Petal and Sepal Dimensions in Iris Blossoms")
for (i in seq(cexv)) {
  text  (1, y.leg[i] - 0.1, paste("cex=", formatC(cexv[i])), cex = 0.8, adj = 0)
  legend(3, y.leg[i], leg.txt, pch = "sSvV", col = c(1, 3), cex = cexv[i])
}

## 線と点をマージするには 'merge = TRUE'：
x <- seq(-pi, pi, len = 65)
plot(x, sin(x), type = "l", ylim = c(-1.2, 1.8), col = 3, lty = 2)
points(x, cos(x), pch = 3, col = 4)
lines(x, tan(x), type = "b", lty = 1, pch = 4, col = 6)
title("legend(..., lty = c(2, -1, 1), pch = c(NA, 3, 4), merge = TRUE)",
      cex.main = 1.1)
legend(-1, 1.9, c("sin", "cos", "tan"), col = c(3, 4, 6),
       text.col = "green4", lty = c(2, -1, 1), pch = c(NA, 3, 4),
       merge = TRUE, bg = "gray90")

## ラベルのセットを右揃え：Uwe Ligges に感謝
x <- 1:5; y1 <- 1/x; y2 <- 2/x
plot(rep(x, 2), c(y1, y2), type = "n", xlab = "x", ylab = "y")
lines(x, y1); lines(x, y2, lty = 2)
temp <- legend("topright", legend = c(" ", " "),
               text.width = strwidth("1,000,000"),
               lty = 1:2, xjust = 1, yjust = 1,
               title = "Line Types")
text(temp$rect$left + temp$rect$w, temp$text$y,
     c("1,000", "1,000,000"), pos = 2)


##--- 対数スケールの例 ------------------------------
leg.txt <- c("a one", "a two")

par(mfrow = c(2, 2))
for(ll in c("","x","y","xy")) {
  plot(2:10, log = ll, main = paste0("log = '", ll, "'"))
  abline(1, 1)
  lines(2:3, 3:4, col = 2)
  points(2, 2, col = 3)
  rect(2, 3, 3, 2, col = 4)
  text(c(3,3), 2:3, c("rect(2,3,3,2, col=4)",
                      "text(c(3,3),2:3,\"c(rect(...)\")"), adj = c(0, 0.3))
  legend(list(x = 2,y = 8), legend = leg.txt, col = 2:3, pch = 1:2,
         lty = 1, merge = TRUE)   #, trace = TRUE)
}
par(mfrow = c(1,1))

##-- 数学表現：  ------------------------------
x <- seq(-pi, pi, len = 65)
plot(x, sin(x), type = "l", col = 2, xlab = expression(phi),
     ylab = expression(f(phi)))
abline(h = -1:1, v = pi/2*(-6:6), col = "gray90")
lines(x, cos(x), col = 3, lty = 2)
ex.cs1 <- expression(plain(sin) * phi,  paste("cos", phi))  # 2 ways
utils::str(legend(-3, .9, ex.cs1, lty = 1:2, plot = FALSE,
           adj = c(0, 0.6)))  # adj y !
legend(-3, 0.9, ex.cs1, lty = 1:2, col = 2:3,  adj = c(0, 0.6))

require(stats)
x <- rexp(100, rate = .5)
hist(x, main = "Mean and Median of a Skewed Distribution")
abline(v = mean(x),   col = 2, lty = 2, lwd = 2)
abline(v = median(x), col = 3, lty = 3, lwd = 2)
ex12 <- expression(bar(x) == sum(over(x[i], n), i == 1, n),
                   hat(x) == median(x[i], i == 1, n))
utils::str(legend(4.1, 30, ex12, col = 2:3, lty = 2:3, lwd = 2))

## '塗りつぶし' た箱 -- より多くは example(plot.factor) を見よ
op <- par(bg = "white") # 凡例のために透明な箱を得るため
plot(cut(weight, 3) ~ group, data = PlantGrowth, col = NULL,
     density = 16*(1:3))
par(op)

## 'ncol' を使う：
x <- 0:64/64
matplot(x, outer(x, 1:7, function(x, k) sin(k * pi * x)),
        type = "o", col = 1:7, ylim = c(-1, 1.5), pch = "*")
op <- par(bg = "antiquewhite1")
legend(0, 1.5, paste("sin(", 1:7, "pi * x)"), col = 1:7, lty = 1:7,
       pch = "*", ncol = 4, cex = 0.8)
legend(.8,1.2, paste("sin(", 1:7, "pi * x)"), col = 1:7, lty = 1:7,
       pch = "*", cex = 0.8)
legend(0, -.1, paste("sin(", 1:4, "pi * x)"), col = 1:4, lty = 1:4,
       ncol = 2, cex = 0.8)
legend(0, -.4, paste("sin(", 5:7, "pi * x)"), col = 4:6,  pch = 24,
       ncol = 2, cex = 1.5, lwd = 2, pt.bg = "pink", pt.cex = 1:3)
par(op)

## 点に重なる線：
y <- sin(3*pi*x)
plot(x, y, type = "l", col = "blue",
    main = "points with bg & legend(*, pt.bg)")
points(x, y, pch = 21, bg = "white")
legend(.4,1, "sin(c x)", pch = 21, pt.bg = "white", lty = 1, col = "blue")

## 別の場所にタイトル付きの凡例
plot(x, y, type = "n")
legend("bottomright", "(x,y)", pch = 1, title = "bottomright")
legend("bottom", "(x,y)", pch = 1, title = "bottom")
legend("bottomleft", "(x,y)", pch = 1, title = "bottomleft")
legend("left", "(x,y)", pch = 1, title = "left")
legend("topleft", "(x,y)", pch = 1, title = "topleft, inset = .05",
       inset = .05)
legend("top", "(x,y)", pch = 1, title = "top")
legend("topright", "(x,y)", pch = 1, title = "topright, inset = .02",
       inset = .02)
legend("right", "(x,y)", pch = 1, title = "right")
legend("center", "(x,y)", pch = 1, title = "center")

# text.font (と text.col) の使用：
op <- par(mfrow = c(2, 2), mar = rep(2.1, 4))
c6 <- terrain.colors(10)[1:6]
for(i in 1:4) {
   plot(1, type = "n", axes = FALSE, ann = FALSE); title(paste("text.font =",i))
   legend("top", legend = LETTERS[1:6], col = c6,
          ncol = 2, cex = 2, lwd = 3, text.font = i, text.col = c6)
}
par(op)
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/legend.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{legend}
%\alias{legend}
%\title{Add Legends to Plots}
%\usage{
%legend(x, y = NULL, legend, fill = NULL, col = par("col"),
%       border = "black", lty, lwd, pch,
%       angle = 45, density = NULL, bty = "o", bg = par("bg"),
%       box.lwd = par("lwd"), box.lty = par("lty"), box.col = par("fg"),
%       pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
%       xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1,
%       adj = c(0, 0.5), text.width = NULL, text.col = par("col"),
%       text.font = NULL, merge = do.lines && has.pch, trace = FALSE,
%       plot = TRUE, ncol = 1, horiz = FALSE, title = NULL,
%       inset = 0, xpd, title.col = text.col, title.adj = 0.5,
%       seg.len = 2)
%}
%\description{
%  This function can be used to add legends to plots.  Note that a call
%  to the function \code{\link{locator}(1)} can be used in place of the \code{x}
%  and \code{y} arguments.
%}
%\arguments{
%  \item{x, y}{the x and y co-ordinates to be used to position the legend.
%    They can be specified by keyword or in any way which is accepted by
%    \code{\link{xy.coords}}: See \sQuote{Details}.}
%  \item{legend}{a character or \link{expression} vector
%    of length \eqn{\ge 1} to appear in the legend.  Other
%    objects will be coerced by \code{\link{as.graphicsAnnot}}.}
%  \item{fill}{if specified, this argument will cause boxes filled
%    with the specified colors (or shaded in the specified colors)
%    to appear beside the legend text.}
%  \item{col}{the color of points or lines appearing in the legend.}
%  \item{border}{the border color for the boxes (used only if
%    \code{fill} is specified).}
%  \item{lty, lwd}{the line types and widths for lines appearing in the
%    legend.  One of these two \emph{must} be specified for line drawing.}
%  \item{pch}{the plotting symbols appearing in the legend, as
%    numeric vector or a vector of 1-character strings (see
%    \code{\link{points}}). Unlike \code{points}, this can all be
%    specified as a single multi-character string.  \emph{Must} be
%    specified for symbol drawing.}
%  \item{angle}{angle of shading lines.}
%  \item{density}{the density of shading lines, if numeric and
%    positive. If \code{NULL} or negative or \code{NA} color filling
%    is assumed.}
%  \item{bty}{the type of box to be drawn around the legend.  The allowed
%    values are \code{"o"} (the default) and \code{"n"}.}
%  \item{bg}{the background color for the legend box.  (Note that this is
%    only used if \code{bty != "n"}.)}
%  \item{box.lty, box.lwd, box.col}{the line type, width and color for
%    the legend box (if \code{bty = "o"}).}
%  \item{pt.bg}{the background color for the \code{\link{points}},
%    corresponding to its argument \code{bg}.}
%  \item{cex}{character expansion factor \bold{relative} to current
%    \code{par("cex")}.  Used for text, and provides the default for
%    \code{pt.cex} and \code{title.cex}.}
%  \item{pt.cex}{expansion factor(s) for the points.}
%  \item{pt.lwd}{line width for the points, defaults to the one for
%    lines, or if that is not set, to \code{par("lwd")}.}
%  \item{xjust}{how the legend is to be justified relative to the legend
%    x location.  A value of 0 means left justified, 0.5 means centered
%    and 1 means right justified.}
%  \item{yjust}{the same as \code{xjust} for the legend y location.}
%  \item{x.intersp}{character interspacing factor for horizontal (x) spacing.}
%  \item{y.intersp}{the same for vertical (y) line distances.}
%  \item{adj}{numeric of length 1 or 2; the string adjustment for legend
%    text.  Useful for y-adjustment when \code{labels} are
%    \link{plotmath} expressions.}
%  \item{text.width}{the width of the legend text in x (\code{"user"})
%    coordinates.  (Should be positive even for a reversed x axis.)
%    Defaults to the proper value computed by \code{\link{strwidth}(legend)}.}
%  \item{text.col}{the color used for the legend text.}
%  \item{text.font}{the font used for the legend text, see \code{\link{text}}.}
%  \item{merge}{logical; if \code{TRUE}, merge points and lines but
%    not filled boxes.  Defaults to \code{TRUE} if there are points and lines.}
%  \item{trace}{logical; if \code{TRUE}, shows how \code{legend} does all
%    its magical computations.}
%  \item{plot}{logical.  If \code{FALSE}, nothing is plotted but the
%    sizes are returned.}
%  \item{ncol}{the number of columns in which to set the legend items
%    (default is 1, a vertical legend).}
%  \item{horiz}{logical; if \code{TRUE}, set the legend horizontally
%    rather than vertically (specifying \code{horiz} overrides the \code{ncol}
%    specification).}
%  \item{title}{a character string or length-one expression giving a
%    title to be placed at the top of the legend.  Other objects will be
%    coerced by \code{\link{as.graphicsAnnot}}.}
%  \item{inset}{inset distance(s) from the margins as a fraction of the
%    plot region when legend is placed by keyword.}
%  \item{xpd}{if supplied, a value of the \link{graphical parameter} \code{xpd}
%    to be used while the legend is being drawn.}
%  \item{title.col}{color for \code{title}.}
%  \item{title.adj}{horizontal adjustment for \code{title}: see the help
%    for \code{\link{par}("adj")}.}
%  \item{seg.len}{the length of lines drawn to illustrate \code{lty}
%    and/or \code{lwd} (in units of character widths).}
%}
%\details{
%  Arguments \code{x}, \code{y}, \code{legend} are interpreted in a
%  non-standard way to allow the coordinates to be specified \emph{via}
%  one or two arguments.  If \code{legend} is missing and \code{y} is not
%  numeric, it is assumed that the second argument is intended to be
%  \code{legend} and that the first argument specifies the coordinates.
%
%  The coordinates can be specified in any way which is accepted by
%  \code{\link{xy.coords}}.  If this gives the coordinates of one point,
%  it is used as the top-left coordinate of the rectangle containing the
%  legend.  If it gives the coordinates of two points, these specify
%  opposite corners of the rectangle (either pair of corners, in any
%  order).
%
%  The location may also be specified by setting \code{x} to a single
%  keyword from the list \code{"bottomright"}, \code{"bottom"},
%  \code{"bottomleft"}, \code{"left"}, \code{"topleft"},
%  \code{"top"}, \code{"topright"}, \code{"right"} and
%  \code{"center"}. This places the legend on the inside of the plot
%  frame at the given location. Partial argument matching is used.  The
%  optional \code{inset} argument specifies how far the legend is inset
%  from the plot margins.  If a single value is given, it is used for
%  both margins; if two values are given, the first is used for \code{x}-
%  distance, the second for \code{y}-distance.
%
%  Attribute arguments such as \code{col}, \code{pch}, \code{lty}, etc,
%  are recycled if necessary: \code{merge} is not.  Set entries of
%  \code{lty} to \code{0} or set entries of \code{lwd} to \code{NA} to
%  suppress lines in corresponding legend entries; set \code{pch}
%  values to \code{NA} to suppress points.
%
%  Points are drawn \emph{after} lines in order that they can cover the
%  line with their background color \code{pt.bg}, if applicable.
%
%  See the examples for how to right-justify labels.
%
%  Since they are not used for Unicode code points, values \code{-31:-1}
%  are silently omitted, as are \code{NA} and \code{""} values.
%}
%\value{
%  A list with list components
%  \item{rect}{a list with components
%    \describe{
%      \item{\code{w}, \code{h}}{positive numbers giving \bold{w}idth and
%        \bold{h}eight of the legend's box.}
%      \item{\code{left}, \code{top}}{x and y coordinates of upper left
%        corner of the box.}
%    }
%  }
%  \item{text}{a list with components
%    \describe{
%      \item{\code{x, y}}{numeric vectors of length \code{length(legend)},
%        giving the x and y coordinates of the legend's text(s).}
%    }
%  }
%  returned invisibly.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{plot}}, \code{\link{barplot}} which uses \code{legend()}, and
%  \code{\link{text}} for more examples of math expressions.
%}
%\examples{
%## Run the example in '?matplot' or the following:
%leg.txt <- c("Setosa     Petals", "Setosa     Sepals",
%             "Versicolor Petals", "Versicolor Sepals")
%y.leg <- c(4.5, 3, 2.1, 1.4, .7)
%cexv  <- c(1.2, 1, 4/5, 2/3, 1/2)
%matplot(c(1, 8), c(0, 4.5), type = "n", xlab = "Length", ylab = "Width",
%        main = "Petal and Sepal Dimensions in Iris Blossoms")
%for (i in seq(cexv)) {
%  text  (1, y.leg[i] - 0.1, paste("cex=", formatC(cexv[i])), cex = 0.8, adj = 0)
%  legend(3, y.leg[i], leg.txt, pch = "sSvV", col = c(1, 3), cex = cexv[i])
%}
%
%## 'merge = TRUE' for merging lines & points:
%x <- seq(-pi, pi, len = 65)
%plot(x, sin(x), type = "l", ylim = c(-1.2, 1.8), col = 3, lty = 2)
%points(x, cos(x), pch = 3, col = 4)
%lines(x, tan(x), type = "b", lty = 1, pch = 4, col = 6)
%title("legend(..., lty = c(2, -1, 1), pch = c(NA, 3, 4), merge = TRUE)",
%      cex.main = 1.1)
%legend(-1, 1.9, c("sin", "cos", "tan"), col = c(3, 4, 6),
%       text.col = "green4", lty = c(2, -1, 1), pch = c(NA, 3, 4),
%       merge = TRUE, bg = "gray90")
%
%## right-justifying a set of labels: thanks to Uwe Ligges
%x <- 1:5; y1 <- 1/x; y2 <- 2/x
%plot(rep(x, 2), c(y1, y2), type = "n", xlab = "x", ylab = "y")
%lines(x, y1); lines(x, y2, lty = 2)
%temp <- legend("topright", legend = c(" ", " "),
%               text.width = strwidth("1,000,000"),
%               lty = 1:2, xjust = 1, yjust = 1,
%               title = "Line Types")
%text(temp$rect$left + temp$rect$w, temp$text$y,
%     c("1,000", "1,000,000"), pos = 2)
%
%
%##--- log scaled Examples ------------------------------
%leg.txt <- c("a one", "a two")
%
%par(mfrow = c(2, 2))
%for(ll in c("","x","y","xy")) {
%  plot(2:10, log = ll, main = paste0("log = '", ll, "'"))
%  abline(1, 1)
%  lines(2:3, 3:4, col = 2)
%  points(2, 2, col = 3)
%  rect(2, 3, 3, 2, col = 4)
%  text(c(3,3), 2:3, c("rect(2,3,3,2, col=4)",
%                      "text(c(3,3),2:3,\"c(rect(...)\")"), adj = c(0, 0.3))
%  legend(list(x = 2,y = 8), legend = leg.txt, col = 2:3, pch = 1:2,
%         lty = 1, merge = TRUE)   #, trace = TRUE)
%}
%par(mfrow = c(1,1))
%
%##-- Math expressions:  ------------------------------
%x <- seq(-pi, pi, len = 65)
%plot(x, sin(x), type = "l", col = 2, xlab = expression(phi),
%     ylab = expression(f(phi)))
%abline(h = -1:1, v = pi/2*(-6:6), col = "gray90")
%lines(x, cos(x), col = 3, lty = 2)
%ex.cs1 <- expression(plain(sin) * phi,  paste("cos", phi))  # 2 ways
%utils::str(legend(-3, .9, ex.cs1, lty = 1:2, plot = FALSE,
%           adj = c(0, 0.6)))  # adj y !
%legend(-3, 0.9, ex.cs1, lty = 1:2, col = 2:3,  adj = c(0, 0.6))
%
%require(stats)
%x <- rexp(100, rate = .5)
%hist(x, main = "Mean and Median of a Skewed Distribution")
%abline(v = mean(x),   col = 2, lty = 2, lwd = 2)
%abline(v = median(x), col = 3, lty = 3, lwd = 2)
%ex12 <- expression(bar(x) == sum(over(x[i], n), i == 1, n),
%                   hat(x) == median(x[i], i == 1, n))
%utils::str(legend(4.1, 30, ex12, col = 2:3, lty = 2:3, lwd = 2))
%
%## 'Filled' boxes -- for more, see example(plot.factor)
%op <- par(bg = "white") # to get an opaque box for the legend
%plot(cut(weight, 3) ~ group, data = PlantGrowth, col = NULL,
%     density = 16*(1:3))
%par(op)
%
%## Using 'ncol' :
%x <- 0:64/64
%matplot(x, outer(x, 1:7, function(x, k) sin(k * pi * x)),
%        type = "o", col = 1:7, ylim = c(-1, 1.5), pch = "*")
%op <- par(bg = "antiquewhite1")
%legend(0, 1.5, paste("sin(", 1:7, "pi * x)"), col = 1:7, lty = 1:7,
%       pch = "*", ncol = 4, cex = 0.8)
%legend(.8,1.2, paste("sin(", 1:7, "pi * x)"), col = 1:7, lty = 1:7,
%       pch = "*", cex = 0.8)
%legend(0, -.1, paste("sin(", 1:4, "pi * x)"), col = 1:4, lty = 1:4,
%       ncol = 2, cex = 0.8)
%legend(0, -.4, paste("sin(", 5:7, "pi * x)"), col = 4:6,  pch = 24,
%       ncol = 2, cex = 1.5, lwd = 2, pt.bg = "pink", pt.cex = 1:3)
%par(op)
%
%## point covering line :
%y <- sin(3*pi*x)
%plot(x, y, type = "l", col = "blue",
%    main = "points with bg & legend(*, pt.bg)")
%points(x, y, pch = 21, bg = "white")
%legend(.4,1, "sin(c x)", pch = 21, pt.bg = "white", lty = 1, col = "blue")
%
%## legends with titles at different locations
%plot(x, y, type = "n")
%legend("bottomright", "(x,y)", pch = 1, title = "bottomright")
%legend("bottom", "(x,y)", pch = 1, title = "bottom")
%legend("bottomleft", "(x,y)", pch = 1, title = "bottomleft")
%legend("left", "(x,y)", pch = 1, title = "left")
%legend("topleft", "(x,y)", pch = 1, title = "topleft, inset = .05",
%       inset = .05)
%legend("top", "(x,y)", pch = 1, title = "top")
%legend("topright", "(x,y)", pch = 1, title = "topright, inset = .02",
%       inset = .02)
%legend("right", "(x,y)", pch = 1, title = "right")
%legend("center", "(x,y)", pch = 1, title = "center")
%
%# using text.font (and text.col):
%op <- par(mfrow = c(2, 2), mar = rep(2.1, 4))
%c6 <- terrain.colors(10)[1:6]
%for(i in 1:4) {
%   plot(1, type = "n", axes = FALSE, ann = FALSE); title(paste("text.font =",i))
%   legend("top", legend = LETTERS[1:6], col = c6,
%          ncol = 2, cex = 2, lwd = 3, text.font = i, text.col = c6)
%}
%par(op)
%}
%\keyword{aplot}
%
%\encoding{UTF8}
