% File src/library/graphics/man/mosaicplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{mosaicplot}
\alias{mosaicplot}
\alias{mosaicplot.default}
\alias{mosaicplot.formula}
\encoding{UTF-8}
\title{Mosaic Plots}
\description{現在のグラフィックスデバイス上にモザイクをプロットする．}
\usage{
mosaicplot(x, \dots)

\method{mosaicplot}{default}(x, main = deparse(substitute(x)),
           sub = NULL, xlab = NULL, ylab = NULL,
           sort = NULL, off = NULL, dir = NULL,
           color = NULL, shade = FALSE, margin = NULL,
           cex.axis = 0.66, las = par("las"), border = NULL,
           type = c("pearson", "deviance", "FT"), \dots)

\method{mosaicplot}{formula}(formula, data = NULL, \dots,
           main = deparse(substitute(data)), subset,
           na.action = stats::na.omit)
}
\arguments{
  \item{x}{配列形式の分類表で，オプションで
    \code{dimnames(x)} 属性中で指定されるカテゴリラベルを持つ．
    テーブルは \code{table()} 命令で最も容易に作ることが出来る．}
  \item{main}{モザイクのタイトル用の文字列．}
  \item{sub}{モザイクの副タイトル(下部)用の文字列．}
  \item{xlab, ylab}{プロットに使われる x 軸と y 軸ラベル．
    既定では \code{names(dimnames(X))} の最初と二番目の要素
    (つまり \code{X} 中の最初と二番目の変数の名前)．}
  \item{sort}{変数を順序付けるベクトルで，
    整数 \code{1:length(dim(x))} (既定)の置換を含む．}
  \item{off}{モザイクの各レベルのパーセント間隔を決めるオフセットのベクトル
    (適当な値は2 次元の表に対しては分割数の20倍で，さもなければ10 倍．
    最大 50 まで再スケール化され，必要ならリサイクルされる．}
  \item{dir}{モザイクの各レベルに対する分割の方向のベクトル(垂直なら \code{"v"} で水平なら
    \code{"h"})で，分割表の各次元に対して一つの方向．
    既定は互い違いの方向で，垂直の分割から始まる．}
  \item{color}{論理値又は色付き陰影に対する色の(リサイクルされる)ベクトルで，
    \code{shade} が \code{FALSE} の時だけ使われる．もしくは \code{NULL} (既定)．
    既定では灰色の箱が描かれる．\code{color = TRUE} は
    ガンマ補正された灰色パレットを使う．
    \code{color = FALSE} は陰影のない空の箱を与える．}
  \item{shade}{拡張モザイクプロットを作るかどうかを指示する論理値．
    又は少なくとも5個の異なる数値を含む数値ベクトルで残差に対する
    カットポイントの絶対値を与える．
    既定では \code{shade} は \code{FALSE} で，簡単なモザイクが作られる．
    \code{shade = TRUE} の使用は絶対値を 2 か 4 でカットする．}
  \item{margin}{対数線形モデルが当てはめられるマージン集計をもつベクトルのリスト．
    既定では独立モデルが当てはめられる．
    これ以上の情報は \code{\link{loglin}} を見よ．}
  \item{cex.axis}{\code{par("cex")} の倍率としての軸の注釈に使われる拡大率．}
  \item{las}{数値；軸ラベルのスタイル，\code{\link{par}} を見よ．}
  \item{border}{セルの輪郭の色，\code{\link{polygon}} を見よ．}
  \item{type}{表示される残差のタイプを指示する文字列ベクトル．
    \code{"pearson"} (ペアソンの \eqn{\chi^2}{chi-squared} の成分を与える)，
    \code{"deviance"} (尤度比 \eqn{\chi^2}{chi-squared} の成分を与える)，又は
    Freeman-Tukey 残差に対しては \code{"FT"}，のどれか一つでなければならない．
    この引数の値は簡略化出来る．}
  \item{formula}{\code{y ~ x} の様な公式．}
  \item{data}{データフレーム(又はリスト)もしくは分割表で，
    \code{formula} 中の変数が取られる．}
  \item{\dots}{他のメソッドへ・から渡される追加の引数．}
  \item{subset}{プロットに使われるデータフレーム中の部分集合を指定する
    オプションのベクトル．}
  \item{na.action}{データがクロス集計される変数を含み，そして
    これらが \code{NA} を含む時に何が起こるべきかを
    指示する関数．既定では任意の変数中に \code{NA} を含む
    ケースを捨て去る．テーブル化は欠損値を含む全てのケースを
    捨て去るので，これは \code{na.action} 関数が欠損値を置き換える時だけ
    有用である．}
}
\details{
  これは総称的関数である．現在既定メソッド(\code{mosaicplot.default})と
  公式インタフェイス(\code{mosaicplot.formula})を持つ．

  拡張モザイクディスプレイはテーブルに対する対数線形モデルの標準化残差を
  モザイクタイルの色と輪郭で視覚化する．
  (標準化残差はしばしば標準正規分布として参照される．)
  負の残差を表すセルは赤の陰影と破線の輪郭で
  描かれる；正のそれは青と実線で描かれる．

  公式メソッドに対しては，もし \code{data} がクラス
  \code{"table"} や \code{"ftable"} を継承するオブジェクトか
  2次元以上の配列ならば，それは分割表として使われ，従って 
  全ての項目は非負でなければならない．
  entries should be non-negative.
  この場合 \code{formula} の左辺は空でなければならず，右辺の変数は
  分割表の次元属性の名前から取られなければならない．
  これらの変数の周辺テーブルが計算され，
  そしてそのテーブルのモザイクプロットが作られる．

  さもなければ，\code{data} は
  データフレームか行列，クロス集計されるべき変数を含むリストか
  環境でなければならない．
  このケースでは，もしかすると \code{subset} 引数で指定される部分集合を
  選択した後で，分割表が \code{formula} 中に与えられる変数から
  分割表が計算され，これからモザイクが作られる．

  より多くの情報と Nielsen Media Research からのテレビ視聴率を
  用いたケーススタディについては Emerson (1998) を見よ．

  \code{data} がクロス集計される変数を含むときは，
  欠損値は \code{na.action} 関数以外ではサポートされない．

  グリッドグラフィックスで描かれたより柔軟で拡張可能な実装が
  貢献パッケージ \CRANpkg{vcd} (Meyer, Zeileis and Hornik, 2005) 中の関数
  \code{\link[vcd]{mosaic}} で与えられる．
  }
\author{
  S-PLUS 用のオリジナルは John Emerson \email{john.emerson@yale.edu} に
  よる．\R 用のオリジナルな修正と拡張は Kurt Hornik による．
}
\references{
  Hartigan, J.A., and Kleiner, B. (1984)
  A mosaic of television ratings. \emph{The American Statistician},
  \bold{38}, 32--35.

  Emerson, J. W. (1998)
  Mosaic displays in S-PLUS: A general implementation and a case study.
  \emph{Statistical Computing and Graphics Newsletter (ASA)},
  \bold{9}, 1, 17--23.

  Friendly, M. (1994)
  Mosaic displays for multi-way contingency tables.
  \emph{Journal of the American Statistical Association}, \bold{89},
  190--200.

  Meyer, D., Zeileis, A., and Hornik, K. (2005)
  The strucplot framework: Visualizing multi-way contingency tables with vcd.
  \emph{Report 22}, Department of Statistics and Mathematics,
  \enc{Wirtschaftsuniversität}{Wirtschaftsuniversitaet} Wien, Research Report Series.
  \url{http://epub.wu.ac.at/dyn/openURL?id=oai:epub.wu-wien.ac.at:epub-wu-01_8a1}
}
\seealso{
  \code{\link{assocplot}},
  \code{\link{loglin}}.
}
\examples{
require(stats)
mosaicplot(Titanic, main = "Survival on the Titanic", color = TRUE)
## テーブルデータに対する公式インタフェイス：
mosaicplot(~ Sex + Age + Survived, data = Titanic, color = TRUE)

mosaicplot(HairEyeColor, shade = TRUE)
## 髪と瞳の色と性別の独立モデル．独立ケースよりも
## 青い瞳の金髪女性が期待されるよりも多く
## 褐色の瞳の金髪女性が少なすぎることを示している．
## 対応するモデルは：
fm <- loglin(HairEyeColor, list(1, 2, 3))
pchisq(fm$pearson, fm$df, lower.tail = FALSE)

mosaicplot(HairEyeColor, shade = TRUE, margin = list(1:2, 3))
## 性別と髪と瞳の色の同時独立性のモデル．
## 褐色の髪と瞳の色を持つ人々の間に男性が過小で
## 褐色の髪と青い瞳の色を持つ人々の間に男性が過大．
## 対応するモデルは：
fm <- loglin(HairEyeColor, list(1:2, 3))
pchisq(fm$pearson, fm$df, lower.tail = FALSE)

## 生データに対する公式インタフェイス：
## Motor Trend car データ中のギアとキャブレータの数のクロス表を可視化する．
mosaicplot(~ gear + carb, data = mtcars, color = TRUE, las = 1)
# 色のリサイクル
mosaicplot(~ gear + carb, data = mtcars, color = 2:3, las = 1)
}
\keyword{hplot}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/mosaicplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mosaicplot}
%\alias{mosaicplot}
%\alias{mosaicplot.default}
%\alias{mosaicplot.formula}
%\encoding{UTF-8}
%\title{Mosaic Plots}
%\description{Plots a mosaic on the current graphics device.}
%\usage{
%mosaicplot(x, \dots)
%
%\method{mosaicplot}{default}(x, main = deparse(substitute(x)),
%           sub = NULL, xlab = NULL, ylab = NULL,
%           sort = NULL, off = NULL, dir = NULL,
%           color = NULL, shade = FALSE, margin = NULL,
%           cex.axis = 0.66, las = par("las"), border = NULL,
%           type = c("pearson", "deviance", "FT"), \dots)
%
%\method{mosaicplot}{formula}(formula, data = NULL, \dots,
%           main = deparse(substitute(data)), subset,
%           na.action = stats::na.omit)
%}
%\arguments{
%  \item{x}{a contingency table in array form, with optional category
%    labels specified in the \code{dimnames(x)} attribute.  The table is
%    best created by the \code{table()} command.}
%  \item{main}{character string for the mosaic title.}
%  \item{sub}{character string for the mosaic sub-title (at bottom).}
%  \item{xlab, ylab}{x- and y-axis labels used for the plot; by default,
%    the first and second element of \code{names(dimnames(X))} (i.e., the
%    name of the first and second variable in \code{X}).}
%  \item{sort}{vector ordering of the variables, containing a permutation
%    of the integers \code{1:length(dim(x))} (the default).}
%  \item{off}{vector of offsets to determine percentage spacing at each
%    level of the mosaic (appropriate values are between 0 and 20,
%    and the default is 20 times the number of splits for 2-dimensional
%    tables, and 10 otherwise.  Rescaled to maximally 50, and recycled if
%    necessary.}
%  \item{dir}{vector of split directions (\code{"v"} for vertical and
%    \code{"h"} for horizontal) for each level of the mosaic, one
%    direction for each dimension of the contingency table.  The
%    default consists of alternating directions, beginning with a
%    vertical split.}
%  \item{color}{logical or (recycling) vector of colors for color
%    shading, used only when \code{shade} is \code{FALSE}, or \code{NULL}
%    (default).  By default, grey boxes are drawn.  \code{color = TRUE}
%    uses a gamma-corrected grey palette.  \code{color = FALSE} gives empty
%    boxes with no shading.}
%  \item{shade}{a logical indicating whether to produce extended mosaic
%    plots, or a numeric vector of at most 5 distinct positive numbers
%    giving the absolute values of the cut points for the residuals.  By
%    default, \code{shade} is \code{FALSE}, and simple mosaics are
%    created.  Using \code{shade = TRUE} cuts absolute values at 2 and
%    4.}
%  \item{margin}{a list of vectors with the marginal totals to be fit in
%    the log-linear model.  By default, an independence model is fitted.
%    See \code{\link{loglin}} for further information.}
%  \item{cex.axis}{The magnification to be used for axis annotation,
%    as a multiple of \code{par("cex")}.}
%  \item{las}{numeric; the style of axis labels, see \code{\link{par}}.}
%  \item{border}{colour of borders of cells: see \code{\link{polygon}}.}
%  \item{type}{a character string indicating the type of residual to be
%    represented.  Must be one of \code{"pearson"} (giving components of
%    Pearson's \eqn{\chi^2}{chi-squared}), \code{"deviance"} (giving
%    components of the likelihood ratio \eqn{\chi^2}{chi-squared}), or
%    \code{"FT"} for the Freeman-Tukey residuals.  The value of this
%    argument can be abbreviated.}
%  \item{formula}{a formula, such as \code{y ~ x}.}
%  \item{data}{a data frame (or list), or a contingency table from which
%    the variables in \code{formula} should be taken.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%  \item{subset}{an optional vector specifying a subset of observations
%    in the data frame to be used for plotting.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contains variables to be cross-tabulated, and these
%    variables contain \code{NA}s.  The default is to omit cases which
%    have an \code{NA} in any variable.  Since the tabulation will omit
%    all cases containing missing values, this will only be useful if the
%    \code{na.action} function replaces missing values.}
%}
%\details{
%  This is a generic function.  It currently has a default method
%  (\code{mosaicplot.default}) and a formula interface
%  (\code{mosaicplot.formula}).
%
%  Extended mosaic displays visualize standardized residuals of a
%  loglinear model for the table by color and outline of the mosaic's
%  tiles.  (Standardized residuals are often referred to a standard
%  normal distribution.)  Cells representing negative residuals are drawn
%  in shaded of red and with broken borders; positive ones are drawn in
%  blue with solid borders.
%
%  For the formula method, if \code{data} is an object inheriting from
%  class \code{"table"} or class \code{"ftable"} or an array with more
%  than 2 dimensions, it is taken as a contingency table, and hence all
%  entries should be non-negative.  In this case the left-hand side of
%  \code{formula} should be empty and the variables on the right-hand
%  side should be taken from the names of the dimnames attribute of the
%  contingency table.  A marginal table of these variables is computed,
%  and a mosaic plot of that table is produced.
%
%  Otherwise, \code{data} should be a data frame or matrix, list or
%  environment containing the variables to be cross-tabulated.  In this
%  case, after possibly selecting a subset of the data as specified by
%  the \code{subset} argument, a contingency table is computed from the
%  variables given in \code{formula}, and a mosaic is produced from
%  this.
%
%  See Emerson (1998) for more information and a case study with
%  television viewer data from Nielsen Media Research.
%
%  Missing values are not supported except via an \code{na.action}
%  function when \code{data} contains variables to be cross-tabulated.
%
%  A more flexible and extensible implementation of mosaic plots written
%  in the grid graphics system is provided in the function
%  \code{\link[vcd]{mosaic}} in the contributed package \CRANpkg{vcd}
%  (Meyer, Zeileis and Hornik, 2005).
%}
%\author{
%  S-PLUS original by John Emerson \email{john.emerson@yale.edu}.
%  Originally modified and enhanced for \R by Kurt Hornik.
%}
%\references{
%  Hartigan, J.A., and Kleiner, B. (1984)
%  A mosaic of television ratings. \emph{The American Statistician},
%  \bold{38}, 32--35.
%
%  Emerson, J. W. (1998)
%  Mosaic displays in S-PLUS: A general implementation and a case study.
%  \emph{Statistical Computing and Graphics Newsletter (ASA)},
%  \bold{9}, 1, 17--23.
%
%  Friendly, M. (1994)
%  Mosaic displays for multi-way contingency tables.
%  \emph{Journal of the American Statistical Association}, \bold{89},
%  190--200.
%
%  Meyer, D., Zeileis, A., and Hornik, K. (2005)
%  The strucplot framework: Visualizing multi-way contingency tables with vcd.
%  \emph{Report 22}, Department of Statistics and Mathematics,
%  \enc{Wirtschaftsuniversität}{Wirtschaftsuniversitaet} Wien, Research Report Series.
%  \url{http://epub.wu.ac.at/dyn/openURL?id=oai:epub.wu-wien.ac.at:epub-wu-01_8a1}
%}
%\seealso{
%  \code{\link{assocplot}},
%  \code{\link{loglin}}.
%}
%\examples{
%require(stats)
%mosaicplot(Titanic, main = "Survival on the Titanic", color = TRUE)
%## Formula interface for tabulated data:
%mosaicplot(~ Sex + Age + Survived, data = Titanic, color = TRUE)
%
%mosaicplot(HairEyeColor, shade = TRUE)
%## Independence model of hair and eye color and sex.  Indicates that
%## there are more blue eyed blonde females than expected in the case
%## of independence and too few brown eyed blonde females.
%## The corresponding model is:
%fm <- loglin(HairEyeColor, list(1, 2, 3))
%pchisq(fm$pearson, fm$df, lower.tail = FALSE)
%
%mosaicplot(HairEyeColor, shade = TRUE, margin = list(1:2, 3))
%## Model of joint independence of sex from hair and eye color.  Males
%## are underrepresented among people with brown hair and eyes, and are
%## overrepresented among people with brown hair and blue eyes.
%## The corresponding model is:
%fm <- loglin(HairEyeColor, list(1:2, 3))
%pchisq(fm$pearson, fm$df, lower.tail = FALSE)
%
%## Formula interface for raw data: visualize cross-tabulation of numbers
%## of gears and carburettors in Motor Trend car data.
%mosaicplot(~ gear + carb, data = mtcars, color = TRUE, las = 1)
%# color recycling
%mosaicplot(~ gear + carb, data = mtcars, color = 2:3, las = 1)
%}
%\keyword{hplot}
%
%\encoding{UTF8}

\encoding{UTF8}

