% File src/library/graphics/man/text.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{text}
\title{Add Text to a Plot}
\encoding{UTF-8}
\usage{
text(x, \dots)

\method{text}{default} (x, y = NULL, labels = seq_along(x), adj = NULL,
     pos = NULL, offset = 0.5, vfont = NULL,
     cex = 1, col = NULL, font = NULL, \dots)
}
\alias{text}
\alias{text.default}
\arguments{
  \item{x, y}{
    テキスト \code{labels} が書かれる座標の数値ベクトル．
    もし \code{x} と \code{y} の長さが異なれば，短いほうが
    リサイクルされる．}
  \item{labels}{書き込まれるテキストを指定する文字列ベクトルもしくは
    表現式．
    他の言語オブジェクト(名前と呼び出し)を表現式に，ベクトルと他のクラス付きオブジェクトを
    \code{\link{as.character}} で文字列ベクトルに
    変換することが試みられる．
    もし \code{labels} が \code{x} と \code{y} より長ければ，
    座標が \code{labels} の長さまでリサイクルされる．}
  \item{adj}{
    \eqn{[0, 1]} 中の一つ又は二つの値で，ラベルの x (オプションで y)補正
    を指定する．殆どのデバイスで区間外の値も使える．}
  \item{pos}{テキストの位置を指定する．
    もし指定されるとこれは
    与えられた任意の \code{adj} 値を上書きする．
    値 \code{1}, \code{2}, \code{3} そして \code{4} はそれぞれ
    指定座標の 下，左，上，そして右位置を指定する．}
  \item{offset}{
    \code{pos} が指定されると，この値はラベルの指定位置からの
    オフセットを文字幅の割合で与える．．}
  \item{vfont}{現在のフォント族に対しては \code{NULL}で，
    Hershey ベクトルフォントに対しては長さ 2 の文字列ベクトル．
    ベクトルの最初の要素はタイプフェイスを，二番目はスタイルを
    選択する．
    もし \code{labels} が表現式ならば無視される．}
  \item{cex}{文字の数値拡大因子；
    これを \code{\link{par}("cex")} 倍したものが最終的な文字サイズになる．
    \code{NULL} と \code{NA} は \code{1.0} に等しい．}
  \item{col, font}{使われる色と(もし \code{vfont = NULL} ならば)フォントで，
    ベクトルかもしれない．
    これらの既定値は \code{\link{par}()} 中の大局的グラフィカルパラメータの
    値である．}
  \item{\dots}{
    \code{srt}, \code{family} そして \code{xpd} のような
    (\code{\link{par}} からの)追加のグラフィカルパラメータ．}
}
\description{
  \code{text} はベクトル \code{labels} 中に与えられた文字列を
  \code{x} と \code{y} で与えられた座標に書く．
  \code{\link{xy.coords}(x, y)} が座標の構成に使われるので
  \code{y} は欠損しているかもしれない．
}
\details{
  \code{labels} は文字列型か
  表現式型(又はそうした型に変換できるもの)でなければならない．
  後者の場合
  下付きや上付き文字，ギリシャ文字，分数等極めて
  僅かな数学表現が可能である．

  \code{adj} は
  \code{(x, y)} に関するテキストの補正を認める．
  値 0, 0.5 そして 1 はそれぞれ 左/下，中央そして
  右/上に揃える．既定値は中央揃え，つまり
  \code{adj = c(0.5, NA)} である．
  垂直の正確な中央化は個々の文字の文字メトリック情報を必要とするが
  これはある種のデバイスでしか利用できない．
  垂直の整列は文字列と表現式では少し違って行われる：
  \code{adj = c(0,0)} は文字列では左揃えで
  文字列の基本線で揃えることを意味するが，
  表現式ではバウンディングボックスの下で揃える．
  これはまた垂直のセンタリングにも影響する：
  文字列に対してはセンタリングは小文字の下に伸びた部分を
  除外するが，表現式に対してはそれらを含む．
  文字列に対する \code{NA} は小文字の下に伸びた部分を含み
  それらをセンタリングする．

  \code{pos} と \code{offset} 引数は
  \code{identify} が返す値と共に対話的なラベルのプロットを
  作るのに使うことが出来る．

  テキストはグラフィカルパラメータ
  \code{srt} (\code{\link{par}} を見よ)を使って回転できる；
  これは \code{adj} で設定される中心の周りに回転する．

  グラフィカルパラメータ\code{col}, \code{cex} そして \code{font}
  はベクトルでよく，その時は
  \code{labels} に周期的に適用される
  (そして余分の値は無視される)．
  \code{font} に対する \code{NA} 値は
  \code{par("font")} で置き換えられ，
  \code{col} に対しても同様である．
  
  \code{x}, \code{y} 又は \code{labels} の値が \code{NA}
  であるラベルはプロットから除外される．

  \code{font = 5} (シンボルフォント)が選択された時何が起きるかは
  デバイスとロケール依存である．
  最も多くの場合 \code{labels} は
  Adobe のシンボルエンコーディングで解釈されるので，
  例えば \code{"d"} はデルタであり，
  \code{"\300"} はアレフになる．
}
\section{ユーロシンボル}{
  ユーロシンボルは古いフォントでは利用できないかもしれない．
  現在の Adobe シンボルフォントではそれは文字 160 であり，従って
  \code{text(x, y, "\xA0", font = 5)} が使えるかもしれない．
  Unix 風システムで西ヨーロッパロケールを使っているならば
  おそらくユーロとして文字 165 を持つ
  ISO-8895-15 (Latin-9) を選ぶことが出来るであろう：
  これはまた \code{\link{postscript}} と \code{\link{pdf}} でも
  使える．Unicode ではそれは \samp{\u20ac} であり，
  UTF-8 ロケールで使うことが出来る．
#ifdef unix

  ユーロは UTF-8 ロケールでは
  \code{\link{X11}} により正しく表示できるが，
  \code{\link{postscript}} と \code{\link{pdf}} 中の
  単バイトロケールでは
  \code{ISOLatin9.enc} として選択される必要がある
  (フォントがユーロのグリフを含む必要があるが，
  古いプリンタは含まないかもしれない)．
#endif
#ifdef windows

  全てのヨーロッパの Windows エンコーディングではユーロは
  シンボル 128 で \samp{\u20ac} が全てのロケールで使える：
  しかしながら全てのフォントがそれを含まないかもしれない．
  それは \code{\link{windows}} と関連するデバイスに対して
  使われるシンボルフォント中には無く，
  Windows プリンタも同様である．
#endif
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  公式メソッドに対しては \code{\link{text.formula}}；
  \code{\link{mtext}}, \code{\link{title}},
  Hershey ベクトルフォントについては \code{\link{Hershey}}，
  数学的注釈に関する詳細とより多くの例については
  \code{\link{plotmath}}．
}
\examples{
plot(-1:1, -1:1, type = "n", xlab = "Re", ylab = "Im")
K <- 16; text(exp(1i * 2 * pi * (1:K) / K), col = 2)

## 次の二つの例は latin1 文字を使う：これらは
## 正しく表現されないかもしれない(又は完全に無視される)．
plot(1:10, 1:10, main = "text(...) examples\n~~~~~~~~~~~~~~",
     sub = "R is GNU ©, but not ® ...")
mtext("«Latin-1 accented chars»: éè øØ å<Å æ<Æ", side = 3)
points(c(6,2), c(2,1), pch = 3, cex = 4, col = "red")
text(6, 2, "the text is CENTERED around (x,y) = (6,2) by default",
     cex = .8)
text(2, 1, "or Left/Bottom - JUSTIFIED at (2,1) by 'adj = c(0,0)'",
     adj = c(0,0))
text(4, 9, expression(hat(beta) == (X^t * X)^{-1} * X^t * y))
text(4, 8.4, "expression(hat(beta) == (X^t * X)^{-1} * X^t * y)",
     cex = .75)
text(4, 7, expression(bar(x) == sum(frac(x[i], n), i==1, n)))

## もう二つの latin1 の例
text(5, 10.2,
     "Le français, c'est façile: Règles, Liberté, Egalité, Fraternité...")
text(5, 9.8,
     "Jetz no chli züritüütsch: (noch ein bißchen Zürcher deutsch)")
}
\keyword{aplot}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/text.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{text}
%\title{Add Text to a Plot}
%\encoding{UTF-8}
%\usage{
%text(x, \dots)
%
%\method{text}{default} (x, y = NULL, labels = seq_along(x), adj = NULL,
%     pos = NULL, offset = 0.5, vfont = NULL,
%     cex = 1, col = NULL, font = NULL, \dots)
%}
%\alias{text}
%\alias{text.default}
%\arguments{
%  \item{x, y}{numeric vectors of coordinates where the text
%    \code{labels} should be written.  If the length of \code{x} and
%    \code{y} differs, the shorter one is recycled.}
%  \item{labels}{a character vector or \link{expression} specifying
%    the \emph{text} to be written.  An attempt is made to coerce other
%    language objects (names and calls) to expressions, and vectors and
%    other classed objects to character vectors by \code{\link{as.character}}.
%    If \code{labels} is longer than \code{x} and
%    \code{y}, the coordinates are recycled to the length of \code{labels}.}
%  \item{adj}{one or two values in \eqn{[0, 1]} which specify the x
%    (and optionally y) adjustment of the labels.  On most devices values
%    outside that interval will also work.}
%  \item{pos}{a position specifier for the text.  If specified this
%    overrides any \code{adj} value given.  Values of \code{1},
%    \code{2}, \code{3} and \code{4}, respectively indicate
%    positions below, to the left of, above and to the right of
%    the specified coordinates.}
%  \item{offset}{when \code{pos} is specified, this value gives the
%    offset of the label from the specified coordinate in fractions
%    of a character width.}
%  \item{vfont}{\code{NULL} for the current font family, or a character
%    vector of length 2 for Hershey vector fonts.  The first element of
%    the vector selects a typeface and the second element selects a
%    style.  Ignored if \code{labels} is an expression.}
%  \item{cex}{numeric \bold{c}haracter \bold{ex}pansion factor; multiplied
%    by \code{\link{par}("cex")} yields the final character size.
%    \code{NULL} and \code{NA} are equivalent to \code{1.0}.}
%  \item{col, font}{the color and (if \code{vfont = NULL}) font to be
%    used, possibly vectors.  These default to the values of the global
%    \link{graphical parameters} in \code{\link{par}()}.}
%  \item{\dots}{further \link{graphical parameters} (from \code{\link{par}}),
%    such as \code{srt}, \code{family} and \code{xpd}.}
%}
%\description{
%  \code{text} draws the strings given in the vector \code{labels} at the
%  coordinates given by \code{x} and \code{y}.
%  \code{y} may be missing since \code{\link{xy.coords}(x, y)} is used for
%  construction of the coordinates.
%}
%\details{
%  \code{labels} must be of type \code{\link{character}} or
%  \code{\link{expression}} (or be coercible to such a type).
%  In the latter case, quite a bit of
%  mathematical notation is available such as sub- and superscripts,
%  greek letters, fractions, etc.
%
%  \code{adj} allows \emph{adj}ustment of the text with respect to
%  \code{(x, y)}.
%  Values of 0, 0.5, and 1 specify left/bottom, middle and
%  right/top alignment, respectively.  The default is for centered text, i.e.,
%  \code{adj = c(0.5, NA)}.  Accurate vertical centering needs
%  character metric information on individual characters which is
%  only available on some devices.  Vertical alignment is done slightly
%  differently for character strings and for expressions:
%  \code{adj = c(0,0)} means to left-justify and to align on the baseline
%  for strings but on the bottom of the bounding box for expressions.
%  This also affects vertical centering: for strings the centering
%  excludes any descenders whereas for expressions it includes them.
%  Using \code{NA} for strings centers them, including descenders.
%
%  The \code{pos} and \code{offset} arguments can be used in conjunction
%  with values returned by \code{identify} to recreate an interactively
%  labelled plot.
%
%  Text can be rotated by using \link{graphical parameters} \code{srt}
%  (see \code{\link{par}}); this rotates about the centre set by
%  \code{adj}.
%
%  Graphical parameters \code{col}, \code{cex} and \code{font} can be
%  vectors and will then be applied cyclically to the \code{labels} (and
%  extra values will be ignored).  \code{NA} values of \code{font} are
%  replaced by \code{par("font")}, and similarly for \code{col}.
%
%  Labels whose \code{x}, \code{y} or \code{labels} value is \code{NA}
%  are omitted from the plot.
%
%  What happens when \code{font = 5} (the symbol font) is selected can be
%  both device- and locale-dependent.  Most often \code{labels} will be
%  interpreted in the Adobe symbol encoding, so e.g.\sspace{}\code{"d"}
%  is delta, and \code{"\300"} is aleph.
%}
%\section{Euro symbol}{
%  The Euro symbol may not be available in older fonts.  In current
%  versions of Adobe symbol fonts it is character 160, so \code{text(x,
%  y, "\xA0", font = 5)} may work. People using Western European locales
%  on Unix-alikes can probably select ISO-8895-15 (Latin-9) which has the
%  Euro as character 165: this can also be used for
%  \code{\link{postscript}} and \code{\link{pdf}}. It is \samp{\u20ac} in
%  Unicode, which can be used in UTF-8 locales.
%#ifdef unix
%
%  The Euro should be rendered correctly by \code{\link{X11}} in UTF-8
%  locales, but the corresponding single-byte encoding in
%  \code{\link{postscript}} and \code{\link{pdf}} will need to be selected
%  as \code{ISOLatin9.enc} (and the font will need to contain the Euro
%  glyph, which for example older printers may not).
%#endif
%#ifdef windows
%
%  In all the European Windows encodings the Euro is symbol 128 and
%  \samp{\u20ac} will work in all locales: however not all fonts will
%  include it.  It is not in the symbol font used for
%  \code{\link{windows}} and related devices, including the Windows printer.
%#endif
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{text.formula}} for the formula method;
%  \code{\link{mtext}}, \code{\link{title}},
%  \code{\link{Hershey}} for details on Hershey vector fonts,
%  \code{\link{plotmath}} for details and more examples on
%  mathematical annotation.
%}
%\examples{
%plot(-1:1, -1:1, type = "n", xlab = "Re", ylab = "Im")
%K <- 16; text(exp(1i * 2 * pi * (1:K) / K), col = 2)
%
%## The following two examples use latin1 characters: these may not
%## appear correctly (or be omitted entirely).
%plot(1:10, 1:10, main = "text(...) examples\n~~~~~~~~~~~~~~",
%     sub = "R is GNU ©, but not ® ...")
%mtext("«Latin-1 accented chars»: éè øØ å<Å æ<Æ", side = 3)
%points(c(6,2), c(2,1), pch = 3, cex = 4, col = "red")
%text(6, 2, "the text is CENTERED around (x,y) = (6,2) by default",
%     cex = .8)
%text(2, 1, "or Left/Bottom - JUSTIFIED at (2,1) by 'adj = c(0,0)'",
%     adj = c(0,0))
%text(4, 9, expression(hat(beta) == (X^t * X)^{-1} * X^t * y))
%text(4, 8.4, "expression(hat(beta) == (X^t * X)^{-1} * X^t * y)",
%     cex = .75)
%text(4, 7, expression(bar(x) == sum(frac(x[i], n), i==1, n)))
%
%## Two more latin1 examples
%text(5, 10.2,
%     "Le français, c'est façile: Règles, Liberté, Egalité, Fraternité...")
%text(5, 9.8,
%     "Jetz no chli züritüütsch: (noch ein bißchen Zürcher deutsch)")
%}
%\keyword{aplot}
%
%
%\encoding{UTF8}

\encoding{UTF8}

