% File src/library/parallel/man/unix/children.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mcchildren}
\alias{children}
\alias{readChild}
\alias{readChildren}
\alias{selectChildren}
\alias{sendChildStdin}
\alias{sendMaster}
\alias{mckill}
\title{Low-level Functions for Management of Forked Processes}
\description{
  これらはフォークを使ったアプローチに対する低水準のサポート
  関数である．

  これらは Windows では利用できず，名前空間から移出されない．
}
\usage{
children(select)
readChild(child)
readChildren(timeout = 0)
selectChildren(children = NULL, timeout = 0)
sendChildStdin(child, what)
sendMaster(what)

mckill(process, signal = 2L)
}
\arguments{
  \item{select}{もし省略されると，全てのアクティブな子プロセスが
    返される．さもなければ
    \code{select} はプロセスのリストであるべきで，
    アクティブなリストからのそれらだけが返される．}
  \item{child}{子プロセス(クラス \code{"childProcess"} のオブジェクト)
    又はプロセス ID (pid)．\sQuote{詳細}も見よ．}
  \item{timeout}{応答を諦める前に待つ時間切れ時間(秒単位，小数が可能)．}
  \item{children}{子プロセスのリスト，
    単一の子プロセス，またはプロセス ID のベクトル，又は
    \code{NULL}．もし \code{NULL} ならば
    現在知られている子プロセス全てが提供される．}
  \item{what}{\code{sendChildStdin} に対して：\cr
    文字列かバイト型ベクトル．
    最初のケースでは要素は新行文字を使い一つにまとめられる．
    (しかし末尾には新行文字が加えられない!)

    \code{sendMaster} に対して：\cr
    マスタープロセスに送るデータ．
    もし \code{what} がバイト型ベクトルでなければ，
    それはバイト型ベクトルにシリアル化される．
    空のバイト型ベクトルを送らないこと -- それは内部的使用のため
    予約されている．}
  \item{process}{プロセス(クラス \code{process} のオブジェクト)又は
    プロセス ID (pid)．}
  \item{signal}{整数：送るシグナル．値 2 (SIGINT), 9
    (SIGKILL) そして 15 (SIGTERM) はかなりの程度に可搬的であるが，
    最大の可搬性のためには \code{tools::\link{SIGTERM}} 等を
    使う．}
}
\details{
  \code{children} は現在アクティブな子プロセスを返す．

  \code{readChild} は与えられた子プロセスからのデータを読み取る．

  \code{selectChildren} は子プロセスに利用可能なデータがあるかどうかをチェックする．

  \code{readChildren} は全ての子プロセスが利用可能なデータを持つかどうか
  チェックし，利用可能なデータを持つ最初の子プロセスから
  読み取る．

  \code{sendChildStdin} は文字列(又はデータ)を一つ又は複数の
  子プロセスの入力に送る．
  もしマスターセッションが対話的ならば，
  それはまたマスタープロセスの標準出力にエコーされる
  (無効にされていない限り)．
  この関数はベクトル互換であり，従って
  \code{child} をリスト又はプロセス ID のベクトルとして
  指定できる．

  \code{sendMaster} はデータを子プロセスからマスタープロセスに送る．

  \code{mckill} はシグナルを一つの子プロセスに送る：
  これはパッケージ \pkg{tools} 中の
  \code{\link{pskill}} と同値である．
}
\value{
  \code{children} は(もしかすると空の)プロセス ID であるクラス
  \code{"process"} のオブジェクトのリストを返す．

  \code{readChild} と \code{readChildren} はもしデータが利用可能ならば
  \code{"pid"} 属性を持つバイト型ベクトル，
  もし子プロセスが終了していればプロセス ID を持つ長さ 1 の
  整数ベクトル，又は子プロセスが最早存在しなければ
  \code{NULL} を返す
  (\code{readChildren} に対して子プロセスが全く無い).

  \code{selectChildren} はもし時間切れならば \code{TRUE} を，
  もし エラーが起きていれば \code{FALSE}
  (つまりもしマスタープロセスが中断されていれば)，又は
  データが利用可能な子プロセスのプロセス ID の整数ベクトル，もしくは
  子プロセスが存在しなければ \code{NULL} を返す．

  \code{sendChildStdin} は
  \code{TRUE} 値のベクトルを返す
  (\code{child} の各メンバーに対して一つ)，又は
  エラーを出す．

  \code{sendMaster} は \code{TRUE} を返すかエラーを出す．

  \code{mckill} は \code{TRUE} を返す．
}
\author{
  Simon Urbanek と R Core．

  Derived from the
  \CRANpkg{multicore} パッケージから導入された．
}
\section{警告}{
  これはエキスパート使用専用の非常に低水準の API である．
}
\seealso{
  \code{\link{mcfork}}, \code{\link{sendMaster}}, \code{\link{mcparallel}}
}
\examples{\dontrun{
p  <- mcparallel(scan(n = 1, quiet = TRUE))
sendChildStdin(p, "17.4\n")
mccollect(p)[[1]]
}}
\keyword{interface}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/unix/children.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mcchildren}
%\alias{children}
%\alias{readChild}
%\alias{readChildren}
%\alias{selectChildren}
%\alias{sendChildStdin}
%\alias{sendMaster}
%\alias{mckill}
%\title{Low-level Functions for Management of Forked Processes}
%\description{
%  These are low-level support functions for the forking approach.
%
%  They are not available on Windows, and not exported from the namespace.
%}
%\usage{
%children(select)
%readChild(child)
%readChildren(timeout = 0)
%selectChildren(children = NULL, timeout = 0)
%sendChildStdin(child, what)
%sendMaster(what)
%
%mckill(process, signal = 2L)
%}
%\arguments{
%  \item{select}{if omitted, all active children are returned, otherwise
%    \code{select} should be a list of processes and only those from the
%    list that are active will be returned.}
%  \item{child}{child process (object of the class \code{"childProcess"}) or a
%    process ID (pid).  See also \sQuote{Details}.}
%  \item{timeout}{timeout (in seconds, fractions supported) to wait
%    for a response before giving up.}
%  \item{children}{list of child processes or a single child process
%    object or a vector of process IDs or \code{NULL}.  If \code{NULL}
%    behaves as if all currently known children were supplied.}
%  \item{what}{For \code{sendChildStdin}:\cr
%    Character or raw vector.  In the former case elements are
%    collapsed using the newline character.  (But no trailing newline is
%    added at the end!)
%
%    For \code{sendMaster}:\cr
%    Data to send to the master process.  If \code{what} is not
%    a raw vector, it will be serialized into a raw vector.  Do NOT
%    send an empty raw vector -- that is reserved for internal use.}
%  \item{process}{process (object of the class \code{process}) or a
%    process ID (pid)}
%  \item{signal}{integer: signal to send.  Values of 2 (SIGINT), 9
%    (SIGKILL) and 15 (SIGTERM) are pretty much portable, but for maximal
%    portability use \code{tools::\link{SIGTERM}} and so on.}
%}
%\details{
%  \code{children} returns currently active children.
%
%  \code{readChild} reads data from a given child process.
%
%  \code{selectChildren} checks children for available data.
%
%  \code{readChildren} checks all children for available data and reads
%  from the first child that has available data.
%
%  \code{sendChildStdin} sends a string (or data) to one or more child's
%  standard input.  Note that if the master session was interactive, it
%  will also be echoed on the standard output of the master process
%  (unless disabled).  The function is vector-compatible, so you can
%  specify \code{child} as a list or a vector of process IDs.
%
%  \code{sendMaster} sends data from the child to the master process.
%
%  \code{mckill} sends a signal to a child process: it is equivalent to
%  \code{\link{pskill}} in package \pkg{tools}.
%}
%\value{
%  \code{children} returns a (possibly empty) list of objects of class
%  \code{"process"}, the process ID.
%
%  \code{readChild} and \code{readChildren} return a raw vector with a
%  \code{"pid"} attribute if data were available, an integer vector of
%  length one with the process ID if a child terminated or \code{NULL}
%  if the child no longer exists (no children at all for
%  \code{readChildren}).
%
%  \code{selectChildren} returns \code{TRUE} is the timeout was reached,
%  \code{FALSE} if an error occurred (e.g., if the master process was
%  interrupted) or an integer vector of process IDs with children that
%  have data available, or \code{NULL} if there are no children.
%
%  \code{sendChildStdin} returns a vector of \code{TRUE} values (one for
%  each member of \code{child}) or throws an error.
%
%  \code{sendMaster} returns \code{TRUE} or throws an error.
%
%  \code{mckill} returns \code{TRUE}.
%}
%\author{
%  Simon Urbanek and R Core.
%
%  Derived from the \CRANpkg{multicore} package.
%}
%\section{Warning}{
%  This is a very low-level API for expert use only.
%}
%\seealso{
%  \code{\link{mcfork}}, \code{\link{sendMaster}}, \code{\link{mcparallel}}
%}
%\examples{\dontrun{
%p  <- mcparallel(scan(n = 1, quiet = TRUE))
%sendChildStdin(p, "17.4\n")
%mccollect(p)[[1]]
%}}
%\keyword{interface}
%
%\encoding{UTF-8}
%\encoding{UTF8}

\encoding{UTF8}

